=== modified file 'HACKING'
--- HACKING	2006-09-13 02:09:37 +0000
+++ HACKING	2006-10-11 01:17:15 +0000
@@ -56,7 +56,7 @@
 applies to modules and classes.
 
 If you wish to change the behaviour of a supported API in an incompatible
-way, you need to change its name as well. For instance, if I add a optional keyword
+way, you need to change its name as well. For instance, if I add an optional keyword
 parameter to branch.commit - that's fine. On the other hand, if I add a
 keyword parameter to branch.commit which is a *required* transaction
 object, I should rename the API - i.e. to 'branch.commit_transaction'. 
@@ -67,7 +67,7 @@
 details for you - such as updating the docstring, and issuing a warning
 when the old api is used.
 
-For unsupported API's, it does not hurt to follow this discipline, but its
+For unsupported API's, it does not hurt to follow this discipline, but it's
 not required. Minimally though, please try to rename things so that
 callers will at least get an AttributeError rather than weird results.
 
@@ -78,7 +78,7 @@
 There are some common requirements in the library: some parameters need to be
 unicode safe, some need byte strings, and so on. At the moment we have
 only codified one specific pattern: Parameters that need to be unicode
-should be check via 'bzrlib.osutils.safe_unicode'. This will coerce the
+should be checked via 'bzrlib.osutils.safe_unicode'. This will coerce the
 input into unicode in a consistent fashion, allowing trivial strings to be
 used for programmer convenience, but not performing unpredictably in the
 presence of different locales.
@@ -227,21 +227,25 @@
   from bzrlib import (
      errors,
      transport,
-     foo as bar,
+     revision as _mod_revision,
      )
   import bzrlib.transport
   import bzrlib.xml5
   """)
 
 At this point, all of these exist as a ``ImportReplacer`` object, ready to
-be imported once a member is accessed.
+be imported once a member is accessed. Also, when importing a module into
+the local namespace, which is likely to clash with variable names, it is
+recommended to prefix it as ``_mod_<module>``. This makes it clean that
+the variable is a module, and these object should be hidden anyway, since
+they shouldn't be imported into other namespaces.
 
 
 Modules versus Members
 ~~~~~~~~~~~~~~~~~~~~~~
 
 While it is possible for ``lazy_import()`` to import members of a module
-wehn using the ``from module import member`` syntax, it is recommended to
+when using the ``from module import member`` syntax, it is recommended to
 only use that syntax to load sub modules ``from module import submodule``.
 This is because variables and classes can frequently be used without
 needing a sub-member for example::
@@ -338,7 +342,7 @@
     the command. We do this so that the library api has continual pressure
     on it to be as functional as the command line in a simple manner, and
     to isolate knock-on effects throughout the blackbox test suite when a
-    command changes it name or signature. Ideally only the tests for a
+    command changes its name or signature. Ideally only the tests for a
     given command are affected when a given command is changed.
 
 Doctests
@@ -463,7 +467,7 @@
     that cannot be displayed.
   
   strict
-    Attempting to print and unprintable character will cause a UnicodeError.
+    Attempting to print an unprintable character will cause a UnicodeError.
     This is for commands that are intended more as scripting support, rather
     than plain user review.
     For exampl: ``bzr ls`` is designed to be used with shell scripting. One

=== modified file 'NEWS'
--- NEWS	2006-09-28 16:04:42 +0000
+++ NEWS	2006-10-11 00:23:23 +0000
@@ -3,12 +3,21 @@
   IMPROVEMENTS:
     * ``bzr help commands`` output is now shorter (Aaron Bentley)
 
+    * ``bzr`` now uses lazy importing to reduce the startup time. This has
+      a moderate effect on lots of actions, especially ones that have
+      little to do. For example ``bzr rocks`` time is down to 116ms from
+      283ms. (John Arbash Meinel)
+
   INTERNALS:
 
     * ``TestCase.run_bzr``, ``run_bzr_captured``, and ``run_bzr_subprocess``
       can take a ``working_dir='foo'`` parameter, which will change directory 
       for the command. (John Arbash Meinel)
 
+    * ``bzrlib.lazy_regex.lazy_compile`` can be used to create a proxy
+      around a regex, which defers compilation until first use. 
+      (John Arbash Meinel)
+
   BUG FIXES:
 
     * bzr branch/pull no longer complain about progress bar cleanup when
@@ -29,6 +38,19 @@
     * Leave HttpTransportBase daughter classes decides how they
       implement cloning. (Vincent Ladeuil, #61606)
 
+   * diff3 does not indicate conflicts on clean merge. (Aaron Bentley)
+
+  TESTING:
+
+    * New test base class TestCaseWithMemoryTransport offers memory-only
+      testing facilities: its not suitable for tests that need to mutate disk
+      state, but most tests should not need that and should be converted to
+      TestCaseWithMemoryTransport. (Robert Collins)
+
+bzr 0.11  2006-10-02
+
+    * Smart server transport test failures on windows fixed. (Lukáš Lalinský).
+
 bzr 0.11rc2  2006-09-27
 
   BUG FIXES:

=== modified file 'TODO'
--- TODO	2006-06-03 16:23:09 +0000
+++ TODO	2006-10-11 01:17:15 +0000
@@ -371,6 +371,11 @@
   This has been implemented, but it does not remove the texts from
   the store.
 
+* ``bzrlib.lazy_import.lazy_import`` could check to see if a given
+  module has already been imported (look at ``sys.modules``). If it
+  has, then just import it directly, rather than creating a lazy
+  object.
+
 
 Large things
 ------------

=== modified file 'bzr'
--- bzr	2006-10-05 05:37:25 +0000
+++ bzr	2006-10-16 01:25:46 +0000
@@ -32,7 +32,7 @@
 
 REINVOKE = "__BZR_REINVOKE"
 NEED_VERS = (2, 4)
-KNOWN_PYTHONS = ('python2.4',)
+KNOWN_PYTHONS = ('python2.4', 'python2.5')
 
 if version_info < NEED_VERS:
     if not os.environ.has_key(REINVOKE):
@@ -50,7 +50,6 @@
     os.unsetenv(REINVOKE)
 
 
-
 profiling = False
 if '--profile-imports' in sys.argv:
     sys.argv.remove('--profile-imports')
@@ -71,6 +70,9 @@
 import bzrlib.inspect_for_copy
 bzrlib.inspect_for_copy.import_copy_with_hacked_inspect()
 
+import bzrlib.lazy_regex
+bzrlib.lazy_regex.install_lazy_compile()
+
 import bzrlib.commands
 import bzrlib.trace
 

=== modified file 'bzrlib/annotate.py'
--- bzrlib/annotate.py	2006-10-11 23:08:27 +0000
+++ bzrlib/annotate.py	2006-10-16 01:25:46 +0000
@@ -29,7 +29,7 @@
 import time
 
 from bzrlib.config import extract_email_address
-from bzrlib.errors import BzrError
+from bzrlib.errors import NoEmailInUsername
 
 
 def annotate_file(branch, rev_id, file_id, verbose=False, full=False,
@@ -81,6 +81,6 @@
             author = rev.committer
             try:
                 author = extract_email_address(author)
-            except BzrError:
+            except NoEmailInUsername:
                 pass        # use the whole name
         yield (revno_str, author, date_str, origin, text)

=== modified file 'bzrlib/atomicfile.py'
--- bzrlib/atomicfile.py	2006-10-11 23:08:27 +0000
+++ bzrlib/atomicfile.py	2006-10-16 01:25:46 +0000
@@ -15,12 +15,13 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-import codecs
-import errno
 import os
+import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import stat
 import socket
-import sys
 import warnings
 
 from bzrlib import (
@@ -28,11 +29,11 @@
     osutils,
     symbol_versioning,
     )
-from bzrlib.osutils import rename
+""")
 
 # not forksafe - but we dont fork.
 _pid = os.getpid()
-_hostname = socket.gethostname()
+_hostname = None
 
 
 class AtomicFile(object):
@@ -47,10 +48,15 @@
     __slots__ = ['tmpfilename', 'realfilename', '_fd']
 
     def __init__(self, filename, mode='wb', new_mode=None):
+        global _hostname
+
         self._fd = None
         assert mode in ('wb', 'wt'), \
             "invalid AtomicFile mode %r" % mode
 
+        if _hostname is None:
+            _hostname = socket.gethostname()
+
         self.tmpfilename = '%s.%d.%s.tmp' % (filename, _pid, _hostname)
 
         self.realfilename = filename
@@ -102,7 +108,7 @@
     def commit(self):
         """Close the file and move to final name."""
         self._close_tmpfile('commit')
-        rename(self.tmpfilename, self.realfilename)
+        osutils.rename(self.tmpfilename, self.realfilename)
 
     def abort(self):
         """Discard temporary file without committing changes."""

=== modified file 'bzrlib/benchmarks/__init__.py'
--- bzrlib/benchmarks/__init__.py	2006-10-11 23:08:27 +0000
+++ bzrlib/benchmarks/__init__.py	2006-10-16 01:25:46 +0000
@@ -127,36 +127,22 @@
         creator = HeavilyMergedTreeCreator(self, link_bzr=hardlink)
         return creator.create(root=directory_name)
 
-    def create_with_commits(self, num_files, num_commits, directory_name='.'):
+    def create_with_commits(self, num_files, num_commits, directory_name='.',
+                            hardlink=False):
         """Create a tree with many files and many commits. Every commit changes
         exactly one file.
         
         :param num_files: number of files to be created
         :param num_commits: number of commits in the newly created tree
         """
-        files = ["%s/%s" % (directory_name, i) for i in range(num_files)]
-        for fn in files:
-            f = open(fn, "wb")
-            try:
-                f.write("some content\n")
-            finally:
-                f.close()
-        tree = bzrdir.BzrDir.create_standalone_workingtree(directory_name)
-        tree.add([str(i) for i in range(num_files)])
-        tree.lock_write()
-        try:
-            tree.commit('initial commit')
-            for i in range(num_commits):
-                fn = files[i % len(files)]
-                content = range(i) + [i, i, i, ""]
-                f = open(fn, "wb")
-                try:
-                    f.write("\n".join([str(i) for i in content]))
-                finally:
-                    f.close()
-                tree.commit("changing file %s" % fn)
-        finally:
-            tree.unlock()
+        from bzrlib.benchmarks.tree_creator.many_commit import (
+            ManyCommitTreeCreator,
+            )
+        creator = ManyCommitTreeCreator(self, link_bzr=hardlink,
+                                        num_files=num_files,
+                                        num_commits=num_commits)
+        tree = creator.create(root=directory_name)
+        files = ["%s/%s" % (directory_name, fn) for fn in creator.files]
         return tree, files
 
     def commit_some_revisions(self, tree, files, num_commits,
@@ -187,13 +173,16 @@
     testmod_names = [ \
                    'bzrlib.benchmarks.bench_add',
                    'bzrlib.benchmarks.bench_bench',
+                   'bzrlib.benchmarks.bench_bundle',
                    'bzrlib.benchmarks.bench_cache_utf8',
                    'bzrlib.benchmarks.bench_checkout',
                    'bzrlib.benchmarks.bench_commit',
+                   'bzrlib.benchmarks.bench_info',
                    'bzrlib.benchmarks.bench_inventory',
                    'bzrlib.benchmarks.bench_log',
                    'bzrlib.benchmarks.bench_osutils',
                    'bzrlib.benchmarks.bench_rocks',
+                   'bzrlib.benchmarks.bench_startup',
                    'bzrlib.benchmarks.bench_status',
                    'bzrlib.benchmarks.bench_transform',
                    'bzrlib.benchmarks.bench_workingtree',

=== added file 'bzrlib/benchmarks/bench_bundle.py'
--- bzrlib/benchmarks/bench_bundle.py	1970-01-01 00:00:00 +0000
+++ bzrlib/benchmarks/bench_bundle.py	2006-10-16 01:25:46 +0000
@@ -0,0 +1,306 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for bzr bundle performance."""
+
+from cStringIO import StringIO
+import os
+import shutil
+
+from bzrlib import bzrdir
+from bzrlib.add import smart_add
+from bzrlib.benchmarks import Benchmark
+from bzrlib.branch import Branch
+from bzrlib.bundle import read_bundle
+from bzrlib.bundle.apply_bundle import install_bundle
+from bzrlib.bundle.serializer import write_bundle
+from bzrlib.revision import NULL_REVISION
+from bzrlib.revisionspec import RevisionSpec
+from bzrlib.workingtree import WorkingTree
+
+
+class BundleBenchmark(Benchmark):
+    """Benchmarks for bzr bundle performance and bzr merge with a bundle."""
+   
+    def test_create_bundle_known_kernel_like_tree(self):
+        """Create a bundle for a kernel sized tree with no ignored, unknowns,
+        or added and one commit.
+        """ 
+        self.make_kernel_like_committed_tree()
+        self.time(self.run_bzr, 'bundle', '--revision', '..-1')
+
+    def test_create_bundle_many_commit_tree (self):
+        """Create a bundle for a tree with many commits but no changes.""" 
+        self.make_many_commit_tree()
+        self.time(self.run_bzr, 'bundle', '--revision', '..-1')
+
+    def test_create_bundle_heavily_merged_tree(self):
+        """Create a bundle for a heavily merged tree.""" 
+        self.make_heavily_merged_tree()
+        self.time(self.run_bzr, 'bundle', '--revision', '..-1')
+        
+    def test_apply_bundle_known_kernel_like_tree(self):
+        """Create a bundle for a kernel sized tree with no ignored, unknowns,
+        or added and one commit.
+        """ 
+        tree = self.make_kernel_like_committed_tree('tree')
+
+        f = open('bundle', 'wb')
+        try:
+            write_bundle(tree.branch.repository, tree.last_revision(),
+                         NULL_REVISION, f)
+        finally:
+            f.close()
+
+        tree2 = self.make_branch_and_tree('branch_a')
+        os.chdir('branch_a')
+        self.time(self.run_bzr, 'merge', '../bundle')
+ 
+class BundleLibraryLevelWriteBenchmark(Benchmark):
+    """ Benchmarks for the write_bundle library function. """
+
+    def _time_read_write(self):
+        print "timing"
+        branch, relpath = Branch.open_containing("a")
+        revision_history = branch.revision_history()
+        bundle_text = StringIO()
+        print "starting write bundle"
+        self.time(write_bundle, branch.repository, revision_history[-1],
+                  NULL_REVISION, bundle_text)
+        print "stopped writing bundle"
+        bundle_text.seek(0)
+        target_tree = self.make_branch_and_tree('b')
+        print "starting reading bundle"
+        bundle = self.time(read_bundle, bundle_text)
+        print "starting installing bundle"
+        self.time(install_bundle, target_tree.branch.repository, bundle)
+
+    def test_few_files_small_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(5, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 1, 1)
+        self._time_read_write()
+
+    def test_few_files_small_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(5, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 100, 1)
+        self._time_read_write()
+
+    def test_few_files_small_tree_1000_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(5, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 1000, 1)
+        self._time_read_write()
+
+    def test_few_files_moderate_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 1, 1)
+        self._time_read_write()
+
+    def test_few_files_moderate_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 100, 1)
+        self._time_read_write()
+
+    def test_few_files_moderate_tree_1000_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 1000, 1)
+        self._time_read_write()
+
+    def test_some_files_moderate_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 1, 1)
+        self._time_read_write()
+
+    def test_some_files_moderate_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 100, 1)
+        self._time_read_write()
+
+    def test_some_files_moderate_tree_1000_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 1000, 1)
+        self._time_read_write()
+
+    def test_few_files_big_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 1, 1)
+        self._time_read_write()
+
+    def test_few_files_big_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 100, 1)
+        self._time_read_write()
+
+    def test_few_files_big_tree_1000_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 1000, 1)
+        self._time_read_write()
+
+    def test_some_files_big_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 1, 1)
+        self._time_read_write()
+
+    def test_some_files_big_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 100, 1)
+        self._time_read_write()
+
+    def test_some_files_big_tree_1000_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 1000, 1)
+        self._time_read_write()
+
+    def test_many_files_big_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:1000], 1, 1)
+        self._time_read_write()
+
+    def test_many_files_big_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:1000], 100, 1)
+        self._time_read_write()
+
+    def test_many_files_big_tree_1000_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:1000], 1000, 1)
+        self._time_read_write()
+
+class BundleLibraryLevelInstallBenchmark(Benchmark):
+    """ Benchmarks for the install_bundle library function. """
+
+    def _time_read_write(self):
+        branch, relpath = Branch.open_containing("a")
+        revision_history = branch.revision_history()
+        bundle_text = StringIO()
+        write_bundle(branch.repository, revision_history[-1],
+                     NULL_REVISION, bundle_text)
+        bundle_text.seek(0)
+        target_tree = self.make_branch_and_tree('b')
+        bundle = self.time(read_bundle, bundle_text)
+        self.time(install_bundle, target_tree.branch.repository, bundle)
+
+    def test_few_files_small_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(5, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 1, 1)
+        self._time_read_write()
+
+    def test_few_files_small_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(5, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 100, 1)
+        self._time_read_write()
+
+    def test_few_files_moderate_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 1, 1)
+        self._time_read_write()
+
+    def test_few_files_moderate_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 100, 1)
+        self._time_read_write()
+
+    def test_some_files_moderate_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 1, 1)
+        self._time_read_write()
+
+    def test_some_files_moderate_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(100, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 100, 1)
+        self._time_read_write()
+
+    def test_few_files_big_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 1, 1)
+        self._time_read_write()
+
+    def test_few_files_big_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:5], 100, 1)
+        self._time_read_write()
+
+    def test_some_files_big_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 1, 1)
+        self._time_read_write()
+
+    def test_some_files_big_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:100], 100, 1)
+        self._time_read_write()
+
+    def test_many_files_big_tree_1_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:1000], 1, 1)
+        self._time_read_write()
+
+    def test_many_files_big_tree_100_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(1000, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:1000], 100, 1)
+        self._time_read_write()
+
+
+if __name__ == '__main__':
+    # USE the following if you want to regenerate the above test functions 
+    for treesize, treesize_h in [(5, "small"), (100, "moderate"),
+                                 (1000, "big")]:
+        for bundlefiles, bundlefiles_h in [(5, "few"), (100, "some"),
+                                           (1000, "many")]:
+            if bundlefiles > treesize:
+                continue
+            for num_revisions in [1, 100, 1000]:
+                code = """\
+    def test_%s_files_%s_tree_%s_revision(self):
+        os.mkdir("a")
+        tree, files = self.create_with_commits(%s, 1, directory_name="a")
+        self.commit_some_revisions(tree, files[:%s], %s, 1)
+        self._time_read_write()
+""" % (bundlefiles_h, treesize_h, num_revisions,
+       treesize, bundlefiles, num_revisions)
+                print code
+
+
+

=== added file 'bzrlib/benchmarks/bench_info.py'
--- bzrlib/benchmarks/bench_info.py	1970-01-01 00:00:00 +0000
+++ bzrlib/benchmarks/bench_info.py	2006-10-16 01:25:46 +0000
@@ -0,0 +1,37 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for bzr info performance."""
+
+
+from bzrlib.benchmarks import Benchmark
+
+
+class InfoBenchmark(Benchmark):
+    """This is a stub. Use this benchmark with a network transport.
+    Currently "bzr info sftp://..." takes > 4 min"""
+
+    def test_no_ignored_unknown_kernel_like_tree(self):
+        """Info in a kernel sized tree with no ignored or unknowns. """
+        self.make_kernel_like_added_tree()
+        self.time(self.run_bzr, 'info')
+
+    def test_no_changes_known_kernel_like_tree(self):
+        """Info in a kernel sized tree with no ignored, unknowns, or added.""" 
+        self.make_kernel_like_committed_tree()
+        self.time(self.run_bzr, 'info')
+
+     

=== modified file 'bzrlib/benchmarks/bench_rocks.py'
--- bzrlib/benchmarks/bench_rocks.py	2006-10-11 23:08:27 +0000
+++ bzrlib/benchmarks/bench_rocks.py	2006-10-16 01:25:46 +0000
@@ -14,7 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""Benchmarks of bzr commit."""
+"""Benchmarks of bzr rocks."""
 
 
 from bzrlib.benchmarks import Benchmark

=== added file 'bzrlib/benchmarks/bench_startup.py'
--- bzrlib/benchmarks/bench_startup.py	1970-01-01 00:00:00 +0000
+++ bzrlib/benchmarks/bench_startup.py	2006-10-16 01:25:46 +0000
@@ -0,0 +1,90 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Benchmarks of bzr startup time, for some simple operations."""
+
+
+from bzrlib.benchmarks import Benchmark
+
+
+class StartupBenchmark(Benchmark):
+
+    def make_simple_tree(self):
+        """A small, simple tree. No caching needed"""
+        tree = self.make_branch_and_tree('.')
+        self.build_tree(['a', 'b/', 'b/c'])
+        tree.add(['a', 'b', 'b/c'])
+        return tree
+
+    def make_simple_committed_tree(self):
+        tree = self.make_simple_tree()
+        tree.commit('simple commit')
+        return tree
+
+    def test___version(self):
+        """Test the startup overhead of plain bzr --version"""
+        self.time(self.run_bzr_subprocess, '--version')
+
+    def test_branch(self):
+        """Test the time to branch this into other"""
+        tree = self.make_simple_committed_tree()
+        self.time(self.run_bzr_subprocess, 'branch', '.', 'other')
+
+    def test_commit(self):
+        """Test execution of simple commit"""
+        tree = self.make_simple_tree()
+        self.time(self.run_bzr_subprocess, 'commit', '-m', 'init simple tree')
+
+    def test_diff(self):
+        """Test simple diff time"""
+        tree = self.make_simple_committed_tree()
+        self.time(self.run_bzr_subprocess, 'diff')
+
+    def test_help(self):
+        """Test the startup overhead of plain bzr help"""
+        self.time(self.run_bzr_subprocess, 'help')
+
+    def test_help_commands(self):
+        """startup time for bzr help commands, which has to load more"""
+        self.time(self.run_bzr_subprocess, 'help', 'commands')
+
+    def test_log(self):
+        """Test simple log time"""
+        tree = self.make_simple_committed_tree()
+        self.time(self.run_bzr_subprocess, 'log')
+
+    def test_missing(self):
+        """Test simple missing time"""
+        tree = self.make_simple_committed_tree()
+        other = tree.bzrdir.sprout('other')
+        self.time(self.run_bzr_subprocess, 'missing', working_dir='other')
+
+    def test_pull(self):
+        """Test simple pull time"""
+        tree = self.make_simple_committed_tree()
+        other = tree.bzrdir.sprout('other')
+        # There should be nothing to pull, and this should be determined
+        # quickly
+        self.time(self.run_bzr_subprocess, 'pull', working_dir='other')
+
+    def test_rocks(self):
+        """Test the startup overhead by running a do-nothing command"""
+        self.time(self.run_bzr_subprocess, 'rocks')
+
+    def test_status(self):
+        """Test simple status time"""
+        tree = self.make_simple_committed_tree()
+        self.time(self.run_bzr_subprocess, 'status')

=== modified file 'bzrlib/benchmarks/bench_status.py'
--- bzrlib/benchmarks/bench_status.py	2006-10-11 23:08:27 +0000
+++ bzrlib/benchmarks/bench_status.py	2006-10-16 01:25:46 +0000
@@ -35,3 +35,10 @@
         """Status in a kernel sized tree with no ignored, unknowns, or added.""" 
         self.make_kernel_like_committed_tree(link_bzr=True)
         self.time(self.run_bzr, 'status')
+
+    def test_single_file_no_changes_known_kernel_like_tree(self):
+        """Status in a kernel sized tree with no ignored, unknowns, or added
+        of a single file."""
+        self.make_kernel_like_committed_tree()
+        #XXX depends on the filenames generated by make_kernel_like_tree
+        self.time(self.run_bzr, 'status', '7/4/0/16')

=== added file 'bzrlib/benchmarks/tree_creator/many_commit.py'
--- bzrlib/benchmarks/tree_creator/many_commit.py	1970-01-01 00:00:00 +0000
+++ bzrlib/benchmarks/tree_creator/many_commit.py	2006-10-16 01:25:46 +0000
@@ -0,0 +1,68 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tree creator for many commits, including file changes."""
+
+from bzrlib import (
+    bzrdir,
+    )
+
+from bzrlib.benchmarks.tree_creator import TreeCreator
+
+
+class ManyCommitTreeCreator(TreeCreator):
+    """Create an tree many files and many commits."""
+
+    def __init__(self, test, link_bzr=False, num_files=10, num_commits=10):
+        tree_name = 'many_files_many_commit_tree_%d_%d' % (
+            num_files, num_commits)
+        super(ManyCommitTreeCreator, self).__init__(test,
+            tree_name=tree_name,
+            link_bzr=link_bzr,
+            link_working=False,
+            hot_cache=True)
+        self.files = ["%s" % (i, ) for i in range(num_files)]
+        self.num_files = num_files
+        self.num_commits = num_commits
+
+    def _create_tree(self, root, in_cache=False):
+        num_files = self.num_files
+        num_commits = self.num_commits
+        files = ["%s/%s" % (root, fn) for fn in self.files]
+        for fn in files:
+            f = open(fn, "wb")
+            try:
+                f.write("some content\n")
+            finally:
+                f.close()
+        tree = bzrdir.BzrDir.create_standalone_workingtree(root)
+        tree.add(self.files)
+        tree.lock_write()
+        try:
+            tree.commit('initial commit')
+            for i in range(num_commits):
+                fn = files[i % len(files)]
+                content = range(i) + [i, i, i, ""]
+                f = open(fn, "wb")
+                try:
+                    f.write("\n".join([str(i) for i in content]))
+                finally:
+                    f.close()
+                tree.commit("changing file %s" % fn)
+        finally:
+            tree.unlock()
+        return tree
+

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2006-09-17 21:03:04 +0000
+++ bzrlib/branch.py	2006-10-11 00:23:23 +0000
@@ -15,8 +15,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
+from cStringIO import StringIO
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 from copy import deepcopy
-from cStringIO import StringIO
 from unittest import TestSuite
 from warnings import warn
 
@@ -26,24 +29,26 @@
         cache_utf8,
         errors,
         lockdir,
+        lockable_files,
         osutils,
-        revision,
+        revision as _mod_revision,
         transport,
         tree,
         ui,
         urlutils,
         )
-from bzrlib.config import TreeConfig
+from bzrlib.config import BranchConfig, TreeConfig
+from bzrlib.lockable_files import LockableFiles, TransportLock
+""")
+
 from bzrlib.decorators import needs_read_lock, needs_write_lock
-import bzrlib.errors as errors
-from bzrlib.errors import (BzrError, BzrCheckError, DivergedBranches, 
-                           HistoryMissing, InvalidRevisionId, 
-                           InvalidRevisionNumber, LockError, NoSuchFile, 
+from bzrlib.errors import (BzrError, BzrCheckError, DivergedBranches,
+                           HistoryMissing, InvalidRevisionId,
+                           InvalidRevisionNumber, LockError, NoSuchFile,
                            NoSuchRevision, NoWorkingTree, NotVersionedError,
-                           NotBranchError, UninitializableFormat, 
-                           UnlistableStore, UnlistableBranch, 
+                           NotBranchError, UninitializableFormat,
+                           UnlistableStore, UnlistableBranch,
                            )
-from bzrlib.lockable_files import LockableFiles, TransportLock
 from bzrlib.symbol_versioning import (deprecated_function,
                                       deprecated_method,
                                       DEPRECATED_PARAMETER,
@@ -148,7 +153,7 @@
         pass
 
     def get_config(self):
-        return bzrlib.config.BranchConfig(self)
+        return BranchConfig(self)
 
     def _get_nick(self):
         return self.get_config().get_nickname()
@@ -222,7 +227,7 @@
                     last_revision = from_history[-1]
                 else:
                     # no history in the source branch
-                    last_revision = revision.NULL_REVISION
+                    last_revision = _mod_revision.NULL_REVISION
             return self.repository.fetch(from_branch.repository,
                                          revision_id=last_revision,
                                          pb=nested_pb)
@@ -729,8 +734,8 @@
         utf8_files = [('revision-history', ''),
                       ('branch-name', ''),
                       ]
-        control_files = LockableFiles(branch_transport, 'branch-lock',
-                                      TransportLock)
+        control_files = lockable_files.LockableFiles(branch_transport,
+                             'branch-lock', lockable_files.TransportLock)
         control_files.create_lock()
         control_files.lock_write()
         try:
@@ -790,7 +795,8 @@
         utf8_files = [('revision-history', ''),
                       ('branch-name', ''),
                       ]
-        control_files = LockableFiles(branch_transport, 'lock', lockdir.LockDir)
+        control_files = lockable_files.LockableFiles(branch_transport, 'lock',
+                                                     lockdir.LockDir)
         control_files.create_lock()
         control_files.lock_write()
         control_files.put_utf8('format', self.get_format_string())
@@ -815,7 +821,8 @@
             format = BranchFormat.find_format(a_bzrdir)
             assert format.__class__ == self.__class__
         transport = a_bzrdir.get_branch_transport(None)
-        control_files = LockableFiles(transport, 'lock', lockdir.LockDir)
+        control_files = lockable_files.LockableFiles(transport, 'lock',
+                                                     lockdir.LockDir)
         return BzrBranch5(_format=self,
                           _control_files=control_files,
                           a_bzrdir=a_bzrdir,
@@ -1129,7 +1136,7 @@
         # make a new revision history from the graph
         current_rev_id = revision_id
         new_history = []
-        while current_rev_id not in (None, revision.NULL_REVISION):
+        while current_rev_id not in (None, _mod_revision.NULL_REVISION):
             new_history.append(current_rev_id)
             current_rev_id_parents = stop_graph[current_rev_id]
             try:

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-10-11 23:08:27 +0000
+++ bzrlib/builtins.py	2006-10-16 01:25:46 +0000
@@ -16,11 +16,12 @@
 
 """builtin bzr commands"""
 
+import os
 
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import codecs
 import errno
-import os
-import os.path
 import sys
 
 import bzrlib
@@ -32,38 +33,34 @@
     errors,
     ignores,
     log,
+    merge as _mod_merge,
     osutils,
     repository,
     transport,
+    tree as _mod_tree,
     ui,
     urlutils,
     )
-from bzrlib.branch import Branch, BranchReferenceFormat
-from bzrlib.bundle import read_bundle_from_url
+from bzrlib.branch import Branch
 from bzrlib.bundle.apply_bundle import install_bundle, merge_bundle
 from bzrlib.conflicts import ConflictList
+from bzrlib.revision import common_ancestor
+from bzrlib.revisionspec import RevisionSpec
+from bzrlib.workingtree import WorkingTree
+""")
+
 from bzrlib.commands import Command, display_command
-from bzrlib.errors import (BzrError, BzrCheckError, BzrCommandError, 
-                           NotBranchError, DivergedBranches, NotConflicted,
-                           NoSuchFile, NoWorkingTree, FileInWrongBranch,
-                           NotVersionedError, NotABundle)
-from bzrlib.merge import Merge3Merger
 from bzrlib.option import Option
 from bzrlib.progress import DummyProgress, ProgressPhase
-from bzrlib.revision import common_ancestor
-from bzrlib.revisionspec import RevisionSpec
 from bzrlib.trace import mutter, note, log_error, warning, is_quiet, info
-from bzrlib.transport.local import LocalTransport
-import bzrlib.tree
-from bzrlib.workingtree import WorkingTree
 
 
 def tree_files(file_list, default_branch=u'.'):
     try:
         return internal_tree_files(file_list, default_branch)
-    except FileInWrongBranch, e:
-        raise BzrCommandError("%s is not in the same branch as %s" %
-                             (e.path, file_list[0]))
+    except errors.FileInWrongBranch, e:
+        raise errors.BzrCommandError("%s is not in the same branch as %s" %
+                                     (e.path, file_list[0]))
 
 
 # XXX: Bad function name; should possibly also be a class method of
@@ -90,7 +87,7 @@
         try:
             new_list.append(tree.relpath(filename))
         except errors.PathNotChild:
-            raise FileInWrongBranch(tree.branch, filename)
+            raise errors.FileInWrongBranch(tree.branch, filename)
     return tree, new_list
 
 
@@ -114,7 +111,7 @@
         return format
     msg = "Unknown bzr format %s. Current formats are: default, knit,\n" \
           "metaweave and weave" % typestring
-    raise BzrCommandError(msg)
+    raise errors.BzrCommandError(msg)
 
 
 # TODO: Make sure no commands unconditionally use the working directory as a
@@ -195,9 +192,11 @@
     def run(self, revision_id=None, revision=None):
 
         if revision_id is not None and revision is not None:
-            raise BzrCommandError('You can only supply one of revision_id or --revision')
+            raise errors.BzrCommandError('You can only supply one of'
+                                         ' revision_id or --revision')
         if revision_id is None and revision is None:
-            raise BzrCommandError('You must supply either --revision or a revision_id')
+            raise errors.BzrCommandError('You must supply either'
+                                         ' --revision or a revision_id')
         b = WorkingTree.open_containing(u'.')[0].branch
 
         # TODO: jam 20060112 should cat-revision always output utf-8?
@@ -206,7 +205,8 @@
         elif revision is not None:
             for rev in revision:
                 if rev is None:
-                    raise BzrCommandError('You cannot specify a NULL revision.')
+                    raise errors.BzrCommandError('You cannot specify a NULL'
+                                                 ' revision.')
                 revno, rev_id = rev.in_history(b)
                 self.outf.write(b.repository.get_revision_xml(rev_id).decode('utf-8'))
     
@@ -242,7 +242,7 @@
             for rev in revision_info_list:
                 revs.append(RevisionSpec.from_string(rev))
         if len(revs) == 0:
-            raise BzrCommandError('You must supply a revision identifier')
+            raise errors.BzrCommandError('You must supply a revision identifier')
 
         b = WorkingTree.open_containing(u'.')[0].branch
 
@@ -299,7 +299,7 @@
                 base_tree, base_path = WorkingTree.open_containing(
                                             file_ids_from)
             except errors.NoWorkingTree:
-                base_branch, base_path = branch.Branch.open_containing(
+                base_branch, base_path = Branch.open_containing(
                                             file_ids_from)
                 base_tree = base_branch.basis_tree()
 
@@ -374,14 +374,14 @@
     @display_command
     def run(self, revision=None, show_ids=False, kind=None, file_list=None):
         if kind and kind not in ['file', 'directory', 'symlink']:
-            raise BzrCommandError('invalid kind specified')
+            raise errors.BzrCommandError('invalid kind specified')
 
         work_tree, file_list = tree_files(file_list)
 
         if revision is not None:
             if len(revision) > 1:
-                raise BzrCommandError('bzr inventory --revision takes'
-                                      ' exactly one revision identifier')
+                raise errors.BzrCommandError('bzr inventory --revision takes'
+                                             ' exactly one revision identifier')
             revision_id = revision[0].in_history(work_tree.branch).rev_id
             tree = work_tree.branch.repository.revision_tree(revision_id)
                         
@@ -395,7 +395,7 @@
             trees = [tree]
 
         if file_list is not None:
-            file_ids = bzrlib.tree.find_ids_across_trees(file_list, trees,
+            file_ids = _mod_tree.find_ids_across_trees(file_list, trees,
                                                       require_versioned=True)
             # find_ids_across_trees may include some paths that don't
             # exist in 'tree'.
@@ -437,7 +437,7 @@
             names_list = []
 
         if len(names_list) < 2:
-            raise BzrCommandError("missing file argument")
+            raise errors.BzrCommandError("missing file argument")
         tree, rel_names = tree_files(names_list)
         
         if os.path.isdir(names_list[-1]):
@@ -446,8 +446,8 @@
                 self.outf.write("%s => %s\n" % pair)
         else:
             if len(names_list) != 2:
-                raise BzrCommandError('to mv multiple files the destination '
-                                      'must be a versioned directory')
+                raise errors.BzrCommandError('to mv multiple files the destination '
+                                             'must be a versioned directory')
             tree.rename_one(rel_names[0], rel_names[1])
             self.outf.write("%s => %s\n" % (rel_names[0], rel_names[1]))
             
@@ -481,7 +481,7 @@
         try:
             tree_to = WorkingTree.open_containing(u'.')[0]
             branch_to = tree_to.branch
-        except NoWorkingTree:
+        except errors.NoWorkingTree:
             tree_to = None
             branch_to = Branch.open_containing(u'.')[0]
 
@@ -489,13 +489,14 @@
         if location is not None:
             try:
                 reader = bundle.read_bundle_from_url(location)
-            except NotABundle:
+            except errors.NotABundle:
                 pass # Continue on considering this url a Branch
 
         stored_loc = branch_to.get_parent()
         if location is None:
             if stored_loc is None:
-                raise BzrCommandError("No pull location known or specified.")
+                raise errors.BzrCommandError("No pull location known or"
+                                             " specified.")
             else:
                 display_url = urlutils.unescape_for_display(stored_loc,
                         self.outf.encoding)
@@ -519,7 +520,7 @@
         elif len(revision) == 1:
             rev_id = revision[0].in_history(branch_from).rev_id
         else:
-            raise BzrCommandError('bzr pull --revision takes one value.')
+            raise errors.BzrCommandError('bzr pull --revision takes one value.')
 
         old_rh = branch_to.revision_history()
         if tree_to is not None:
@@ -579,7 +580,7 @@
         stored_loc = br_from.get_push_location()
         if location is None:
             if stored_loc is None:
-                raise BzrCommandError("No push location known or specified.")
+                raise errors.BzrCommandError("No push location known or specified.")
             else:
                 display_url = urlutils.unescape_for_display(stored_loc,
                         self.outf.encoding)
@@ -593,7 +594,7 @@
         try:
             dir_to = bzrdir.BzrDir.open(location_url)
             br_to = dir_to.open_branch()
-        except NotBranchError:
+        except errors.NotBranchError:
             # create a branch.
             to_transport = to_transport.clone('..')
             if not create_prefix:
@@ -601,9 +602,9 @@
                     relurl = to_transport.relpath(location_url)
                     mutter('creating directory %s => %s', location_url, relurl)
                     to_transport.mkdir(relurl)
-                except NoSuchFile:
-                    raise BzrCommandError("Parent directory of %s "
-                                          "does not exist." % location)
+                except errors.NoSuchFile:
+                    raise errors.BzrCommandError("Parent directory of %s "
+                                                 "does not exist." % location)
             else:
                 current = to_transport.base
                 needed = [(to_transport, to_transport.relpath(location_url))]
@@ -612,13 +613,13 @@
                         to_transport, relpath = needed[-1]
                         to_transport.mkdir(relpath)
                         needed.pop()
-                    except NoSuchFile:
+                    except errors.NoSuchFile:
                         new_transport = to_transport.clone('..')
                         needed.append((new_transport,
                                        new_transport.relpath(to_transport.base)))
                         if new_transport.base == to_transport.base:
-                            raise BzrCommandError("Could not create "
-                                                  "path prefix.")
+                            raise errors.BzrCommandError("Could not create "
+                                                         "path prefix.")
             dir_to = br_from.bzrdir.clone(location_url,
                 revision_id=br_from.last_revision())
             br_to = dir_to.open_branch()
@@ -639,13 +640,13 @@
                     warning('This transport does not update the working '
                             'tree of: %s' % (br_to.base,))
                     count = br_to.pull(br_from, overwrite)
-                except NoWorkingTree:
+                except errors.NoWorkingTree:
                     count = br_to.pull(br_from, overwrite)
                 else:
                     count = tree_to.pull(br_from, overwrite)
-            except DivergedBranches:
-                raise BzrCommandError("These branches have diverged."
-                                      "  Try a merge then push with overwrite.")
+            except errors.DivergedBranches:
+                raise errors.BzrCommandError('These branches have diverged.'
+                                        '  Try using "merge" and then "push".')
         note('%d revision(s) pushed.' % (count,))
 
         if verbose:
@@ -678,14 +679,14 @@
         if revision is None:
             revision = [None]
         elif len(revision) > 1:
-            raise BzrCommandError(
+            raise errors.BzrCommandError(
                 'bzr branch --revision takes exactly 1 revision value')
         try:
             br_from = Branch.open(from_location)
         except OSError, e:
             if e.errno == errno.ENOENT:
-                raise BzrCommandError('Source location "%s" does not'
-                                      ' exist.' % to_location)
+                raise errors.BzrCommandError('Source location "%s" does not'
+                                             ' exist.' % to_location)
             else:
                 raise
         br_from.lock_read()
@@ -711,11 +712,11 @@
             try:
                 to_transport.mkdir('.')
             except errors.FileExists:
-                raise BzrCommandError('Target directory "%s" already'
-                                      ' exists.' % to_location)
+                raise errors.BzrCommandError('Target directory "%s" already'
+                                             ' exists.' % to_location)
             except errors.NoSuchFile:
-                raise BzrCommandError('Parent of "%s" does not exist.' %
-                                      to_location)
+                raise errors.BzrCommandError('Parent of "%s" does not exist.'
+                                             % to_location)
             try:
                 # preserve whatever source format we have.
                 dir = br_from.bzrdir.sprout(to_transport.base,
@@ -724,11 +725,11 @@
             except errors.NoSuchRevision:
                 to_transport.delete_tree('.')
                 msg = "The branch %s has no revision %s." % (from_location, revision[0])
-                raise BzrCommandError(msg)
+                raise errors.BzrCommandError(msg)
             except errors.UnlistableBranch:
                 osutils.rmtree(to_location)
                 msg = "The branch %s cannot be used as a --basis" % (basis,)
-                raise BzrCommandError(msg)
+                raise errors.BzrCommandError(msg)
             if name:
                 branch.control_files.put_utf8('branch-name', name)
             note('Branched %d revision(s).' % branch.revno())
@@ -773,7 +774,7 @@
         if revision is None:
             revision = [None]
         elif len(revision) > 1:
-            raise BzrCommandError(
+            raise errors.BzrCommandError(
                 'bzr checkout --revision takes exactly 1 revision value')
         if branch_location is None:
             branch_location = osutils.getcwd()
@@ -799,11 +800,11 @@
             os.mkdir(to_location)
         except OSError, e:
             if e.errno == errno.EEXIST:
-                raise BzrCommandError('Target directory "%s" already'
-                                      ' exists.' % to_location)
+                raise errors.BzrCommandError('Target directory "%s" already'
+                                             ' exists.' % to_location)
             if e.errno == errno.ENOENT:
-                raise BzrCommandError('Parent of "%s" does not exist.' %
-                                      to_location)
+                raise errors.BzrCommandError('Parent of "%s" does not exist.'
+                                             % to_location)
             else:
                 raise
         old_format = bzrdir.BzrDirFormat.get_default_format()
@@ -824,11 +825,10 @@
 
     @display_command
     def run(self, dir=u'.'):
-        from bzrlib.tree import find_renames
         tree = WorkingTree.open_containing(dir)[0]
         old_inv = tree.basis_tree().inventory
         new_inv = tree.read_working_inventory()
-        renames = list(find_renames(old_inv, new_inv))
+        renames = list(_mod_tree.find_renames(old_inv, new_inv))
         renames.sort()
         for old_name, new_name in renames:
             self.outf.write("%s => %s\n" % (old_name, new_name))
@@ -913,14 +913,14 @@
         tree, file_list = tree_files(file_list)
         if new is False:
             if file_list is None:
-                raise BzrCommandError('Specify one or more files to remove, or'
-                                      ' use --new.')
+                raise errors.BzrCommandError('Specify one or more files to'
+                                             ' remove, or use --new.')
         else:
             added = tree.changes_from(tree.basis_tree(),
                 specific_files=file_list).added
             file_list = sorted([f[0] for f in added], reverse=True)
             if len(file_list) == 0:
-                raise BzrCommandError('No matching files.')
+                raise errors.BzrCommandError('No matching files.')
         tree.remove(file_list, verbose=verbose, to_file=self.outf)
 
 
@@ -940,7 +940,7 @@
         tree, relpath = WorkingTree.open_containing(filename)
         i = tree.inventory.path2id(relpath)
         if i is None:
-            raise BzrError("%r is not a versioned file" % filename)
+            raise errors.BzrError("%r is not a versioned file" % filename)
         else:
             self.outf.write(i + '\n')
 
@@ -961,7 +961,7 @@
         inv = tree.inventory
         fid = inv.path2id(relpath)
         if fid is None:
-            raise BzrError("%r is not a versioned file" % filename)
+            raise errors.BzrError("%r is not a versioned file" % filename)
         for fip in inv.get_idpath(fid):
             self.outf.write(fip + '\n')
 
@@ -1081,10 +1081,11 @@
                     
         try:
             existing_bzrdir = bzrdir.BzrDir.open(location)
-        except NotBranchError:
+        except errors.NotBranchError:
             # really a NotBzrDir error...
             bzrdir.BzrDir.create_branch_convenience(location, format=format)
         else:
+            from bzrlib.transport.local import LocalTransport
             if existing_bzrdir.has_branch():
                 if (isinstance(to_transport, LocalTransport)
                     and not existing_bzrdir.has_workingtree()):
@@ -1191,7 +1192,8 @@
             new_label = 'new/'
         else:
             if not ':' in prefix:
-                 raise BzrError("--diff-prefix expects two values separated by a colon")
+                 raise errors.BzrError("--diff-prefix expects two values"
+                                       " separated by a colon")
             old_label, new_label = prefix.split(":")
         
         try:
@@ -1199,17 +1201,17 @@
             tree2 = None
             b = None
             b2 = None
-        except FileInWrongBranch:
+        except errors.FileInWrongBranch:
             if len(file_list) != 2:
-                raise BzrCommandError("Files are in different branches")
+                raise errors.BzrCommandError("Files are in different branches")
 
             tree1, file1 = WorkingTree.open_containing(file_list[0])
             tree2, file2 = WorkingTree.open_containing(file_list[1])
             if file1 != "" or file2 != "":
                 # FIXME diff those two files. rbc 20051123
-                raise BzrCommandError("Files are in different branches")
+                raise errors.BzrCommandError("Files are in different branches")
             file_list = None
-        except NotBranchError:
+        except errors.NotBranchError:
             if (revision is not None and len(revision) == 2
                 and not revision[0].needs_branch()
                 and not revision[1].needs_branch()):
@@ -1220,7 +1222,7 @@
                 raise
         if revision is not None:
             if tree2 is not None:
-                raise BzrCommandError("Can't specify -r with two branches")
+                raise errors.BzrCommandError("Can't specify -r with two branches")
             if (len(revision) == 1) or (revision[1].spec is None):
                 return diff_cmd_helper(tree1, file_list, diff_options,
                                        revision[0], 
@@ -1230,7 +1232,8 @@
                                        revision[0], revision[1],
                                        old_label=old_label, new_label=new_label)
             else:
-                raise BzrCommandError('bzr diff --revision takes exactly one or two revision identifiers')
+                raise errors.BzrCommandError('bzr diff --revision takes exactly'
+                                             ' one or two revision identifiers')
         else:
             if tree2 is not None:
                 return show_diff_trees(tree1, tree2, sys.stdout, 
@@ -1392,7 +1395,7 @@
                 # b is taken from revision[0].get_branch(), and
                 # show_log will use its revision_history. Having
                 # different branches will lead to weird behaviors.
-                raise BzrCommandError(
+                raise errors.BzrCommandError(
                     "Log doesn't accept two revisions in different branches.")
             if revision[0].spec is None:
                 # missing begin-range means first revision
@@ -1406,7 +1409,7 @@
             else:
                 rev2 = revision[1].in_history(b).revno
         else:
-            raise BzrCommandError('bzr log --revision takes one or two values.')
+            raise errors.BzrCommandError('bzr log --revision takes one or two values.')
 
         # By this point, the revision numbers are converted to the +ve
         # form if they were supplied in the -ve form, so we can do
@@ -1486,7 +1489,7 @@
             null=False):
 
         if verbose and null:
-            raise BzrCommandError('Cannot set both --verbose and --null')
+            raise errors.BzrCommandError('Cannot set both --verbose and --null')
         all = not (unknown or versioned or ignored)
 
         selection = {'I':ignored, '?':unknown, 'V':versioned}
@@ -1558,7 +1561,7 @@
                 print pattern
             return
         if name_pattern is None:
-            raise BzrCommandError("ignore requires a NAME_PATTERN")
+            raise errors.BzrCommandError("ignore requires a NAME_PATTERN")
         tree, relpath = WorkingTree.open_containing(u'.')
         ifn = tree.abspath('.bzrignore')
         if os.path.exists(ifn):
@@ -1621,7 +1624,7 @@
         try:
             revno = int(revno)
         except ValueError:
-            raise BzrCommandError("not a valid revision-number: %r" % revno)
+            raise errors.BzrCommandError("not a valid revision-number: %r" % revno)
 
         print WorkingTree.open_containing(u'.')[0].branch.get_rev_id(revno)
 
@@ -1659,13 +1662,14 @@
             rev_id = b.last_revision()
         else:
             if len(revision) != 1:
-                raise BzrError('bzr export --revision takes exactly 1 argument')
+                raise errors.BzrError('bzr export --revision takes exactly'
+                                      ' 1 argument')
             rev_id = revision[0].in_history(b).rev_id
         t = b.repository.revision_tree(rev_id)
         try:
             export(t, dest, format, root)
         except errors.NoSuchExportFormat, e:
-            raise BzrCommandError('Unsupported export format: %s' % e.format)
+            raise errors.BzrCommandError('Unsupported export format: %s' % e.format)
 
 
 class cmd_cat(Command):
@@ -1677,12 +1681,12 @@
     @display_command
     def run(self, filename, revision=None):
         if revision is not None and len(revision) != 1:
-            raise BzrCommandError("bzr cat --revision takes exactly one number")
+            raise errors.BzrCommandError("bzr cat --revision takes exactly one number")
         tree = None
         try:
             tree, relpath = WorkingTree.open_containing(filename)
             b = tree.branch
-        except NotBranchError:
+        except errors.NotBranchError:
             pass
 
         if tree is None:
@@ -1776,16 +1780,16 @@
             template = make_commit_message_template(tree, selected_list)
             message = edit_commit_message(template)
             if message is None:
-                raise BzrCommandError("please specify a commit message"
-                                      " with either --message or --file")
+                raise errors.BzrCommandError("please specify a commit message"
+                                             " with either --message or --file")
         elif message and file:
-            raise BzrCommandError("please specify either --message or --file")
+            raise errors.BzrCommandError("please specify either --message or --file")
         
         if file:
             message = codecs.open(file, 'rt', bzrlib.user_encoding).read()
 
         if message == "":
-            raise BzrCommandError("empty commit message specified")
+            raise errors.BzrCommandError("empty commit message specified")
         
         if verbose:
             reporter = ReportCommitToLog()
@@ -1799,16 +1803,16 @@
         except PointlessCommit:
             # FIXME: This should really happen before the file is read in;
             # perhaps prepare the commit; get the message; then actually commit
-            raise BzrCommandError("no changes to commit."
-                                  " use --unchanged to commit anyhow")
+            raise errors.BzrCommandError("no changes to commit."
+                                         " use --unchanged to commit anyhow")
         except ConflictsInTree:
-            raise BzrCommandError("Conflicts detected in working tree.  "
+            raise errors.BzrCommandError("Conflicts detected in working tree.  "
                 'Use "bzr conflicts" to list, "bzr resolve FILE" to resolve.')
         except StrictCommitFailed:
-            raise BzrCommandError("Commit refused because there are unknown "
-                                  "files in the working tree.")
+            raise errors.BzrCommandError("Commit refused because there are unknown "
+                                         "files in the working tree.")
         except errors.BoundBranchOutOfDate, e:
-            raise BzrCommandError(str(e) + "\n"
+            raise errors.BzrCommandError(str(e) + "\n"
                 'To commit to master branch, run update and then commit.\n'
                 'You can also pass --local to commit to continue working '
                 'disconnected.')
@@ -1898,7 +1902,7 @@
             # use branch if we're inside one; otherwise global config
             try:
                 c = Branch.open_containing('.')[0].get_config()
-            except NotBranchError:
+            except errors.NotBranchError:
                 c = config.GlobalConfig()
             if email:
                 self.outf.write(c.user_email() + '\n')
@@ -1909,7 +1913,7 @@
         # display a warning if an email address isn't included in the given name.
         try:
             config.extract_email_address(name)
-        except BzrError, e:
+        except errors.NoEmailInUsername, e:
             warning('"%s" does not seem to contain an email address.  '
                     'This is allowed, but not recommended.', name)
         
@@ -1977,7 +1981,7 @@
             return FakeNFSServer
         msg = "No known transport type %s. Supported types are: sftp\n" %\
             (typestring)
-        raise BzrCommandError(msg)
+        raise errors.BzrCommandError(msg)
 
     hidden = True
     takes_args = ['testspecs*']
@@ -2082,7 +2086,7 @@
     
     @display_command
     def run(self, branch, other):
-        from bzrlib.revision import common_ancestor, MultipleRevisionSources
+        from bzrlib.revision import MultipleRevisionSources
         
         branch1 = Branch.open_containing(branch)[0]
         branch2 = Branch.open_containing(other)[0]
@@ -2150,22 +2154,21 @@
                             ' from a working copy, instead of branch changes')]
 
     def help(self):
-        from merge import merge_type_help
         from inspect import getdoc
-        return getdoc(self) + '\n' + merge_type_help() 
+        return getdoc(self) + '\n' + _mod_merge.merge_type_help()
 
     def run(self, branch=None, revision=None, force=False, merge_type=None,
             show_base=False, reprocess=False, remember=False, 
             uncommitted=False):
         if merge_type is None:
-            merge_type = Merge3Merger
+            merge_type = _mod_merge.Merge3Merger
 
         tree = WorkingTree.open_containing(u'.')[0]
 
         if branch is not None:
             try:
                 reader = bundle.read_bundle_from_url(branch)
-            except NotABundle:
+            except errors.NotABundle:
                 pass # Continue on considering this url a Branch
             else:
                 conflicts = merge_bundle(reader, tree, not force, merge_type,
@@ -2189,8 +2192,8 @@
             other_branch, path = Branch.open_containing(branch)
         else:
             if uncommitted:
-                raise BzrCommandError('Cannot use --uncommitted and --revision'
-                                      ' at the same time.')
+                raise errors.BzrCommandError('Cannot use --uncommitted and'
+                                             ' --revision at the same time.')
             branch = revision[0].get_branch() or branch
             if len(revision) == 1:
                 base = [None, None]
@@ -2200,7 +2203,7 @@
             else:
                 assert len(revision) == 2
                 if None in revision:
-                    raise BzrCommandError(
+                    raise errors.BzrCommandError(
                         "Merge doesn't permit empty revision specifier.")
                 base_branch, path = Branch.open_containing(branch)
                 branch1 = revision[1].get_branch() or branch
@@ -2222,11 +2225,12 @@
         pb = ui.ui_factory.nested_progress_bar()
         try:
             try:
-                conflict_count = merge(other, base, check_clean=(not force),
-                                       merge_type=merge_type,
-                                       reprocess=reprocess,
-                                       show_base=show_base,
-                                       pb=pb, file_list=interesting_files)
+                conflict_count = _merge_helper(
+                    other, base, check_clean=(not force),
+                    merge_type=merge_type,
+                    reprocess=reprocess,
+                    show_base=show_base,
+                    pb=pb, file_list=interesting_files)
             finally:
                 pb.finished()
             if conflict_count != 0:
@@ -2253,7 +2257,7 @@
         stored_location = tree.branch.get_parent()
         mutter("%s", stored_location)
         if stored_location is None:
-            raise BzrCommandError("No location specified or remembered")
+            raise errors.BzrCommandError("No location specified or remembered")
         display_url = urlutils.unescape_for_display(stored_location, self.outf.encoding)
         self.outf.write("%s remembered location %s\n" % (verb_string, display_url))
         return stored_location
@@ -2286,23 +2290,21 @@
                             "conflicts")]
 
     def help(self):
-        from merge import merge_type_help
         from inspect import getdoc
-        return getdoc(self) + '\n' + merge_type_help() 
+        return getdoc(self) + '\n' + _mod_merge.merge_type_help()
 
     def run(self, file_list=None, merge_type=None, show_base=False,
             reprocess=False):
-        from bzrlib.merge import merge_inner, transform_tree
         if merge_type is None:
-            merge_type = Merge3Merger
+            merge_type = _mod_merge.Merge3Merger
         tree, file_list = tree_files(file_list)
         tree.lock_write()
         try:
             parents = tree.get_parent_ids()
             if len(parents) != 2:
-                raise BzrCommandError("Sorry, remerge only works after normal"
-                                      " merges.  Not cherrypicking or"
-                                      " multi-merges.")
+                raise errors.BzrCommandError("Sorry, remerge only works after normal"
+                                             " merges.  Not cherrypicking or"
+                                             " multi-merges.")
             repository = tree.branch.repository
             base_revision = common_ancestor(parents[0],
                                             parents[1], repository)
@@ -2316,7 +2318,7 @@
                 for filename in file_list:
                     file_id = tree.path2id(filename)
                     if file_id is None:
-                        raise NotVersionedError(filename)
+                        raise errors.NotVersionedError(filename)
                     interesting_ids.add(file_id)
                     if tree.kind(file_id) != "directory":
                         continue
@@ -2324,7 +2326,7 @@
                     for name, ie in tree.inventory.iter_entries(file_id):
                         interesting_ids.add(ie.file_id)
                 new_conflicts = conflicts.select_conflicts(tree, file_list)[0]
-            transform_tree(tree, tree.basis_tree(), interesting_ids)
+            _mod_merge.transform_tree(tree, tree.basis_tree(), interesting_ids)
             tree.set_conflicts(ConflictList(new_conflicts))
             if file_list is None:
                 restore_files = list(tree.iter_conflicts())
@@ -2333,15 +2335,16 @@
             for filename in restore_files:
                 try:
                     restore(tree.abspath(filename))
-                except NotConflicted:
+                except errors.NotConflicted:
                     pass
-            conflicts = merge_inner(tree.branch, other_tree, base_tree,
-                                    this_tree=tree,
-                                    interesting_ids=interesting_ids,
-                                    other_rev_id=parents[1],
-                                    merge_type=merge_type,
-                                    show_base=show_base,
-                                    reprocess=reprocess)
+            conflicts = _mod_merge.merge_inner(
+                                      tree.branch, other_tree, base_tree,
+                                      this_tree=tree,
+                                      interesting_ids=interesting_ids,
+                                      other_rev_id=parents[1],
+                                      merge_type=merge_type,
+                                      show_base=show_base,
+                                      reprocess=reprocess)
         finally:
             tree.unlock()
         if conflicts > 0:
@@ -2375,10 +2378,9 @@
     aliases = ['merge-revert']
 
     def run(self, revision=None, no_backup=False, file_list=None):
-        from bzrlib.commands import parse_spec
         if file_list is not None:
             if len(file_list) == 0:
-                raise BzrCommandError("No files specified")
+                raise errors.BzrCommandError("No files specified")
         else:
             file_list = []
         
@@ -2387,7 +2389,7 @@
             # FIXME should be tree.last_revision
             rev_id = tree.last_revision()
         elif len(revision) != 1:
-            raise BzrCommandError('bzr revert --revision takes exactly 1 argument')
+            raise errors.BzrCommandError('bzr revert --revision takes exactly 1 argument')
         else:
             rev_id = revision[0].in_history(tree.branch).rev_id
         pb = ui.ui_factory.nested_progress_bar()
@@ -2479,7 +2481,7 @@
         if other_branch is None:
             other_branch = parent
             if other_branch is None:
-                raise BzrCommandError("No peer location known or specified.")
+                raise errors.BzrCommandError("No peer location known or specified.")
             print "Using last location: " + local_branch.get_parent()
         remote_branch = Branch.open(other_branch)
         if remote_branch.base == local_branch.base:
@@ -2614,7 +2616,7 @@
             if revision is None:
                 revision_id = branch.last_revision()
             elif len(revision) != 1:
-                raise BzrCommandError('bzr annotate --revision takes exactly 1 argument')
+                raise errors.BzrCommandError('bzr annotate --revision takes exactly 1 argument')
             else:
                 revision_id = revision[0].in_history(branch).rev_id
             file_id = tree.inventory.path2id(relpath)
@@ -2636,9 +2638,9 @@
     def run(self, revision_id_list=None, revision=None):
         import bzrlib.gpg as gpg
         if revision_id_list is not None and revision is not None:
-            raise BzrCommandError('You can only supply one of revision_id or --revision')
+            raise errors.BzrCommandError('You can only supply one of revision_id or --revision')
         if revision_id_list is None and revision is None:
-            raise BzrCommandError('You must supply either --revision or a revision_id')
+            raise errors.BzrCommandError('You must supply either --revision or a revision_id')
         b = WorkingTree.open_containing(u'.')[0].branch
         gpg_strategy = gpg.GPGStrategy(b.get_config())
         if revision_id_list is not None:
@@ -2657,12 +2659,12 @@
                 if to_revid is None:
                     to_revno = b.revno()
                 if from_revno is None or to_revno is None:
-                    raise BzrCommandError('Cannot sign a range of non-revision-history revisions')
+                    raise errors.BzrCommandError('Cannot sign a range of non-revision-history revisions')
                 for revno in range(from_revno, to_revno + 1):
                     b.repository.sign_revision(b.get_rev_id(revno), 
                                                gpg_strategy)
             else:
-                raise BzrCommandError('Please supply either one revision, or a range.')
+                raise errors.BzrCommandError('Please supply either one revision, or a range.')
 
 
 class cmd_bind(Command):
@@ -2680,9 +2682,9 @@
         b_other = Branch.open(location)
         try:
             b.bind(b_other)
-        except DivergedBranches:
-            raise BzrCommandError('These branches have diverged.'
-                                  ' Try merging, and then bind again.')
+        except errors.DivergedBranches:
+            raise errors.BzrCommandError('These branches have diverged.'
+                                         ' Try merging, and then bind again.')
 
 
 class cmd_unbind(Command):
@@ -2698,7 +2700,7 @@
     def run(self):
         b, relpath = Branch.open_containing(u'.')
         if not b.unbind():
-            raise BzrCommandError('Local branch is not bound')
+            raise errors.BzrCommandError('Local branch is not bound')
 
 
 class cmd_uncommit(Command):
@@ -2863,16 +2865,17 @@
             print 'listening on port: ', server.port
             sys.stdout.flush()
         else:
-            raise BzrCommandError("bzr serve requires one of --inet or --port")
+            raise errors.BzrCommandError("bzr serve requires one of --inet or --port")
         server.serve()
 
 
 # command-line interpretation helper for merge-related commands
-def merge(other_revision, base_revision,
-          check_clean=True, ignore_zero=False,
-          this_dir=None, backup_files=False, merge_type=Merge3Merger,
-          file_list=None, show_base=False, reprocess=False,
-          pb=DummyProgress()):
+def _merge_helper(other_revision, base_revision,
+                  check_clean=True, ignore_zero=False,
+                  this_dir=None, backup_files=False,
+                  merge_type=None,
+                  file_list=None, show_base=False, reprocess=False,
+                  pb=DummyProgress()):
     """Merge changes into a tree.
 
     base_revision
@@ -2900,20 +2903,23 @@
     clients might prefer to call merge.merge_inner(), which has less magic 
     behavior.
     """
-    from bzrlib.merge import Merger
+    # Loading it late, so that we don't always have to import bzrlib.merge
+    if merge_type is None:
+        merge_type = _mod_merge.Merge3Merger
     if this_dir is None:
         this_dir = u'.'
     this_tree = WorkingTree.open_containing(this_dir)[0]
-    if show_base and not merge_type is Merge3Merger:
-        raise BzrCommandError("Show-base is not supported for this merge"
-                              " type. %s" % merge_type)
+    if show_base and not merge_type is _mod_merge.Merge3Merger:
+        raise errors.BzrCommandError("Show-base is not supported for this merge"
+                                     " type. %s" % merge_type)
     if reprocess and not merge_type.supports_reprocess:
-        raise BzrCommandError("Conflict reduction is not supported for merge"
-                              " type %s." % merge_type)
+        raise errors.BzrCommandError("Conflict reduction is not supported for merge"
+                                     " type %s." % merge_type)
     if reprocess and show_base:
-        raise BzrCommandError("Cannot do conflict reduction and show base.")
+        raise errors.BzrCommandError("Cannot do conflict reduction and show base.")
     try:
-        merger = Merger(this_tree.branch, this_tree=this_tree, pb=pb)
+        merger = _mod_merge.Merger(this_tree.branch, this_tree=this_tree,
+                                   pb=pb)
         merger.pp = ProgressPhase("Merge phase", 5, pb)
         merger.pp.next_phase()
         merger.check_basis(check_clean)
@@ -2936,6 +2942,10 @@
     return conflicts
 
 
+# Compatibility
+merge = _merge_helper
+
+
 # these get imported and then picked up by the scan for cmd_*
 # TODO: Some more consistent way to split command definitions across files;
 # we do need to load at least some information about them to know of 

=== modified file 'bzrlib/bundle/__init__.py'
--- bzrlib/bundle/__init__.py	2006-10-11 23:08:27 +0000
+++ bzrlib/bundle/__init__.py	2006-10-16 01:25:46 +0000
@@ -14,10 +14,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+from bzrlib import (
+    errors,
+    urlutils,
+    )
 from bzrlib.bundle.serializer import read_bundle
-import bzrlib.errors as errors
-import bzrlib.urlutils
-import bzrlib.transport
+from bzrlib.transport import get_transport
+""")
 
 
 def read_bundle_from_url(url):
@@ -26,7 +31,7 @@
     :return: A BundleReader, may raise NotABundle if the target 
             is not a proper bundle.
     """
-    url, filename = bzrlib.urlutils.split(url, exclude_trailing_slash=False)
+    url, filename = urlutils.split(url, exclude_trailing_slash=False)
     if not filename:
         # A path to a directory was passed in
         # definitely not a bundle
@@ -36,7 +41,7 @@
     # Some transports cannot detect that we are trying to read a
     # directory until we actually issue read() on the handle.
     try:
-        t = bzrlib.transport.get_transport(url)
+        t = get_transport(url)
         f = t.get(filename)
         return read_bundle(f)
     except (errors.TransportError, errors.PathError), e:

=== modified file 'bzrlib/bundle/commands.py'
--- bzrlib/bundle/commands.py	2006-10-05 05:37:25 +0000
+++ bzrlib/bundle/commands.py	2006-10-16 01:25:46 +0000
@@ -22,14 +22,19 @@
 
 import sys
 
-from bzrlib.branch import Branch
-from bzrlib.commands import Command, register_command
-import bzrlib.errors as errors
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+from bzrlib import (
+    branch,
+    errors,
+    urlutils,
+    )
+from bzrlib.revision import common_ancestor
+""")
+
+from bzrlib.commands import Command
 from bzrlib.option import Option
-from bzrlib.revision import (common_ancestor, MultipleRevisionSources,
-                             NULL_REVISION)
 from bzrlib.trace import note
-from bzrlib import urlutils
 
 
 class cmd_send_changeset(Command):
@@ -57,7 +62,7 @@
                 raise BzrCommandError('We do not support rollup-changesets yet.')
             revision = revision[0]
 
-        b = Branch.open_containing('.')
+        b = branch.Branch.open_containing('.')
 
         if not to:
             try:
@@ -98,7 +103,7 @@
         from bzrlib import user_encoding
         from bzrlib.bundle.serializer import write_bundle
 
-        target_branch = Branch.open_containing(u'.')[0]
+        target_branch = branch.Branch.open_containing(u'.')[0]
 
         if base is None:
             base_specified = False
@@ -132,7 +137,7 @@
                 # we must format with 'ascii' to be safe
                 note('Using saved location: %s',
                      urlutils.unescape_for_display(base, 'ascii'))
-            base_branch = Branch.open(base)
+            base_branch = branch.Branch.open(base)
 
             # We don't want to lock the same branch across
             # 2 different branches
@@ -173,7 +178,7 @@
         from read_changeset import read_changeset
         #from bzrlib.xml import serializer_v4
 
-        b, relpath = Branch.open_containing('.')
+        b, relpath = branch.Branch.open_containing('.')
 
         if filename is None or filename == '-':
             f = sys.stdin

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2006-09-14 04:18:19 +0000
+++ bzrlib/bzrdir.py	2006-10-11 00:23:23 +0000
@@ -28,35 +28,40 @@
 # TODO: Can we move specific formats into separate modules to make this file
 # smaller?
 
-from copy import deepcopy
 from cStringIO import StringIO
 import os
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+from copy import deepcopy
 from stat import S_ISDIR
-from unittest import TestSuite
+import unittest
 
 import bzrlib
-import bzrlib.errors as errors
-from bzrlib.lockable_files import LockableFiles, TransportLock
-from bzrlib.lockdir import LockDir
+from bzrlib import (
+    errors,
+    lockable_files,
+    lockdir,
+    revision as _mod_revision,
+    urlutils,
+    xml4,
+    xml5,
+    )
 from bzrlib.osutils import (
-                            abspath,
-                            pathjoin,
-                            safe_unicode,
-                            sha_strings,
-                            sha_string,
-                            )
-import bzrlib.revision
+    safe_unicode,
+    sha_strings,
+    sha_string,
+    )
 from bzrlib.store.revision.text import TextRevisionStore
 from bzrlib.store.text import TextStore
 from bzrlib.store.versioned import WeaveStore
-from bzrlib.trace import mutter
 from bzrlib.transactions import WriteTransaction
 from bzrlib.transport import get_transport
+from bzrlib.weave import Weave
+""")
+
+from bzrlib.trace import mutter
 from bzrlib.transport.local import LocalTransport
-import bzrlib.urlutils as urlutils
-from bzrlib.weave import Weave
-from bzrlib.xml4 import serializer_v4
-import bzrlib.xml5
 
 
 class BzrDir(object):
@@ -188,7 +193,7 @@
     def _make_tail(self, url):
         head, tail = urlutils.split(url)
         if tail and tail != '.':
-            t = bzrlib.transport.get_transport(head)
+            t = get_transport(head)
             try:
                 t.mkdir(tail)
             except errors.FileExists:
@@ -210,7 +215,7 @@
                     "not one of %r" % cls)
         head, tail = urlutils.split(base)
         if tail and tail != '.':
-            t = bzrlib.transport.get_transport(head)
+            t = get_transport(head)
             try:
                 t.mkdir(tail)
             except errors.FileExists:
@@ -341,6 +346,21 @@
         """
         raise NotImplementedError(self.create_workingtree)
 
+    def destroy_workingtree(self):
+        """Destroy the working tree at this BzrDir.
+
+        Formats that do not support this may raise UnsupportedOperation.
+        """
+        raise NotImplementedError(self.destroy_workingtree)
+
+    def destroy_workingtree_metadata(self):
+        """Destroy the control files for the working tree at this BzrDir.
+
+        The contents of working tree files are not affected.
+        Formats that do not support this may raise UnsupportedOperation.
+        """
+        raise NotImplementedError(self.destroy_workingtree_metadata)
+
     def find_repository(self):
         """Find the repository that should be used for a_bzrdir.
 
@@ -675,9 +695,10 @@
     def __init__(self, _transport, _format):
         """See BzrDir.__init__."""
         super(BzrDirPreSplitOut, self).__init__(_transport, _format)
-        assert self._format._lock_class == TransportLock
+        assert self._format._lock_class == lockable_files.TransportLock
         assert self._format._lock_file_name == 'branch-lock'
-        self._control_files = LockableFiles(self.get_branch_transport(None),
+        self._control_files = lockable_files.LockableFiles(
+                                            self.get_branch_transport(None),
                                             self._format._lock_file_name,
                                             self._format._lock_class)
 
@@ -727,12 +748,21 @@
         # done on this format anyway. So - acceptable wart.
         result = self.open_workingtree()
         if revision_id is not None:
-            if revision_id == bzrlib.revision.NULL_REVISION:
+            if revision_id == _mod_revision.NULL_REVISION:
                 result.set_parent_ids([])
             else:
                 result.set_parent_ids([revision_id])
         return result
 
+    def destroy_workingtree(self):
+        """See BzrDir.destroy_workingtree."""
+        raise errors.UnsupportedOperation(self.destroy_workingtree, self)
+
+    def destroy_workingtree_metadata(self):
+        """See BzrDir.destroy_workingtree_metadata."""
+        raise errors.UnsupportedOperation(self.destroy_workingtree_metadata, 
+                                          self)
+
     def get_branch_transport(self, branch_format):
         """See BzrDir.get_branch_transport()."""
         if branch_format is None:
@@ -878,9 +908,21 @@
         from bzrlib.workingtree import WorkingTreeFormat
         return WorkingTreeFormat.get_default_format().initialize(self, revision_id)
 
+    def destroy_workingtree(self):
+        """See BzrDir.destroy_workingtree."""
+        wt = self.open_workingtree()
+        repository = wt.branch.repository
+        empty = repository.revision_tree(bzrlib.revision.NULL_REVISION)
+        wt.revert([], old_tree=empty)
+        self.destroy_workingtree_metadata()
+
+    def destroy_workingtree_metadata(self):
+        self.transport.delete_tree('checkout')
+
     def _get_mkdir_mode(self):
         """Figure out the mode to use when creating a bzrdir subdir."""
-        temp_control = LockableFiles(self.transport, '', TransportLock)
+        temp_control = lockable_files.LockableFiles(self.transport, '',
+                                     lockable_files.TransportLock)
         return temp_control._dir_mode
 
     def get_branch_transport(self, branch_format):
@@ -1062,7 +1104,8 @@
         """Initialize a new bzrdir in the base directory of a Transport."""
         # Since we don't have a .bzr directory, inherit the
         # mode from the root directory
-        temp_control = LockableFiles(transport, '', TransportLock)
+        temp_control = lockable_files.LockableFiles(transport,
+                            '', lockable_files.TransportLock)
         temp_control._transport.mkdir('.bzr',
                                       # FIXME: RBC 20060121 don't peek under
                                       # the covers
@@ -1077,8 +1120,8 @@
                       ('branch-format', self.get_format_string()),
                       ]
         # NB: no need to escape relative paths that are url safe.
-        control_files = LockableFiles(control, self._lock_file_name, 
-                                      self._lock_class)
+        control_files = lockable_files.LockableFiles(control,
+                            self._lock_file_name, self._lock_class)
         control_files.create_lock()
         control_files.lock_write()
         try:
@@ -1187,7 +1230,7 @@
     removed in format 5; write support for this format has been removed.
     """
 
-    _lock_class = TransportLock
+    _lock_class = lockable_files.TransportLock
 
     def get_format_string(self):
         """See BzrDirFormat.get_format_string()."""
@@ -1237,7 +1280,7 @@
        Unhashed stores in the repository.
     """
 
-    _lock_class = TransportLock
+    _lock_class = lockable_files.TransportLock
 
     def get_format_string(self):
         """See BzrDirFormat.get_format_string()."""
@@ -1296,7 +1339,7 @@
      - Format 6 repositories [always]
     """
 
-    _lock_class = TransportLock
+    _lock_class = lockable_files.TransportLock
 
     def get_format_string(self):
         """See BzrDirFormat.get_format_string()."""
@@ -1356,7 +1399,7 @@
      - Format 7 repositories [optional]
     """
 
-    _lock_class = LockDir
+    _lock_class = lockdir.LockDir
 
     def get_converter(self, format=None):
         """See BzrDirFormat.get_converter()."""
@@ -1416,7 +1459,7 @@
         self._formats = formats
     
     def adapt(self, test):
-        result = TestSuite()
+        result = unittest.TestSuite()
         for format in self._formats:
             new_test = deepcopy(test)
             new_test.transport_server = self._transport_server
@@ -1520,8 +1563,9 @@
         self.bzrdir.transport.delete_tree('text-store')
 
     def _convert_working_inv(self):
-        inv = serializer_v4.read_inventory(self.branch.control_files.get('inventory'))
-        new_inv_xml = bzrlib.xml5.serializer_v5.write_inventory_to_string(inv)
+        inv = xml4.serializer_v4.read_inventory(
+                    self.branch.control_files.get('inventory'))
+        new_inv_xml = xml5.serializer_v5.write_inventory_to_string(inv)
         # FIXME inventory is a working tree change.
         self.branch.control_files.put('inventory', StringIO(new_inv_xml))
 
@@ -1553,7 +1597,7 @@
                                                       prefixed=False,
                                                       compressed=True))
         try:
-            transaction = bzrlib.transactions.WriteTransaction()
+            transaction = WriteTransaction()
             for i, rev_id in enumerate(self.converted_revs):
                 self.pb.update('write revision', i, len(self.converted_revs))
                 _revision_store.add_revision(self.revisions[rev_id], transaction)
@@ -1585,7 +1629,7 @@
     def _load_old_inventory(self, rev_id):
         assert rev_id not in self.converted_revs
         old_inv_xml = self.branch.repository.inventory_store.get(rev_id).read()
-        inv = serializer_v4.read_inventory_from_string(old_inv_xml)
+        inv = xml4.serializer_v4.read_inventory_from_string(old_inv_xml)
         inv.revision_id = rev_id
         rev = self.revisions[rev_id]
         if rev.inventory_sha1:
@@ -1596,7 +1640,7 @@
     def _load_updated_inventory(self, rev_id):
         assert rev_id in self.converted_revs
         inv_xml = self.inv_weave.get_text(rev_id)
-        inv = bzrlib.xml5.serializer_v5.read_inventory_from_string(inv_xml)
+        inv = xml5.serializer_v5.read_inventory_from_string(inv_xml)
         return inv
 
     def _convert_one_rev(self, rev_id):
@@ -1618,7 +1662,7 @@
                 assert getattr(ie, 'revision', None) is not None, \
                     'no revision on {%s} in {%s}' % \
                     (file_id, rev.revision_id)
-        new_inv_xml = bzrlib.xml5.serializer_v5.write_inventory_to_string(inv)
+        new_inv_xml = xml5.serializer_v5.write_inventory_to_string(inv)
         new_inv_sha1 = sha_string(new_inv_xml)
         self.inv_weave.add_lines(rev.revision_id, 
                                  present_parents,
@@ -1836,10 +1880,10 @@
     def make_lock(self, name):
         """Make a lock for the new control dir name."""
         self.step('Make %s lock' % name)
-        ld = LockDir(self.bzrdir.transport, 
-                     '%s/lock' % name,
-                     file_modebits=self.file_mode,
-                     dir_modebits=self.dir_mode)
+        ld = lockdir.LockDir(self.bzrdir.transport,
+                             '%s/lock' % name,
+                             file_modebits=self.file_mode,
+                             dir_modebits=self.dir_mode)
         ld.create()
 
     def move_entry(self, new_dir, entry):

=== modified file 'bzrlib/cmd_version_info.py'
--- bzrlib/cmd_version_info.py	2006-09-22 15:19:55 +0000
+++ bzrlib/cmd_version_info.py	2006-10-06 07:00:57 +0000
@@ -16,12 +16,15 @@
 
 """Commands for generating snapshot information about a bzr tree."""
 
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 from bzrlib import (
     branch,
     errors,
     version_info_formats,
     workingtree,
     )
+""")
 from bzrlib.commands import Command
 from bzrlib.option import Option
 

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2006-10-11 23:08:27 +0000
+++ bzrlib/commands.py	2006-10-16 01:25:46 +0000
@@ -28,24 +28,33 @@
 # TODO: "--profile=cum", to change sort order.  Is there any value in leaving
 # the profile output behind so it can be interactively examined?
 
+import os
+import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import codecs
 import errno
-import os
 from warnings import warn
-import sys
 
 import bzrlib
-import bzrlib.errors as errors
-from bzrlib.errors import (BzrError,
-                           BzrCommandError,
-                           BzrCheckError,
-                           NotBranchError)
-from bzrlib import option
+from bzrlib import (
+    errors,
+    option,
+    osutils,
+    trace,
+    )
+""")
+
+from bzrlib.symbol_versioning import (
+    deprecated_function,
+    deprecated_method,
+    zero_eight,
+    zero_eleven,
+    )
+# Compatibility
 from bzrlib.option import Option
-import bzrlib.osutils
-from bzrlib.symbol_versioning import (deprecated_method, zero_eight)
-import bzrlib.trace
-from bzrlib.trace import mutter, note, log_error, warning, be_quiet
+
 
 plugin_cmds = {}
 
@@ -66,7 +75,7 @@
         k_unsquished = k
     if k_unsquished not in plugin_cmds:
         plugin_cmds[k_unsquished] = cmd
-        mutter('registered plugin command %s', k_unsquished)
+        trace.mutter('registered plugin command %s', k_unsquished)
         if decorate and k_unsquished in builtin_command_names():
             return _builtin_commands()[k_unsquished]
     elif decorate:
@@ -74,8 +83,8 @@
         plugin_cmds[k_unsquished] = cmd
         return result
     else:
-        log_error('Two plugins defined the same command: %r' % k)
-        log_error('Not loading the one in %r' % sys.modules[cmd.__module__])
+        trace.log_error('Two plugins defined the same command: %r' % k)
+        trace.log_error('Not loading the one in %r' % sys.modules[cmd.__module__])
 
 
 def _squish_command_name(cmd):
@@ -150,7 +159,7 @@
     if cmd_obj:
         return cmd_obj
 
-    raise BzrCommandError('unknown command "%s"' % cmd_name)
+    raise errors.BzrCommandError('unknown command "%s"' % cmd_name)
 
 
 class Command(object):
@@ -222,10 +231,10 @@
 
         Maps from long option name to option object."""
         r = dict()
-        r['help'] = Option.OPTIONS['help']
+        r['help'] = option.Option.OPTIONS['help']
         for o in self.takes_options:
             if isinstance(o, basestring):
-                o = Option.OPTIONS[o]
+                o = option.Option.OPTIONS[o]
             r[o.name] = o
         return r
 
@@ -239,7 +248,7 @@
             self.outf = sys.stdout
             return
 
-        output_encoding = bzrlib.osutils.get_terminal_encoding()
+        output_encoding = osutils.get_terminal_encoding()
 
         # use 'replace' so that we don't abort if trying to write out
         # in e.g. the default C locale.
@@ -316,6 +325,9 @@
             return None
 
 
+# Technically, this function hasn't been use in a *really* long time
+# but we are only deprecating it now.
+@deprecated_function(zero_eleven)
 def parse_spec(spec):
     """
     >>> parse_spec(None)
@@ -385,29 +397,29 @@
                 argdict[argname + '_list'] = None
         elif ap[-1] == '+':
             if not args:
-                raise BzrCommandError("command %r needs one or more %s"
-                        % (cmd, argname.upper()))
+                raise errors.BzrCommandError("command %r needs one or more %s"
+                                             % (cmd, argname.upper()))
             else:
                 argdict[argname + '_list'] = args[:]
                 args = []
         elif ap[-1] == '$': # all but one
             if len(args) < 2:
-                raise BzrCommandError("command %r needs one or more %s"
-                        % (cmd, argname.upper()))
+                raise errors.BzrCommandError("command %r needs one or more %s"
+                                             % (cmd, argname.upper()))
             argdict[argname + '_list'] = args[:-1]
             args[:-1] = []
         else:
             # just a plain arg
             argname = ap
             if not args:
-                raise BzrCommandError("command %r requires argument %s"
-                        % (cmd, argname.upper()))
+                raise errors.BzrCommandError("command %r requires argument %s"
+                               % (cmd, argname.upper()))
             else:
                 argdict[argname] = args.pop(0)
             
     if args:
-        raise BzrCommandError("extra argument to command %s: %s"
-                              % (cmd, args[0]))
+        raise errors.BzrCommandError("extra argument to command %s: %s"
+                                     % (cmd, args[0]))
 
     return argdict
 
@@ -520,7 +532,7 @@
         elif a == '--builtin':
             opt_builtin = True
         elif a in ('--quiet', '-q'):
-            be_quiet()
+            trace.be_quiet()
         else:
             argv_copy.append(a)
         i += 1
@@ -574,7 +586,7 @@
         return ret or 0
     finally:
         # reset, in case we may do other commands later within the same process
-        be_quiet(False)
+        trace.be_quiet(False)
 
 def display_command(func):
     """Decorator that suppresses pipe/interrupt errors."""
@@ -602,7 +614,7 @@
     bzrlib.ui.ui_factory = TextUIFactory()
     argv = [a.decode(bzrlib.user_encoding) for a in argv[1:]]
     ret = run_bzr_catch_errors(argv)
-    mutter("return code %d", ret)
+    trace.mutter("return code %d", ret)
     return ret
 
 
@@ -614,7 +626,7 @@
     except (KeyboardInterrupt, Exception), e:
         # used to handle AssertionError and KeyboardInterrupt
         # specially here, but hopefully they're handled ok by the logger now
-        bzrlib.trace.report_exception(sys.exc_info(), sys.stderr)
+        trace.report_exception(sys.exc_info(), sys.stderr)
         if os.environ.get('BZR_PDB'):
             print '**** entering debugger'
             import pdb

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2006-10-11 23:08:27 +0000
+++ bzrlib/config.py	2006-10-16 01:25:46 +0000
@@ -61,19 +61,26 @@
 up=pull
 """
 
+import os
+import sys
 
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import errno
 from fnmatch import fnmatch
-import os
 import re
-import sys
 from StringIO import StringIO
 
 import bzrlib
-from bzrlib import errors, urlutils
-from bzrlib.osutils import pathjoin
+from bzrlib import (
+    errors,
+    osutils,
+    urlutils,
+    )
+import bzrlib.util.configobj.configobj as configobj
+""")
+
 from bzrlib.trace import mutter, warning
-import bzrlib.util.configobj.configobj as configobj
 
 
 CHECK_IF_POSSIBLE=0
@@ -599,32 +606,32 @@
             base = os.environ.get('HOME', None)
         if base is None:
             raise errors.BzrError('You must have one of BZR_HOME, APPDATA, or HOME set')
-        return pathjoin(base, 'bazaar', '2.0')
+        return osutils.pathjoin(base, 'bazaar', '2.0')
     else:
         # cygwin, linux, and darwin all have a $HOME directory
         if base is None:
             base = os.path.expanduser("~")
-        return pathjoin(base, ".bazaar")
+        return osutils.pathjoin(base, ".bazaar")
 
 
 def config_filename():
     """Return per-user configuration ini file filename."""
-    return pathjoin(config_dir(), 'bazaar.conf')
+    return osutils.pathjoin(config_dir(), 'bazaar.conf')
 
 
 def branches_config_filename():
     """Return per-user configuration ini file filename."""
-    return pathjoin(config_dir(), 'branches.conf')
+    return osutils.pathjoin(config_dir(), 'branches.conf')
 
 
 def locations_config_filename():
     """Return per-user configuration ini file filename."""
-    return pathjoin(config_dir(), 'locations.conf')
+    return osutils.pathjoin(config_dir(), 'locations.conf')
 
 
 def user_ignore_config_filename():
     """Return the user default ignore filename"""
-    return pathjoin(config_dir(), 'ignore')
+    return osutils.pathjoin(config_dir(), 'ignore')
 
 
 def _auto_user_id():
@@ -698,8 +705,7 @@
     """
     m = re.search(r'[\w+.-]+@[\w+.-]+', e)
     if not m:
-        raise errors.BzrError("%r doesn't seem to contain "
-                              "a reasonable email address" % e)
+        raise errors.NoEmailInUsername(e)
     return m.group(0)
 
 

=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2006-10-11 23:32:09 +0000
+++ bzrlib/conflicts.py	2006-10-16 01:25:46 +0000
@@ -20,20 +20,25 @@
 # point down
 
 import os
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import errno
 
-import bzrlib
-from bzrlib.commands import register_command
-from bzrlib.errors import BzrCommandError, NotConflicted, UnsupportedOperation
+from bzrlib import (
+    commands,
+    errors,
+    osutils,
+    rio,
+    )
+""")
 from bzrlib.option import Option
-from bzrlib.osutils import rename, delete_any
-from bzrlib.rio import Stanza
 
 
 CONFLICT_SUFFIXES = ('.THIS', '.BASE', '.OTHER')
 
 
-class cmd_conflicts(bzrlib.commands.Command):
+class cmd_conflicts(commands.Command):
     """List files with conflicts.
 
     Merge will do its best to combine the changes in two branches, but there
@@ -55,7 +60,7 @@
             print conflict
 
 
-class cmd_resolve(bzrlib.commands.Command):
+class cmd_resolve(commands.Command):
     """Mark a conflict as resolved.
 
     Merge will do its best to combine the changes in two branches, but there
@@ -76,12 +81,14 @@
         from bzrlib.workingtree import WorkingTree
         if all:
             if file_list:
-                raise BzrCommandError("If --all is specified, no FILE may be provided")
+                raise errors.BzrCommandError("If --all is specified,"
+                                             " no FILE may be provided")
             tree = WorkingTree.open_containing('.')[0]
             resolve(tree)
         else:
             if file_list is None:
-                raise BzrCommandError("command 'resolve' needs one or more FILE, or --all")
+                raise errors.BzrCommandError("command 'resolve' needs one or"
+                                             " more FILE, or --all")
             tree = WorkingTree.open_containing(file_list[0])[0]
             to_resolve = [tree.relpath(p) for p in file_list]
             resolve(tree, to_resolve)
@@ -99,7 +106,7 @@
                 tree_conflicts.select_conflicts(tree, paths, ignore_misses)
         try:
             tree.set_conflicts(new_conflicts)
-        except UnsupportedOperation:
+        except errors.UnsupportedOperation:
             pass
         selected_conflicts.remove_files(tree)
     finally:
@@ -113,7 +120,7 @@
     """
     conflicted = False
     try:
-        rename(filename + ".THIS", filename)
+        osutils.rename(filename + ".THIS", filename)
         conflicted = True
     except OSError, e:
         if e.errno != errno.ENOENT:
@@ -131,7 +138,7 @@
         if e.errno != errno.ENOENT:
             raise
     if not conflicted:
-        raise NotConflicted(filename)
+        raise errors.NotConflicted(filename)
 
 
 class ConflictList(object):
@@ -198,7 +205,7 @@
                 continue
             for suffix in CONFLICT_SUFFIXES:
                 try:
-                    delete_any(tree.abspath(conflict.path+suffix))
+                    osutils.delete_any(tree.abspath(conflict.path+suffix))
                 except OSError, e:
                     if e.errno != errno.ENOENT:
                         raise
@@ -261,7 +268,7 @@
         self.file_id = file_id
 
     def as_stanza(self):
-        s = Stanza(type=self.typestring, path=self.path)
+        s = rio.Stanza(type=self.typestring, path=self.path)
         if self.file_id is not None:
             s.add('file_id', self.file_id)
         return s

=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2006-09-09 15:55:01 +0000
+++ bzrlib/diff.py	2006-09-12 22:16:38 +0000
@@ -14,27 +14,32 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import errno
 import os
 import re
+import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+import errno
 import subprocess
-import sys
 import tempfile
 import time
 
 from bzrlib import (
     errors,
     osutils,
+    patiencediff,
+    textfile,
     )
+""")
+
 # compatability - plugins import compare_trees from diff!!!
 # deprecated as of 0.10
 from bzrlib.delta import compare_trees
-from bzrlib.errors import BzrError
-from bzrlib.patiencediff import unified_diff
-import bzrlib.patiencediff
-from bzrlib.symbol_versioning import (deprecated_function,
-        zero_eight)
-from bzrlib.textfile import check_text_lines
+from bzrlib.symbol_versioning import (
+        deprecated_function,
+        zero_eight,
+        )
 from bzrlib.trace import mutter, warning
 
 
@@ -62,12 +67,12 @@
         return
     
     if allow_binary is False:
-        check_text_lines(oldlines)
-        check_text_lines(newlines)
+        textfile.check_text_lines(oldlines)
+        textfile.check_text_lines(newlines)
 
     if sequence_matcher is None:
-        sequence_matcher = bzrlib.patiencediff.PatienceSequenceMatcher
-    ud = unified_diff(oldlines, newlines,
+        sequence_matcher = patiencediff.PatienceSequenceMatcher
+    ud = patiencediff.unified_diff(oldlines, newlines,
                       fromfile=old_filename.encode(path_encoding),
                       tofile=new_filename.encode(path_encoding),
                       sequencematcher=sequence_matcher)
@@ -212,7 +217,8 @@
             # Write out the new i18n diff response
             to_file.write(out+'\n')
             if pipe.returncode != 2:
-                raise BzrError('external diff failed with exit code 2'
+                raise errors.BzrError(
+                               'external diff failed with exit code 2'
                                ' when run with LANG=C, but not when run'
                                ' natively: %r' % (diffcmd,))
 
@@ -220,8 +226,8 @@
             # Starting with diffutils 2.8.4 the word "binary" was dropped.
             m = re.match('^(binary )?files.*differ$', first_line, re.I)
             if m is None:
-                raise BzrError('external diff failed with exit code 2;'
-                               ' command: %r' % (diffcmd,))
+                raise errors.BzrError('external diff failed with exit code 2;'
+                                      ' command: %r' % (diffcmd,))
             else:
                 # Binary files differ, just return
                 return
@@ -236,8 +242,8 @@
             else:
                 msg = 'exit code %d' % rc
                 
-            raise BzrError('external diff failed with %s; command: %r' 
-                           % (rc, diffcmd))
+            raise errors.BzrError('external diff failed with %s; command: %r' 
+                                  % (rc, diffcmd))
 
 
     finally:

=== modified file 'bzrlib/doc/api/branch.txt'
--- bzrlib/doc/api/branch.txt	2006-06-30 21:22:07 +0000
+++ bzrlib/doc/api/branch.txt	2006-10-05 22:42:09 +0000
@@ -4,8 +4,8 @@
 
 Make a temporary directory for these tests:
 
-   >>> from bzrlib.osutils import mkdtemp
-   >>> test_dir = mkdtemp(prefix='bzrlib_doc_api_branch_txt_')
+   >>> from bzrlib import osutils
+   >>> test_dir = osutils.mkdtemp(prefix='bzrlib_doc_api_branch_txt_')
 
 Branches are created by BzrDir's:
 

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-10-05 05:37:25 +0000
+++ bzrlib/errors.py	2006-10-16 01:25:46 +0000
@@ -890,6 +890,14 @@
         BzrError.__init__(self, message)
 
 
+class NoEmailInUsername(BzrNewError):
+    """%(username)r does not seem to contain a reasonable email address"""
+
+    def __init__(self, username):
+        BzrNewError.__init__(self)
+        self.username = username
+
+
 class SigningFailed(BzrError):
     def __init__(self, command_line):
         BzrError.__init__(self, "Failed to gpg sign data with command '%s'"

=== modified file 'bzrlib/gpg.py'
--- bzrlib/gpg.py	2006-10-11 23:08:27 +0000
+++ bzrlib/gpg.py	2006-10-16 01:25:46 +0000
@@ -17,16 +17,20 @@
 
 """GPG signing and checking logic."""
 
+import os
+import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import errno
-import os
 import subprocess
-import sys
 
 from bzrlib import (
     errors,
     trace,
     ui,
     )
+""")
 
 
 class DisabledGPGStrategy(object):

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2006-09-20 22:54:18 +0000
+++ bzrlib/inventory.py	2006-10-06 05:53:44 +0000
@@ -27,21 +27,27 @@
 # created, but it's not for now.
 ROOT_ID = "TREE_ROOT"
 
-
-import collections
-import os.path
+import os
 import re
 import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+import collections
 import tarfile
-import types
-from warnings import warn
 
 import bzrlib
-from bzrlib import errors, osutils
-from bzrlib.osutils import (pumpfile, quotefn, splitpath, joinpath,
-                            pathjoin, sha_strings)
-from bzrlib.errors import (NotVersionedError, InvalidEntryName,
-                           BzrError, BzrCheckError, BinaryFile)
+from bzrlib import (
+    errors,
+    osutils,
+    symbol_versioning,
+    )
+""")
+
+from bzrlib.errors import (
+    BzrCheckError,
+    BzrError,
+    )
 from bzrlib.trace import mutter
 
 
@@ -82,7 +88,7 @@
     InventoryDirectory('123', 'src', parent_id='TREE_ROOT', revision=None)
     >>> i.add(InventoryFile('2323', 'hello.c', parent_id='123'))
     InventoryFile('2323', 'hello.c', parent_id='123', sha1=None, len=None)
-    >>> shouldbe = {0: '', 1: 'src', 2: pathjoin('src','hello.c')}
+    >>> shouldbe = {0: '', 1: 'src', 2: 'src/hello.c'}
     >>> for ix, j in enumerate(i.iter_entries()):
     ...   print (j[0] == shouldbe[ix], j[1])
     ... 
@@ -246,7 +252,7 @@
 
     def get_tar_item(self, root, dp, now, tree):
         """Get a tarfile item and a file stream for its content."""
-        item = tarfile.TarInfo(pathjoin(root, dp).encode('utf8'))
+        item = tarfile.TarInfo(osutils.pathjoin(root, dp).encode('utf8'))
         # TODO: would be cool to actually set it to the timestamp of the
         # revision it was last changed
         item.mtime = now
@@ -281,7 +287,7 @@
         """
         assert isinstance(name, basestring), name
         if '/' in name or '\\' in name:
-            raise InvalidEntryName(name=name)
+            raise errors.InvalidEntryName(name=name)
         self.executable = False
         self.revision = None
         self.text_sha1 = None
@@ -311,7 +317,7 @@
         
         This is a template method - implement _put_on_disk in subclasses.
         """
-        fullpath = pathjoin(dest, dp)
+        fullpath = osutils.pathjoin(dest, dp)
         self._put_on_disk(fullpath, tree)
         # mutter("  export {%s} kind %s to %s", self.file_id,
         #         self.kind, fullpath)
@@ -514,9 +520,9 @@
         self.parent_id = None
         self.name = u''
         self.revision = None
-        warn('RootEntry is deprecated as of bzr 0.10.  Please use '
-             'InventoryDirectory instead.',
-            DeprecationWarning, stacklevel=2)
+        symbol_versioning.warn('RootEntry is deprecated as of bzr 0.10.'
+                               '  Please use InventoryDirectory instead.',
+                               DeprecationWarning, stacklevel=2)
 
     def __eq__(self, other):
         if not isinstance(other, RootEntry):
@@ -645,7 +651,7 @@
             else:
                 text_diff(to_label, to_text,
                           from_label, from_text, output_to)
-        except BinaryFile:
+        except errors.BinaryFile:
             if reverse:
                 label_pair = (to_label, from_label)
             else:
@@ -677,7 +683,7 @@
 
     def _put_on_disk(self, fullpath, tree):
         """See InventoryEntry._put_on_disk."""
-        pumpfile(tree.get_file(self.file_id), file(fullpath, 'wb'))
+        osutils.pumpfile(tree.get_file(self.file_id), file(fullpath, 'wb'))
         if tree.is_executable(self.file_id):
             os.chmod(fullpath, 0755)
 
@@ -982,7 +988,7 @@
             kids = dir_ie.children.items()
             kids.sort()
             for name, ie in kids:
-                child_path = pathjoin(dir_path, name)
+                child_path = osutils.pathjoin(dir_path, name)
                 accum.append((child_path, ie))
                 if ie.kind == 'directory':
                     descend(ie, child_path)
@@ -1001,7 +1007,7 @@
             kids.sort()
 
             for name, child_ie in kids:
-                child_path = pathjoin(parent_path, name)
+                child_path = osutils.pathjoin(parent_path, name)
                 descend(child_ie, child_path)
         descend(self.root, u'')
         return accum
@@ -1068,7 +1074,7 @@
 
         if entry.name in parent.children:
             raise BzrError("%s is already versioned" %
-                    pathjoin(self.id2path(parent.file_id), entry.name))
+                    osutils.pathjoin(self.id2path(parent.file_id), entry.name))
 
         self._byid[entry.file_id] = entry
         parent.children[entry.name] = entry
@@ -1093,7 +1099,7 @@
             parent_path = parts[:-1]
             parent_id = self.path2id(parent_path)
             if parent_id is None:
-                raise NotVersionedError(path=parent_path)
+                raise errors.NotVersionedError(path=parent_path)
         ie = make_entry(kind, parts[-1], parent_id, file_id)
         return self.add(ie)
 
@@ -1193,8 +1199,8 @@
 
         Returns None IFF the path is not found.
         """
-        if isinstance(name, types.StringTypes):
-            name = splitpath(name)
+        if isinstance(name, basestring):
+            name = osutils.splitpath(name)
 
         # mutter("lookup path %r" % name)
 

=== modified file 'bzrlib/lazy_import.py'
--- bzrlib/lazy_import.py	2006-10-11 23:08:27 +0000
+++ bzrlib/lazy_import.py	2006-10-16 01:25:46 +0000
@@ -40,13 +40,6 @@
     to inherit from them).
 """
 
-import re
-import sys
-
-from bzrlib import (
-    errors,
-    )
-
 
 class ScopeReplacer(object):
     """A lazy object that will replace itself in the appropriate scope.
@@ -377,3 +370,12 @@
     # This is just a helper around ImportProcessor.lazy_import
     proc = ImportProcessor(lazy_import_class=lazy_import_class)
     return proc.lazy_import(scope, text)
+
+
+# The only module that this module depends on is 'bzrlib.errors'. But it
+# can actually be imported lazily, since we only need it if there is a
+# problem.
+
+lazy_import(globals(), """
+from bzrlib import errors
+""")

=== added file 'bzrlib/lazy_regex.py'
--- bzrlib/lazy_regex.py	1970-01-01 00:00:00 +0000
+++ bzrlib/lazy_regex.py	2006-10-16 01:25:46 +0000
@@ -0,0 +1,106 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Lazily compiled regex objects.
+
+This module defines a class which creates proxy objects for regex compilation.
+This allows overriding re.compile() to return lazily compiled objects.
+"""
+
+import re
+
+
+class LazyRegex(object):
+    """A proxy around a real regex, which won't be compiled until accessed."""
+
+
+    # These are the parameters on a real _sre.SRE_Pattern object, which we
+    # will map to local members so that we don't have the proxy overhead.
+    _regex_attributes_to_copy = [
+                 '__copy__', '__deepcopy__', 'findall', 'finditer', 'match',
+                 'scanner', 'search', 'split', 'sub', 'subn'
+                 ]
+
+    # We use slots to keep the overhead low. But we need a slot entry for
+    # all of the attributes we will copy
+    __slots__ = ['_real_regex', '_regex_args', '_regex_kwargs',
+                ] + _regex_attributes_to_copy
+
+    def __init__(self, args=(), kwargs={}):
+        """Create a new proxy object, passing in the args to pass to re.compile
+
+        :param args: The *args to pass to re.compile
+        :param kwargs: The **kwargs to pass to re.compile
+        """
+        self._real_regex = None
+        self._regex_args = args
+        self._regex_kwargs = kwargs
+
+    def _compile_and_collapse(self):
+        """Actually compile the requested regex"""
+        self._real_regex = self._real_re_compile(*self._regex_args,
+                                                 **self._regex_kwargs)
+        for attr in self._regex_attributes_to_copy:
+            setattr(self, attr, getattr(self._real_regex, attr))
+
+    def _real_re_compile(self, *args, **kwargs):
+        """Thunk over to the original re.compile"""
+        return _real_re_compile(*args, **kwargs)
+
+    def __getattr__(self, attr):
+        """Return a member from the proxied regex object.
+
+        If the regex hasn't been compiled yet, compile it
+        """
+        if self._real_regex is None:
+            self._compile_and_collapse()
+        # Once we have compiled, the only time we should come here
+        # is actually if the attribute is missing.
+        return getattr(self._real_regex, attr)
+
+
+def lazy_compile(*args, **kwargs):
+    """Create a proxy object which will compile the regex on demand.
+
+    :return: a LazyRegex proxy object.
+    """
+    return LazyRegex(args, kwargs)
+
+
+def install_lazy_compile():
+    """Make lazy_compile the default compile mode for regex compilation.
+
+    This overrides re.compile with lazy_compile. To restore the original
+    functionality, call reset_compile().
+    """
+    re.compile = lazy_compile
+
+
+def reset_compile():
+    """Restore the original function to re.compile().
+    
+    It is safe to call reset_compile() multiple times, it will always
+    restore re.compile() to the value that existed at import time.
+    Though the first call will reset back to the original (it doesn't
+    track nesting level)
+    """
+    re.compile = _real_re_compile
+
+
+_real_re_compile = re.compile
+assert _real_re_compile is not lazy_compile, \
+    "re.compile has already been overridden as lazy_compile, but this would" \
+    " cause infinite recursion"

=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2006-09-27 22:12:53 +0000
+++ bzrlib/lockdir.py	2006-09-29 20:24:37 +0000
@@ -98,6 +98,9 @@
 import time
 from cStringIO import StringIO
 
+from bzrlib import (
+    errors,
+    )
 import bzrlib.config
 from bzrlib.errors import (
         DirectoryNotEmpty,
@@ -342,11 +345,15 @@
         import socket
         # XXX: is creating this here inefficient?
         config = bzrlib.config.GlobalConfig()
+        try:
+            user = config.user_email()
+        except errors.NoEmailInUsername:
+            user = config.username()
         s = Stanza(hostname=socket.gethostname(),
                    pid=str(os.getpid()),
                    start_time=str(int(time.time())),
                    nonce=self.nonce,
-                   user=config.user_email(),
+                   user=user,
                    )
         return s.to_string()
 

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2006-09-04 08:00:00 +0000
+++ bzrlib/merge.py	2006-10-06 05:53:44 +0000
@@ -17,9 +17,11 @@
 
 import os
 import errno
-from tempfile import mkdtemp
 import warnings
 
+from bzrlib import (
+    osutils,
+    )
 from bzrlib.branch import Branch
 from bzrlib.conflicts import ConflictList, Conflict
 from bzrlib.errors import (BzrCommandError,
@@ -37,7 +39,7 @@
                            )
 from bzrlib.merge3 import Merge3
 import bzrlib.osutils
-from bzrlib.osutils import rename, pathjoin, rmtree
+from bzrlib.osutils import rename, pathjoin
 from progress import DummyProgress, ProgressPhase
 from bzrlib.revision import common_ancestor, is_ancestor, NULL_REVISION
 from bzrlib.textfile import check_text_lines
@@ -868,7 +870,7 @@
         will be dumped, and a will be conflict noted.
         """
         import bzrlib.patch
-        temp_dir = mkdtemp(prefix="bzr-")
+        temp_dir = osutils.mkdtemp(prefix="bzr-")
         try:
             new_file = pathjoin(temp_dir, "new")
             this = self.dump_file(temp_dir, "this", self.this_tree, file_id)
@@ -886,9 +888,9 @@
                 name = self.tt.final_name(trans_id)
                 parent_id = self.tt.final_parent(trans_id)
                 self._dump_conflicts(name, parent_id, file_id)
-            self._raw_conflicts.append(('text conflict', trans_id))
+                self._raw_conflicts.append(('text conflict', trans_id))
         finally:
-            rmtree(temp_dir)
+            osutils.rmtree(temp_dir)
 
 
 def merge_inner(this_branch, other_tree, base_tree, ignore_zero=False,

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2006-10-11 23:08:27 +0000
+++ bzrlib/option.py	2006-10-16 01:25:46 +0000
@@ -17,12 +17,18 @@
 # TODO: For things like --diff-prefix, we want a way to customize the display
 # of the option argument.
 
+import re
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import optparse
-import re
 
+from bzrlib import (
+    errors,
+    revisionspec,
+    )
+""")
 from bzrlib.trace import warning
-from bzrlib.revisionspec import RevisionSpec
-from bzrlib.errors import BzrCommandError
 
 
 def _parse_revision_str(revstr):
@@ -82,7 +88,7 @@
     revs = []
     sep = re.compile("\\.\\.(?!/)")
     for x in sep.split(revstr):
-        revs.append(RevisionSpec.from_string(x or None))
+        revs.append(revisionspec.RevisionSpec.from_string(x or None))
     return revs
 
 
@@ -100,7 +106,7 @@
         type_list = '\n'.join(lines)
         msg = "No known merge type %s. Supported types are:\n%s" %\
             (typestring, type_list)
-        raise BzrCommandError(msg)
+        raise errors.BzrCommandError(msg)
 
 class Option(object):
     """Description of a command line option"""
@@ -191,7 +197,7 @@
     DEFAULT_VALUE = object()
 
     def error(self, message):
-        raise BzrCommandError(message)
+        raise errors.BzrCommandError(message)
 
 
 def get_optparser(options):

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2006-10-11 23:08:27 +0000
+++ bzrlib/osutils.py	2006-10-16 01:25:46 +0000
@@ -17,6 +17,16 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from cStringIO import StringIO
+import os
+import re
+import stat
+from stat import (S_ISREG, S_ISDIR, S_ISLNK, ST_MODE, ST_SIZE,
+                  S_ISCHR, S_ISBLK, S_ISFIFO, S_ISSOCK)
+import sys
+import time
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import errno
 from ntpath import (abspath as _nt_abspath,
                     join as _nt_join,
@@ -24,32 +34,29 @@
                     realpath as _nt_realpath,
                     splitdrive as _nt_splitdrive,
                     )
-import os
-from os import listdir
 import posixpath
-import re
 import sha
 import shutil
-from shutil import copyfile
-import stat
-from stat import (S_ISREG, S_ISDIR, S_ISLNK, ST_MODE, ST_SIZE,
-                  S_ISCHR, S_ISBLK, S_ISFIFO, S_ISSOCK)
+from shutil import (
+    rmtree,
+    )
 import string
-import sys
-import time
-import types
 import tempfile
+from tempfile import (
+    mkdtemp,
+    )
 import unicodedata
 
+from bzrlib import (
+    errors,
+    )
+""")
+
 import bzrlib
-from bzrlib.errors import (BzrError,
-                           BzrBadParameterNotUnicode,
-                           NoSuchFile,
-                           PathNotChild,
-                           IllegalPath,
-                           )
-from bzrlib.symbol_versioning import (deprecated_function, 
-        zero_nine)
+from bzrlib.symbol_versioning import (
+    deprecated_function,
+    zero_nine,
+    )
 from bzrlib.trace import mutter
 
 
@@ -122,7 +129,7 @@
         return _mapper(_lstat(f).st_mode)
     except OSError, e:
         if getattr(e, 'errno', None) == errno.ENOENT:
-            raise bzrlib.errors.NoSuchFile(f)
+            raise errors.NoSuchFile(f)
         raise
 
 
@@ -144,7 +151,7 @@
     elif kind == 'symlink':
         return '@'
     else:
-        raise BzrError('invalid file kind %r' % kind)
+        raise errors.BzrError('invalid file kind %r' % kind)
 
 lexists = getattr(os.path, 'lexists', None)
 if lexists is None:
@@ -159,7 +166,7 @@
             if e.errno == errno.ENOENT:
                 return False;
             else:
-                raise BzrError("lstat/stat of (%r): %r" % (f, e))
+                raise errors.BzrError("lstat/stat of (%r): %r" % (f, e))
 
 
 def fancy_rename(old, new, rename_func, unlink_func):
@@ -186,7 +193,7 @@
     file_existed = False
     try:
         rename_func(new, tmp_name)
-    except (NoSuchFile,), e:
+    except (errors.NoSuchFile,), e:
         pass
     except IOError, e:
         # RBC 20060103 abstraction leakage: the paramiko SFTP clients rename
@@ -302,11 +309,12 @@
 pathjoin = os.path.join
 normpath = os.path.normpath
 getcwd = os.getcwdu
-mkdtemp = tempfile.mkdtemp
 rename = os.rename
 dirname = os.path.dirname
 basename = os.path.basename
-rmtree = shutil.rmtree
+# These were already imported into local scope
+# mkdtemp = tempfile.mkdtemp
+# rmtree = shutil.rmtree
 
 MIN_ABS_PATHLENGTH = 1
 
@@ -330,7 +338,7 @@
         if function in (os.remove, os.rmdir) \
             and type_ == OSError \
             and value.errno == errno.EACCES:
-            bzrlib.osutils.make_writable(path)
+            make_writable(path)
             function(path)
         else:
             raise
@@ -440,19 +448,6 @@
     
     The empty string as a dir name is taken as top-of-tree and matches 
     everything.
-    
-    >>> is_inside('src', pathjoin('src', 'foo.c'))
-    True
-    >>> is_inside('src', 'srccontrol')
-    False
-    >>> is_inside('src', pathjoin('src', 'a', 'a', 'a', 'foo.c'))
-    True
-    >>> is_inside('foo.c', 'foo.c')
-    True
-    >>> is_inside('foo.c', '')
-    False
-    >>> is_inside('', 'foo.c')
-    True
     """
     # XXX: Most callers of this can actually do something smarter by 
     # looking at the inventory
@@ -581,8 +576,8 @@
         tt = time.localtime(t)
         offset = local_time_offset(t)
     else:
-        raise BzrError("unsupported timezone format %r" % timezone,
-                       ['options are "utc", "original", "local"'])
+        raise errors.BzrError("unsupported timezone format %r" % timezone,
+                              ['options are "utc", "original", "local"'])
     if date_fmt is None:
         date_fmt = "%a %Y-%m-%d %H:%M:%S"
     if show_offset:
@@ -659,10 +654,10 @@
 except (NotImplementedError, AttributeError):
     # If python doesn't have os.urandom, or it doesn't work,
     # then try to first pull random data from /dev/urandom
-    if os.path.exists("/dev/urandom"):
+    try:
         rand_bytes = file('/dev/urandom', 'rb').read
     # Otherwise, use this hack as a last resort
-    else:
+    except (IOError, OSError):
         # not well seeded, but better than nothing
         def rand_bytes(n):
             import random
@@ -690,22 +685,8 @@
 ## decomposition (might be too tricksy though.)
 
 def splitpath(p):
-    """Turn string into list of parts.
-
-    >>> splitpath('a')
-    ['a']
-    >>> splitpath('a/b')
-    ['a', 'b']
-    >>> splitpath('a/./b')
-    ['a', 'b']
-    >>> splitpath('a/.b')
-    ['a', '.b']
-    >>> splitpath('a/../b')
-    Traceback (most recent call last):
-    ...
-    BzrError: sorry, '..' not allowed in path
-    """
-    assert isinstance(p, types.StringTypes)
+    """Turn string into list of parts."""
+    assert isinstance(p, basestring)
 
     # split on either delimiter because people might use either on
     # Windows
@@ -714,7 +695,7 @@
     rps = []
     for f in ps:
         if f == '..':
-            raise BzrError("sorry, %r not allowed in path" % f)
+            raise errors.BzrError("sorry, %r not allowed in path" % f)
         elif (f == '.') or (f == ''):
             pass
         else:
@@ -725,7 +706,7 @@
     assert isinstance(p, list)
     for f in p:
         if (f == '..') or (f is None) or (f == ''):
-            raise BzrError("sorry, %r not allowed in path" % f)
+            raise errors.BzrError("sorry, %r not allowed in path" % f)
     return pathjoin(*p)
 
 
@@ -753,14 +734,14 @@
 def link_or_copy(src, dest):
     """Hardlink a file, or copy it if it can't be hardlinked."""
     if not hardlinks_good():
-        copyfile(src, dest)
+        shutil.copyfile(src, dest)
         return
     try:
         os.link(src, dest)
     except (OSError, IOError), e:
         if e.errno != errno.EXDEV:
             raise
-        copyfile(src, dest)
+        shutil.copyfile(src, dest)
 
 def delete_any(full_path):
     """Delete a file or directory."""
@@ -824,7 +805,7 @@
         if tail:
             s.insert(0, tail)
     else:
-        raise PathNotChild(rp, base)
+        raise errors.PathNotChild(rp, base)
 
     if s:
         return pathjoin(*s)
@@ -845,7 +826,7 @@
     try:
         return unicode_or_utf8_string.decode('utf8')
     except UnicodeDecodeError:
-        raise BzrBadParameterNotUnicode(unicode_or_utf8_string)
+        raise errors.BzrBadParameterNotUnicode(unicode_or_utf8_string)
 
 
 _platform_normalizes_filenames = False
@@ -950,7 +931,7 @@
     if sys.platform != "win32":
         return
     if _validWin32PathRE.match(path) is None:
-        raise IllegalPath(path)
+        raise errors.IllegalPath(path)
 
 
 def walkdirs(top, prefix=""):
@@ -989,7 +970,7 @@
     lstat = os.lstat
     pending = []
     _directory = _directory_kind
-    _listdir = listdir
+    _listdir = os.listdir
     pending = [(prefix, "", _directory, None, top)]
     while pending:
         dirblock = []

=== modified file 'bzrlib/plugin.py'
--- bzrlib/plugin.py	2006-10-11 23:08:27 +0000
+++ bzrlib/plugin.py	2006-10-16 01:25:46 +0000
@@ -39,20 +39,34 @@
 # That could be either a separate Python interpreter or perhaps a new
 # namespace inside this interpreter.
 
-import imp
 import os
 import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+import imp
 import types
 
-import bzrlib
-from bzrlib.config import config_dir
-from bzrlib.trace import log_error, mutter, warning, \
-        log_exception_quietly
-from bzrlib.errors import BzrError
-from bzrlib import plugins
-from bzrlib.osutils import pathjoin
-
-DEFAULT_PLUGIN_PATH = pathjoin(config_dir(), 'plugins')
+from bzrlib import (
+    config,
+    osutils,
+    plugins,
+    )
+""")
+
+from bzrlib.trace import mutter, warning, log_exception_quietly
+
+
+DEFAULT_PLUGIN_PATH = None
+
+
+def get_default_plugin_path():
+    """Get the DEFAULT_PLUGIN_PATH"""
+    global DEFAULT_PLUGIN_PATH
+    if DEFAULT_PLUGIN_PATH is None:
+        DEFAULT_PLUGIN_PATH = osutils.pathjoin(config.config_dir(), 'plugins')
+    return DEFAULT_PLUGIN_PATH
+
 
 _loaded = False
 
@@ -60,7 +74,7 @@
 def all_plugins():
     """Return a dictionary of the plugins."""
     result = {}
-    for name, plugin in bzrlib.plugins.__dict__.items():
+    for name, plugin in plugins.__dict__.items():
         if isinstance(plugin, types.ModuleType):
             result[name] = plugin
     return result
@@ -92,10 +106,10 @@
     if _loaded:
         # People can make sure plugins are loaded, they just won't be twice
         return
-        #raise BzrError("plugins already initialized")
     _loaded = True
 
-    dirs = os.environ.get('BZR_PLUGIN_PATH', DEFAULT_PLUGIN_PATH).split(os.pathsep)
+    dirs = os.environ.get('BZR_PLUGIN_PATH',
+                          get_default_plugin_path()).split(os.pathsep)
     dirs.insert(0, os.path.dirname(plugins.__file__))
 
     load_from_dirs(dirs)
@@ -125,12 +139,12 @@
         if not os.path.isdir(d):
             continue
         for f in os.listdir(d):
-            path = pathjoin(d, f)
+            path = osutils.pathjoin(d, f)
             if os.path.isdir(path):
                 for entry in package_entries:
                     # This directory should be a package, and thus added to
                     # the list
-                    if os.path.isfile(pathjoin(path, entry)):
+                    if os.path.isfile(osutils.pathjoin(path, entry)):
                         break
                 else: # This directory is not a package
                     continue
@@ -143,7 +157,7 @@
                         break
                 else:
                     continue
-            if getattr(bzrlib.plugins, f, None):
+            if getattr(plugins, f, None):
                 mutter('Plugin name %s already loaded', f)
             else:
                 mutter('add plugin name %s', f)
@@ -158,7 +172,7 @@
                 try:
                     plugin = imp.load_module('bzrlib.plugins.' + name,
                                              *plugin_info)
-                    setattr(bzrlib.plugins, name, plugin)
+                    setattr(plugins, name, plugin)
                 finally:
                     if plugin_info[0] is not None:
                         plugin_info[0].close()

=== modified file 'bzrlib/progress.py'
--- bzrlib/progress.py	2006-10-05 05:37:25 +0000
+++ bzrlib/progress.py	2006-10-16 01:25:46 +0000
@@ -35,12 +35,17 @@
 # TODO: Optionally show elapsed time instead/as well as ETA; nicer
 # when the rate is unpredictable
 
-
 import sys
 import time
 import os
 
-import bzrlib.errors as errors
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+from bzrlib import (
+    errors,
+    )
+""")
+
 from bzrlib.trace import mutter
 
 

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2006-09-27 20:27:46 +0000
+++ bzrlib/repository.py	2006-10-06 05:53:44 +0000
@@ -14,47 +14,55 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from cStringIO import StringIO
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 from binascii import hexlify
 from copy import deepcopy
-from cStringIO import StringIO
 import re
 import time
-from unittest import TestSuite
+import unittest
 
 from bzrlib import (
-    bzrdir, 
-    check, 
-    delta, 
-    gpg, 
-    errors, 
+    bzrdir,
+    check,
+    delta,
+    errors,
+    gpg,
+    graph,
+    knit,
+    lockable_files,
+    lockdir,
     osutils,
+    revision as _mod_revision,
+    symbol_versioning,
     transactions,
-    ui, 
-    xml5, 
+    ui,
+    weave,
+    weavefile,
+    xml5,
     xml6,
     )
+from bzrlib.osutils import (
+    rand_bytes,
+    compact_date, 
+    local_time_offset,
+    )
+from bzrlib.revisiontree import RevisionTree
+from bzrlib.store.versioned import VersionedFileStore
+from bzrlib.store.text import TextStore
+from bzrlib.testament import Testament
+""")
+
 from bzrlib.decorators import needs_read_lock, needs_write_lock
-from bzrlib.errors import InvalidRevisionId
-from bzrlib.graph import Graph
 from bzrlib.inter import InterObject
 from bzrlib.inventory import Inventory, InventoryDirectory, ROOT_ID
-from bzrlib.knit import KnitVersionedFile, KnitPlainFactory
-from bzrlib.lockable_files import LockableFiles, TransportLock
-from bzrlib.lockdir import LockDir
-from bzrlib.osutils import (safe_unicode, rand_bytes, compact_date, 
-                            local_time_offset)
-from bzrlib.revision import NULL_REVISION, Revision
-from bzrlib.revisiontree import RevisionTree
-from bzrlib.store.versioned import VersionedFileStore, WeaveStore
-from bzrlib.store.text import TextStore
-from bzrlib import symbol_versioning
-from bzrlib.symbol_versioning import (deprecated_method,
-        zero_nine, 
+from bzrlib.symbol_versioning import (
+        deprecated_method,
+        zero_nine,
         )
-from bzrlib.testament import Testament
 from bzrlib.trace import mutter, note, warning
-from bzrlib.tsort import topo_sort
-from bzrlib.weave import WeaveFile
 
 
 # Old formats display a warning, but only once
@@ -317,7 +325,8 @@
         or testing the revision graph.
         """
         if not revision_id or not isinstance(revision_id, basestring):
-            raise InvalidRevisionId(revision_id=revision_id, branch=self)
+            raise errors.InvalidRevisionId(revision_id=revision_id,
+                                           branch=self)
         return self._revision_store.get_revisions([revision_id],
                                                   self.get_transaction())[0]
     @needs_read_lock
@@ -497,11 +506,12 @@
         :return: a dictionary of revision_id->revision_parents_list.
         """
         # special case NULL_REVISION
-        if revision_id == NULL_REVISION:
+        if revision_id == _mod_revision.NULL_REVISION:
             return {}
-        weave = self.get_inventory_weave()
-        all_revisions = self._eliminate_revisions_not_present(weave.versions())
-        entire_graph = dict([(node, weave.get_parents(node)) for 
+        a_weave = self.get_inventory_weave()
+        all_revisions = self._eliminate_revisions_not_present(
+                                a_weave.versions())
+        entire_graph = dict([(node, a_weave.get_parents(node)) for 
                              node in all_revisions])
         if revision_id is None:
             return entire_graph
@@ -526,15 +536,15 @@
         :param revision_ids: an iterable of revisions to graph or None for all.
         :return: a Graph object with the graph reachable from revision_ids.
         """
-        result = Graph()
+        result = graph.Graph()
         if not revision_ids:
             pending = set(self.all_revision_ids())
             required = set([])
         else:
             pending = set(revision_ids)
             # special case NULL_REVISION
-            if NULL_REVISION in pending:
-                pending.remove(NULL_REVISION)
+            if _mod_revision.NULL_REVISION in pending:
+                pending.remove(_mod_revision.NULL_REVISION)
             required = set(pending)
         done = set([])
         while len(pending):
@@ -594,8 +604,8 @@
         """
         # TODO: refactor this to use an existing revision object
         # so we don't need to read it in twice.
-        if revision_id is None or revision_id == NULL_REVISION:
-            return RevisionTree(self, Inventory(), NULL_REVISION)
+        if revision_id is None or revision_id == _mod_revision.NULL_REVISION:
+            return RevisionTree(self, Inventory(), _mod_revision.NULL_REVISION)
         else:
             inv = self.get_revision_inventory(revision_id)
             return RevisionTree(self, inv, revision_id)
@@ -606,7 +616,7 @@
 
         `revision_id` may not be None or 'null:'"""
         assert None not in revision_ids
-        assert NULL_REVISION not in revision_ids
+        assert _mod_revision.NULL_REVISION not in revision_ids
         texts = self.get_inventory_weave().get_texts(revision_ids)
         for text, revision_id in zip(texts, revision_ids):
             inv = self.deserialise_inventory(revision_id, text)
@@ -933,13 +943,13 @@
         :return: a dictionary of revision_id->revision_parents_list.
         """
         # special case NULL_REVISION
-        if revision_id == NULL_REVISION:
+        if revision_id == _mod_revision.NULL_REVISION:
             return {}
-        weave = self._get_revision_vf()
-        entire_graph = weave.get_graph()
+        a_weave = self._get_revision_vf()
+        entire_graph = a_weave.get_graph()
         if revision_id is None:
-            return weave.get_graph()
-        elif revision_id not in weave:
+            return a_weave.get_graph()
+        elif revision_id not in a_weave:
             raise errors.NoSuchRevision(self, revision_id)
         else:
             # add what can be reached from revision_id
@@ -947,7 +957,7 @@
             pending = set([revision_id])
             while len(pending) > 0:
                 node = pending.pop()
-                result[node] = weave.get_parents(node)
+                result[node] = a_weave.get_parents(node)
                 for revision_id in result[node]:
                     if revision_id not in result:
                         pending.add(revision_id)
@@ -960,7 +970,7 @@
         :param revision_ids: an iterable of revisions to graph or None for all.
         :return: a Graph object with the graph reachable from revision_ids.
         """
-        result = Graph()
+        result = graph.Graph()
         vf = self._get_revision_vf()
         versions = set(vf.versions())
         if not revision_ids:
@@ -969,8 +979,8 @@
         else:
             pending = set(revision_ids)
             # special case NULL_REVISION
-            if NULL_REVISION in pending:
-                pending.remove(NULL_REVISION)
+            if _mod_revision.NULL_REVISION in pending:
+                pending.remove(_mod_revision.NULL_REVISION)
             required = set(pending)
         done = set([])
         while len(pending):
@@ -1155,7 +1165,7 @@
                                   transport,
                                   control_files,
                                   prefixed=True,
-                                  versionedfile_class=WeaveFile,
+                                  versionedfile_class=weave.WeaveFile,
                                   versionedfile_kwargs={},
                                   escaped=False):
         weave_transport = control_files._transport.clone(name)
@@ -1222,9 +1232,6 @@
         TODO: when creating split out bzr branch formats, move this to a common
         base for Format5, Format6. or something like that.
         """
-        from bzrlib.weavefile import write_weave_v5
-        from bzrlib.weave import Weave
-
         if shared:
             raise errors.IncompatibleFormat(self, a_bzrdir._format)
 
@@ -1234,7 +1241,7 @@
         
         # Create an empty weave
         sio = StringIO()
-        write_weave_v5(Weave(), sio)
+        weavefile.write_weave_v5(weave.Weave(), sio)
         empty_weave = sio.getvalue()
 
         mutter('creating repository in %s.', a_bzrdir.transport.base)
@@ -1244,8 +1251,8 @@
         
         # FIXME: RBC 20060125 don't peek under the covers
         # NB: no need to escape relative paths that are url safe.
-        control_files = LockableFiles(a_bzrdir.transport, 'branch-lock',
-                                      TransportLock)
+        control_files = lockable_files.LockableFiles(a_bzrdir.transport,
+                                'branch-lock', lockable_files.TransportLock)
         control_files.create_lock()
         control_files.lock_write()
         control_files._transport.mkdir_multi(dirs,
@@ -1415,7 +1422,8 @@
         # FIXME: RBC 20060125 don't peek under the covers
         # NB: no need to escape relative paths that are url safe.
         repository_transport = a_bzrdir.get_repository_transport(self)
-        control_files = LockableFiles(repository_transport, 'lock', LockDir)
+        control_files = lockable_files.LockableFiles(repository_transport,
+                                'lock', lockdir.LockDir)
         control_files.create_lock()
         return control_files
 
@@ -1487,12 +1495,9 @@
         :param shared: If true the repository will be initialized as a shared
                        repository.
         """
-        from bzrlib.weavefile import write_weave_v5
-        from bzrlib.weave import Weave
-
         # Create an empty weave
         sio = StringIO()
-        write_weave_v5(Weave(), sio)
+        weavefile.write_weave_v5(weave.Weave(), sio)
         empty_weave = sio.getvalue()
 
         mutter('creating repository in %s.', a_bzrdir.transport.base)
@@ -1518,7 +1523,8 @@
             repo_transport = _override_transport
         else:
             repo_transport = a_bzrdir.get_repository_transport(None)
-        control_files = LockableFiles(repo_transport, 'lock', LockDir)
+        control_files = lockable_files.LockableFiles(repo_transport,
+                                'lock', lockdir.LockDir)
         text_store = self._get_text_store(repo_transport, control_files)
         control_store = self._get_control_store(repo_transport, control_files)
         _revision_store = self._get_revision_store(repo_transport, control_files)
@@ -1550,8 +1556,8 @@
             repo_transport,
             prefixed=False,
             file_mode=control_files._file_mode,
-            versionedfile_class=KnitVersionedFile,
-            versionedfile_kwargs={'factory':KnitPlainFactory()},
+            versionedfile_class=knit.KnitVersionedFile,
+            versionedfile_kwargs={'factory':knit.KnitPlainFactory()},
             )
 
     def _get_revision_store(self, repo_transport, control_files):
@@ -1562,8 +1568,10 @@
             file_mode=control_files._file_mode,
             prefixed=False,
             precious=True,
-            versionedfile_class=KnitVersionedFile,
-            versionedfile_kwargs={'delta':False, 'factory':KnitPlainFactory(),},
+            versionedfile_class=knit.KnitVersionedFile,
+            versionedfile_kwargs={'delta':False,
+                                  'factory':knit.KnitPlainFactory(),
+                                 },
             escaped=True,
             )
         return KnitRevisionStore(versioned_file_store)
@@ -1571,15 +1579,15 @@
     def _get_text_store(self, transport, control_files):
         """See RepositoryFormat._get_text_store()."""
         return self._get_versioned_file_store('knits',
-                                              transport,
-                                              control_files,
-                                              versionedfile_class=KnitVersionedFile,
-                                              versionedfile_kwargs={
-                                                  'create_parent_dir':True,
-                                                  'delay_create':True,
-                                                  'dir_mode':control_files._dir_mode,
-                                              },
-                                              escaped=True)
+                                  transport,
+                                  control_files,
+                                  versionedfile_class=knit.KnitVersionedFile,
+                                  versionedfile_kwargs={
+                                      'create_parent_dir':True,
+                                      'delay_create':True,
+                                      'dir_mode':control_files._dir_mode,
+                                  },
+                                  escaped=True)
 
     def initialize(self, a_bzrdir, shared=False):
         """Create a knit format 1 repository.
@@ -1596,7 +1604,8 @@
         
         self._upload_blank_content(a_bzrdir, dirs, files, utf8_files, shared)
         repo_transport = a_bzrdir.get_repository_transport(None)
-        control_files = LockableFiles(repo_transport, 'lock', LockDir)
+        control_files = lockable_files.LockableFiles(repo_transport,
+                                'lock', lockdir.LockDir)
         control_store = self._get_control_store(repo_transport, control_files)
         transaction = transactions.WriteTransaction()
         # trigger a write of the inventory store.
@@ -1620,7 +1629,8 @@
             repo_transport = _override_transport
         else:
             repo_transport = a_bzrdir.get_repository_transport(None)
-        control_files = LockableFiles(repo_transport, 'lock', LockDir)
+        control_files = lockable_files.LockableFiles(repo_transport,
+                                'lock', lockdir.LockDir)
         text_store = self._get_text_store(repo_transport, control_files)
         control_store = self._get_control_store(repo_transport, control_files)
         _revision_store = self._get_revision_store(repo_transport, control_files)
@@ -1705,7 +1715,8 @@
             repo_transport = _override_transport
         else:
             repo_transport = a_bzrdir.get_repository_transport(None)
-        control_files = LockableFiles(repo_transport, 'lock', LockDir)
+        control_files = lockable_files.LockableFiles(repo_transport, 'lock',
+                                                     lockdir.LockDir)
         text_store = self._get_text_store(repo_transport, control_files)
         control_store = self._get_control_store(repo_transport, control_files)
         _revision_store = self._get_revision_store(repo_transport, control_files)
@@ -1826,7 +1837,7 @@
         if basis is not None:
             self.target.fetch(basis, revision_id=revision_id)
         # but don't bother fetching if we have the needed data now.
-        if (revision_id not in (None, NULL_REVISION) and 
+        if (revision_id not in (None, _mod_revision.NULL_REVISION) and 
             self.target.has_revision(revision_id)):
             return
         self.target.fetch(self.source, revision_id=revision_id)
@@ -2070,7 +2081,7 @@
         if basis is not None:
             self.target.fetch(basis, revision_id=revision_id)
         # but don't bother fetching if we have the needed data now.
-        if (revision_id not in (None, NULL_REVISION) and 
+        if (revision_id not in (None, _mod_revision.NULL_REVISION) and 
             self.target.has_revision(revision_id)):
             return
         self.target.fetch(self.source, revision_id=revision_id)
@@ -2125,7 +2136,7 @@
         self._formats = formats
     
     def adapt(self, test):
-        result = TestSuite()
+        result = unittest.TestSuite()
         for repository_format, bzrdir_format in self._formats:
             new_test = deepcopy(test)
             new_test.transport_server = self._transport_server
@@ -2155,7 +2166,7 @@
         self._formats = formats
     
     def adapt(self, test):
-        result = TestSuite()
+        result = unittest.TestSuite()
         for interrepo_class, repository_format, repository_format_to in self._formats:
             new_test = deepcopy(test)
             new_test.transport_server = self._transport_server
@@ -2304,7 +2315,8 @@
 
         :return: The revision id of the recorded revision.
         """
-        rev = Revision(timestamp=self._timestamp,
+        rev = _mod_revision.Revision(
+                       timestamp=self._timestamp,
                        timezone=self._timezone,
                        committer=self._committer,
                        message=message,

=== modified file 'bzrlib/sign_my_commits.py'
--- bzrlib/sign_my_commits.py	2006-07-28 16:05:23 +0000
+++ bzrlib/sign_my_commits.py	2006-09-13 02:44:23 +0000
@@ -17,9 +17,15 @@
 """Command which looks for unsigned commits by the current user, and signs them.
 """
 
-from bzrlib import config, gpg
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+from bzrlib import (
+    config,
+    gpg,
+    )
+from bzrlib.bzrdir import BzrDir
+""")
 from bzrlib.commands import Command
-from bzrlib.bzrdir import BzrDir
 from bzrlib.option import Option
 
 

=== modified file 'bzrlib/store/revision/__init__.py'
--- bzrlib/store/revision/__init__.py	2006-10-11 23:08:27 +0000
+++ bzrlib/store/revision/__init__.py	2006-10-16 01:25:46 +0000
@@ -21,14 +21,19 @@
 and ghosts information.
 """
 
+from cStringIO import StringIO
 
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 from copy import deepcopy
-from cStringIO import StringIO
-from unittest import TestSuite
-
+import unittest
 
 import bzrlib
-import bzrlib.errors as errors
+from bzrlib import (
+    errors,
+    xml5,
+    )
+""")
 from bzrlib.trace import mutter
 
 
@@ -47,7 +52,7 @@
         self._factories = factories
     
     def adapt(self, test):
-        result = TestSuite()
+        result = unittest.TestSuite()
         for factory in self._factories:
             new_test = deepcopy(test)
             new_test.transport_server = self._transport_server
@@ -77,7 +82,7 @@
 
     def __init__(self, serializer=None):
         if serializer is None:
-            serializer = bzrlib.xml5.serializer_v5
+            serializer = xml5.serializer_v5
         self._serializer = serializer
 
     def add_revision(self, revision, transaction):

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/__init__.py	2006-10-16 01:25:46 +0000
@@ -71,6 +71,7 @@
 from bzrlib.transport import get_transport
 import bzrlib.transport
 from bzrlib.transport.local import LocalRelpathServer
+from bzrlib.transport.memory import MemoryServer
 from bzrlib.transport.readonly import ReadonlyServer
 from bzrlib.trace import mutter
 from bzrlib.tests import TestUtil
@@ -86,9 +87,7 @@
 
 MODULES_TO_TEST = []
 MODULES_TO_DOCTEST = [
-                      bzrlib.branch,
                       bzrlib.bundle.serializer,
-                      bzrlib.commands,
                       bzrlib.errors,
                       bzrlib.export,
                       bzrlib.inventory,
@@ -96,9 +95,7 @@
                       bzrlib.lockdir,
                       bzrlib.merge3,
                       bzrlib.option,
-                      bzrlib.osutils,
                       bzrlib.store,
-                      bzrlib.transport,
                       ]
 
 
@@ -394,7 +391,7 @@
         # This is still a little bogus, 
         # but only a little. Folk not using our testrunner will
         # have to delete their temp directories themselves.
-        test_root = TestCaseInTempDir.TEST_ROOT
+        test_root = TestCaseWithMemoryTransport.TEST_ROOT
         if result.wasSuccessful() or not self.keep_output:
             if test_root is not None:
                 # If LANG=C we probably have created some bogus paths
@@ -418,7 +415,7 @@
                 self.stream.writeln(
                     "Failed tests working directories are in '%s'\n" %
                     test_root)
-        TestCaseInTempDir.TEST_ROOT = None
+        TestCaseWithMemoryTransport.TEST_ROOT = None
         if self.pb is not None:
             self.pb.clear()
         return result
@@ -703,6 +700,7 @@
 
     def _cleanEnvironment(self):
         new_env = {
+            'BZR_HOME': None, # Don't inherit BZR_HOME to all the tests.
             'HOME': os.getcwd(),
             'APPDATA': os.getcwd(),
             'BZR_EMAIL': None,
@@ -1107,8 +1105,213 @@
 
 BzrTestBase = TestCase
 
+
+class TestCaseWithMemoryTransport(TestCase):
+    """Common test class for tests that do not need disk resources.
+
+    Tests that need disk resources should derive from TestCaseWithTransport.
+
+    TestCaseWithMemoryTransport sets the TEST_ROOT variable for all bzr tests.
+
+    For TestCaseWithMemoryTransport the test_home_dir is set to the name of
+    a directory which does not exist. This serves to help ensure test isolation
+    is preserved. test_dir is set to the TEST_ROOT, as is cwd, because they
+    must exist. However, TestCaseWithMemoryTransport does not offer local
+    file defaults for the transport in tests, nor does it obey the command line
+    override, so tests that accidentally write to the common directory should
+    be rare.
+    """
+
+    TEST_ROOT = None
+    _TEST_NAME = 'test'
+
+
+    def __init__(self, methodName='runTest'):
+        # allow test parameterisation after test construction and before test
+        # execution. Variables that the parameteriser sets need to be 
+        # ones that are not set by setUp, or setUp will trash them.
+        super(TestCaseWithMemoryTransport, self).__init__(methodName)
+        self.transport_server = default_transport
+        self.transport_readonly_server = None
+
+    def failUnlessExists(self, path):
+        """Fail unless path, which may be abs or relative, exists."""
+        self.failUnless(osutils.lexists(path))
+
+    def failIfExists(self, path):
+        """Fail if path, which may be abs or relative, exists."""
+        self.failIf(osutils.lexists(path))
+        
+    def get_transport(self):
+        """Return a writeable transport for the test scratch space"""
+        t = get_transport(self.get_url())
+        self.assertFalse(t.is_readonly())
+        return t
+
+    def get_readonly_transport(self):
+        """Return a readonly transport for the test scratch space
+        
+        This can be used to test that operations which should only need
+        readonly access in fact do not try to write.
+        """
+        t = get_transport(self.get_readonly_url())
+        self.assertTrue(t.is_readonly())
+        return t
+
+    def get_readonly_server(self):
+        """Get the server instance for the readonly transport
+
+        This is useful for some tests with specific servers to do diagnostics.
+        """
+        if self.__readonly_server is None:
+            if self.transport_readonly_server is None:
+                # readonly decorator requested
+                # bring up the server
+                self.get_url()
+                self.__readonly_server = ReadonlyServer()
+                self.__readonly_server.setUp(self.__server)
+            else:
+                self.__readonly_server = self.transport_readonly_server()
+                self.__readonly_server.setUp()
+            self.addCleanup(self.__readonly_server.tearDown)
+        return self.__readonly_server
+
+    def get_readonly_url(self, relpath=None):
+        """Get a URL for the readonly transport.
+
+        This will either be backed by '.' or a decorator to the transport 
+        used by self.get_url()
+        relpath provides for clients to get a path relative to the base url.
+        These should only be downwards relative, not upwards.
+        """
+        base = self.get_readonly_server().get_url()
+        if relpath is not None:
+            if not base.endswith('/'):
+                base = base + '/'
+            base = base + relpath
+        return base
+
+    def get_server(self):
+        """Get the read/write server instance.
+
+        This is useful for some tests with specific servers that need
+        diagnostics.
+
+        For TestCaseWithMemoryTransport this is always a MemoryServer, and there
+        is no means to override it.
+        """
+        if self.__server is None:
+            self.__server = MemoryServer()
+            self.__server.setUp()
+            self.addCleanup(self.__server.tearDown)
+        return self.__server
+
+    def get_url(self, relpath=None):
+        """Get a URL (or maybe a path) for the readwrite transport.
+
+        This will either be backed by '.' or to an equivalent non-file based
+        facility.
+        relpath provides for clients to get a path relative to the base url.
+        These should only be downwards relative, not upwards.
+        """
+        base = self.get_server().get_url()
+        if relpath is not None and relpath != '.':
+            if not base.endswith('/'):
+                base = base + '/'
+            # XXX: Really base should be a url; we did after all call
+            # get_url()!  But sometimes it's just a path (from
+            # LocalAbspathServer), and it'd be wrong to append urlescaped data
+            # to a non-escaped local path.
+            if base.startswith('./') or base.startswith('/'):
+                base += relpath
+            else:
+                base += urlutils.escape(relpath)
+        return base
+
+    def _make_test_root(self):
+        if TestCaseWithMemoryTransport.TEST_ROOT is not None:
+            return
+        i = 0
+        while True:
+            root = u'test%04d.tmp' % i
+            try:
+                os.mkdir(root)
+            except OSError, e:
+                if e.errno == errno.EEXIST:
+                    i += 1
+                    continue
+                else:
+                    raise
+            # successfully created
+            TestCaseWithMemoryTransport.TEST_ROOT = osutils.abspath(root)
+            break
+        # make a fake bzr directory there to prevent any tests propagating
+        # up onto the source directory's real branch
+        bzrdir.BzrDir.create_standalone_workingtree(
+            TestCaseWithMemoryTransport.TEST_ROOT)
+
+    def makeAndChdirToTestDir(self):
+        """Create a temporary directories for this one test.
+        
+        This must set self.test_home_dir and self.test_dir and chdir to
+        self.test_dir.
+        
+        For TestCaseWithMemoryTransport we chdir to the TEST_ROOT for this test.
+        """
+        os.chdir(TestCaseWithMemoryTransport.TEST_ROOT)
+        self.test_dir = TestCaseWithMemoryTransport.TEST_ROOT
+        self.test_home_dir = self.test_dir + "/MemoryTransportMissingHomeDir"
+        
+    def make_branch(self, relpath, format=None):
+        """Create a branch on the transport at relpath."""
+        repo = self.make_repository(relpath, format=format)
+        return repo.bzrdir.create_branch()
+
+    def make_bzrdir(self, relpath, format=None):
+        try:
+            # might be a relative or absolute path
+            maybe_a_url = self.get_url(relpath)
+            segments = maybe_a_url.rsplit('/', 1)
+            t = get_transport(maybe_a_url)
+            if len(segments) > 1 and segments[-1] not in ('', '.'):
+                try:
+                    t.mkdir('.')
+                except errors.FileExists:
+                    pass
+            if format is None:
+                format = bzrlib.bzrdir.BzrDirFormat.get_default_format()
+            return format.initialize_on_transport(t)
+        except errors.UninitializableFormat:
+            raise TestSkipped("Format %s is not initializable." % format)
+
+    def make_repository(self, relpath, shared=False, format=None):
+        """Create a repository on our default transport at relpath."""
+        made_control = self.make_bzrdir(relpath, format=format)
+        return made_control.create_repository(shared=shared)
+
+    def make_branch_and_memory_tree(self, relpath):
+        """Create a branch on the default transport and a MemoryTree for it."""
+        b = self.make_branch(relpath)
+        return memorytree.MemoryTree.create_on_branch(b)
+
+    def overrideEnvironmentForTesting(self):
+        os.environ['HOME'] = self.test_home_dir
+        os.environ['APPDATA'] = self.test_home_dir
+        
+    def setUp(self):
+        super(TestCaseWithMemoryTransport, self).setUp()
+        self._make_test_root()
+        _currentdir = os.getcwdu()
+        def _leaveDirectory():
+            os.chdir(_currentdir)
+        self.addCleanup(_leaveDirectory)
+        self.makeAndChdirToTestDir()
+        self.overrideEnvironmentForTesting()
+        self.__readonly_server = None
+        self.__server = None
+
      
-class TestCaseInTempDir(TestCase):
+class TestCaseInTempDir(TestCaseWithMemoryTransport):
     """Derived class that runs a test within a temporary directory.
 
     This is useful for tests that need to create a branch, etc.
@@ -1121,8 +1324,6 @@
     InTempDir is an old alias for FunctionalTestCase.
     """
 
-    TEST_ROOT = None
-    _TEST_NAME = 'test'
     OVERRIDE_PYTHON = 'python'
 
     def check_file_contents(self, filename, expect):
@@ -1133,31 +1334,12 @@
             self.log("actually: %r" % contents)
             self.fail("contents of %s not as expected" % filename)
 
-    def _make_test_root(self):
-        if TestCaseInTempDir.TEST_ROOT is not None:
-            return
-        i = 0
-        while True:
-            root = u'test%04d.tmp' % i
-            try:
-                os.mkdir(root)
-            except OSError, e:
-                if e.errno == errno.EEXIST:
-                    i += 1
-                    continue
-                else:
-                    raise
-            # successfully created
-            TestCaseInTempDir.TEST_ROOT = osutils.abspath(root)
-            break
-        # make a fake bzr directory there to prevent any tests propagating
-        # up onto the source directory's real branch
-        bzrdir.BzrDir.create_standalone_workingtree(TestCaseInTempDir.TEST_ROOT)
-
-    def setUp(self):
-        super(TestCaseInTempDir, self).setUp()
-        self._make_test_root()
-        _currentdir = os.getcwdu()
+    def makeAndChdirToTestDir(self):
+        """See TestCaseWithMemoryTransport.makeAndChdirToTestDir().
+        
+        For TestCaseInTempDir we create a temporary directory based on the test
+        name and then create two subdirs - test and home under it.
+        """
         # shorten the name, to avoid test failures due to path length
         short_id = self.id().replace('bzrlib.tests.', '') \
                    .replace('__main__.', '')[-100:]
@@ -1180,12 +1362,7 @@
                 os.mkdir(self.test_dir)
                 os.chdir(self.test_dir)
                 break
-        os.environ['HOME'] = self.test_home_dir
-        os.environ['APPDATA'] = self.test_home_dir
-        def _leaveDirectory():
-            os.chdir(_currentdir)
-        self.addCleanup(_leaveDirectory)
-        
+
     def build_tree(self, shape, line_endings='native', transport=None):
         """Build a test tree according to a pattern.
 
@@ -1232,14 +1409,6 @@
     def build_tree_contents(self, shape):
         build_tree_contents(shape)
 
-    def failUnlessExists(self, path):
-        """Fail unless path, which may be abs or relative, exists."""
-        self.failUnless(osutils.lexists(path))
-
-    def failIfExists(self, path):
-        """Fail if path, which may be abs or relative, exists."""
-        self.failIf(osutils.lexists(path))
-        
     def assertFileEqual(self, content, path):
         """Fail if path does not contain 'content'."""
         self.failUnless(osutils.lexists(path))
@@ -1261,48 +1430,8 @@
     readwrite one must both define get_url() as resolving to os.getcwd().
     """
 
-    def __init__(self, methodName='testMethod'):
-        super(TestCaseWithTransport, self).__init__(methodName)
-        self.__readonly_server = None
-        self.__server = None
-        self.transport_server = default_transport
-        self.transport_readonly_server = None
-
-    def get_readonly_url(self, relpath=None):
-        """Get a URL for the readonly transport.
-
-        This will either be backed by '.' or a decorator to the transport 
-        used by self.get_url()
-        relpath provides for clients to get a path relative to the base url.
-        These should only be downwards relative, not upwards.
-        """
-        base = self.get_readonly_server().get_url()
-        if relpath is not None:
-            if not base.endswith('/'):
-                base = base + '/'
-            base = base + relpath
-        return base
-
-    def get_readonly_server(self):
-        """Get the server instance for the readonly transport
-
-        This is useful for some tests with specific servers to do diagnostics.
-        """
-        if self.__readonly_server is None:
-            if self.transport_readonly_server is None:
-                # readonly decorator requested
-                # bring up the server
-                self.get_url()
-                self.__readonly_server = ReadonlyServer()
-                self.__readonly_server.setUp(self.__server)
-            else:
-                self.__readonly_server = self.transport_readonly_server()
-                self.__readonly_server.setUp()
-            self.addCleanup(self.__readonly_server.tearDown)
-        return self.__readonly_server
-
     def get_server(self):
-        """Get the read/write server instance.
+        """See TestCaseWithMemoryTransport.
 
         This is useful for some tests with specific servers that need
         diagnostics.
@@ -1313,76 +1442,6 @@
             self.addCleanup(self.__server.tearDown)
         return self.__server
 
-    def get_url(self, relpath=None):
-        """Get a URL (or maybe a path) for the readwrite transport.
-
-        This will either be backed by '.' or to an equivalent non-file based
-        facility.
-        relpath provides for clients to get a path relative to the base url.
-        These should only be downwards relative, not upwards.
-        """
-        base = self.get_server().get_url()
-        if relpath is not None and relpath != '.':
-            if not base.endswith('/'):
-                base = base + '/'
-            # XXX: Really base should be a url; we did after all call
-            # get_url()!  But sometimes it's just a path (from
-            # LocalAbspathServer), and it'd be wrong to append urlescaped data
-            # to a non-escaped local path.
-            if base.startswith('./') or base.startswith('/'):
-                base += relpath
-            else:
-                base += urlutils.escape(relpath)
-        return base
-
-    def get_transport(self):
-        """Return a writeable transport for the test scratch space"""
-        t = get_transport(self.get_url())
-        self.assertFalse(t.is_readonly())
-        return t
-
-    def get_readonly_transport(self):
-        """Return a readonly transport for the test scratch space
-        
-        This can be used to test that operations which should only need
-        readonly access in fact do not try to write.
-        """
-        t = get_transport(self.get_readonly_url())
-        self.assertTrue(t.is_readonly())
-        return t
-
-    def make_branch(self, relpath, format=None):
-        """Create a branch on the transport at relpath."""
-        repo = self.make_repository(relpath, format=format)
-        return repo.bzrdir.create_branch()
-
-    def make_bzrdir(self, relpath, format=None):
-        try:
-            # might be a relative or absolute path
-            maybe_a_url = self.get_url(relpath)
-            segments = maybe_a_url.rsplit('/', 1)
-            t = get_transport(maybe_a_url)
-            if len(segments) > 1 and segments[-1] not in ('', '.'):
-                try:
-                    t.mkdir('.')
-                except errors.FileExists:
-                    pass
-            if format is None:
-                format = bzrlib.bzrdir.BzrDirFormat.get_default_format()
-            return format.initialize_on_transport(t)
-        except errors.UninitializableFormat:
-            raise TestSkipped("Format %s is not initializable." % format)
-
-    def make_repository(self, relpath, shared=False, format=None):
-        """Create a repository on our default transport at relpath."""
-        made_control = self.make_bzrdir(relpath, format=format)
-        return made_control.create_repository(shared=shared)
-
-    def make_branch_and_memory_tree(self, relpath):
-        """Create a branch on the default transport and a MemoryTree for it."""
-        b = self.make_branch(relpath)
-        return memorytree.MemoryTree.create_on_branch(b)
-
     def make_branch_and_tree(self, relpath, format=None):
         """Create a branch on the transport and a tree locally.
 
@@ -1430,6 +1489,11 @@
             self.fail("path %s is not a directory; has mode %#o"
                       % (relpath, mode))
 
+    def setUp(self):
+        super(TestCaseWithTransport, self).setUp()
+        self.__server = None
+        self.transport_server = default_transport
+
 
 class ChrootedTestCase(TestCaseWithTransport):
     """A support class that provides readonly urls outside the local namespace.
@@ -1461,7 +1525,6 @@
 def run_suite(suite, name='test', verbose=False, pattern=".*",
               stop_on_failure=False, keep_output=False,
               transport=None, lsprof_timed=None, bench_history=None):
-    TestCaseInTempDir._TEST_NAME = name
     TestCase._gather_lsprof_in_benchmarks = lsprof_timed
     if verbose:
         verbosity = 2
@@ -1551,6 +1614,7 @@
                    'bzrlib.tests.test_inv',
                    'bzrlib.tests.test_knit',
                    'bzrlib.tests.test_lazy_import',
+                   'bzrlib.tests.test_lazy_regex',
                    'bzrlib.tests.test_lockdir',
                    'bzrlib.tests.test_lockable_files',
                    'bzrlib.tests.test_log',
@@ -1622,7 +1686,11 @@
     for m in MODULES_TO_TEST:
         suite.addTest(loader.loadTestsFromModule(m))
     for m in MODULES_TO_DOCTEST:
-        suite.addTest(doctest.DocTestSuite(m))
+        try:
+            suite.addTest(doctest.DocTestSuite(m))
+        except ValueError, e:
+            print '**failed to get doctest for: %s\n%s' %(m,e)
+            raise
     for name, plugin in bzrlib.plugin.all_plugins().items():
         if getattr(plugin, 'test_suite', None) is not None:
             suite.addTest(plugin.test_suite())

=== modified file 'bzrlib/tests/blackbox/test_ignore.py'
--- bzrlib/tests/blackbox/test_ignore.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/blackbox/test_ignore.py	2006-10-16 01:25:46 +0000
@@ -22,7 +22,10 @@
 import re
 import sys
 
-from bzrlib import ignores
+from bzrlib import (
+    ignores,
+    osutils,
+    )
 import bzrlib
 from bzrlib.branch import Branch
 import bzrlib.bzrdir as bzrdir
@@ -30,7 +33,6 @@
 from bzrlib.osutils import (
     has_symlinks,
     pathjoin,
-    rmtree,
     terminal_width,
     )
 from bzrlib.tests.HTTPTestUtil import TestCaseWithWebserver

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/blackbox/test_push.py	2006-10-16 01:25:46 +0000
@@ -71,7 +71,7 @@
         out = self.run_bzr('push', '../branch_b', retcode=3)
         self.assertEquals(out,
                 ('','bzr: ERROR: These branches have diverged.  '
-                    'Try a merge then push with overwrite.\n'))
+                    'Try using "merge" and then "push".\n'))
         self.assertEquals(abspath(branch_a.get_push_location()),
                           abspath(branch_b.bzrdir.root_transport.base))
 

=== modified file 'bzrlib/tests/blackbox/test_selftest.py'
--- bzrlib/tests/blackbox/test_selftest.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/blackbox/test_selftest.py	2006-10-16 01:25:46 +0000
@@ -27,7 +27,7 @@
 from bzrlib.errors import ParamikoNotPresent
 from bzrlib.tests import (
                           TestCase,
-                          TestCaseInTempDir,
+                          TestCaseWithMemoryTransport,
                           TestCaseWithTransport,
                           TestSkipped,
                           )
@@ -66,8 +66,8 @@
         except ParamikoNotPresent:
             raise TestSkipped("Paramiko not present")
         old_transport = bzrlib.tests.default_transport
-        old_root = TestCaseInTempDir.TEST_ROOT
-        TestCaseInTempDir.TEST_ROOT = None
+        old_root = TestCaseWithMemoryTransport.TEST_ROOT
+        TestCaseWithMemoryTransport.TEST_ROOT = None
         try:
             TestOptions.current_test = "test_transport_set_to_sftp"
             stdout = self.capture('selftest --transport=sftp test_transport_set_to_sftp')
@@ -82,7 +82,7 @@
         finally:
             bzrlib.tests.default_transport = old_transport
             TestOptions.current_test = None
-            TestCaseInTempDir.TEST_ROOT = old_root
+            TestCaseWithMemoryTransport.TEST_ROOT = old_root
 
 
 class TestRunBzr(ExternalBase):
@@ -166,12 +166,12 @@
         """bzr selftest --benchmark should not run the default test suite."""
         # We test this by passing a regression test name to --benchmark, which
         # should result in 0 rests run.
-        old_root = TestCaseInTempDir.TEST_ROOT
+        old_root = TestCaseWithMemoryTransport.TEST_ROOT
         try:
-            TestCaseInTempDir.TEST_ROOT = None
+            TestCaseWithMemoryTransport.TEST_ROOT = None
             out, err = self.run_bzr('selftest', '--benchmark', 'workingtree_implementations')
         finally:
-            TestCaseInTempDir.TEST_ROOT = old_root
+            TestCaseWithMemoryTransport.TEST_ROOT = old_root
         self.assertContainsRe(out, 'Ran 0 tests.*\n\nOK')
         self.assertEqual(
             'running tests...\ntests passed\n',

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2006-10-16 01:25:46 +0000
@@ -40,13 +40,14 @@
 import sys
 
 import bzrlib
+from bzrlib import (
+    osutils,
+    )
 from bzrlib.branch import Branch
-import bzrlib.bzrdir as bzrdir
 from bzrlib.errors import BzrCommandError
 from bzrlib.osutils import (
     has_symlinks,
     pathjoin,
-    rmtree,
     terminal_width,
     )
 from bzrlib.tests.HTTPTestUtil import TestCaseWithWebserver
@@ -208,7 +209,7 @@
         self.runbzr('pull')
         self.runbzr('pull ../c')
         self.runbzr('branch ../c ../d')
-        rmtree('../c')
+        osutils.rmtree('../c')
         self.runbzr('pull')
         os.chdir('../b')
         self.runbzr('pull')

=== modified file 'bzrlib/tests/bzrdir_implementations/test_bzrdir.py'
--- bzrlib/tests/bzrdir_implementations/test_bzrdir.py	2006-09-27 22:12:53 +0000
+++ bzrlib/tests/bzrdir_implementations/test_bzrdir.py	2006-09-29 16:34:45 +0000
@@ -153,6 +153,24 @@
         wt = dir.create_workingtree(revision_id=bzrlib.revision.NULL_REVISION)
         self.assertEqual([], wt.get_parent_ids())
 
+    def test_destroy_workingtree(self):
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/file'])
+        tree.add('file')
+        tree.commit('first commit')
+        bzrdir = tree.bzrdir
+        try:
+            bzrdir.destroy_workingtree()
+        except errors.UnsupportedOperation:
+            raise TestSkipped('Format does not support destroying tree')
+        self.failIfExists('tree/file')
+        self.assertRaises(errors.NoWorkingTree, bzrdir.open_workingtree)
+        bzrdir.create_workingtree()
+        self.failUnlessExists('tree/file')
+        bzrdir.destroy_workingtree_metadata()
+        self.failUnlessExists('tree/file')
+        self.assertRaises(errors.NoWorkingTree, bzrdir.open_workingtree)
+            
     def test_clone_bzrdir_empty(self):
         dir = self.make_bzrdir('source')
         target = dir.clone(self.get_url('target'))

=== modified file 'bzrlib/tests/repository_implementations/test_repository.py'
--- bzrlib/tests/repository_implementations/test_repository.py	2006-09-27 20:27:46 +0000
+++ bzrlib/tests/repository_implementations/test_repository.py	2006-09-29 11:15:51 +0000
@@ -582,7 +582,7 @@
         FOO_ID = 'foo<:>ID'
         REV_ID = 'revid-1'
         wt = self.make_branch_and_tree('repo')
-        self.build_tree(["repo/foo"])
+        self.build_tree(["repo/foo"], line_endings='binary')
         # add file with id containing wierd characters
         wt.add(['foo'], [FOO_ID])
         wt.commit('this is my new commit', rev_id=REV_ID)

=== modified file 'bzrlib/tests/test_ancestry.py'
--- bzrlib/tests/test_ancestry.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/test_ancestry.py	2006-10-16 01:25:46 +0000
@@ -19,42 +19,37 @@
 import os
 import sys
 
-from bzrlib.tests import TestCase, TestCaseWithTransport
+from bzrlib.tests import TestCaseWithMemoryTransport
 from bzrlib.branch import Branch
 from bzrlib.revision import is_ancestor
 
 
-class TestAncestry(TestCaseWithTransport):
+class TestAncestry(TestCaseWithMemoryTransport):
+
+    def assertAncestryEqual(self, expected, revision_id, branch):
+        """Assert that the ancestry of revision_id in branch is as expected."""
+        ancestry = branch.repository.get_ancestry(revision_id)
+        self.assertEqual(expected, ancestry)
 
     def test_straightline_ancestry(self):
         """Test ancestry file when just committing."""
-        wt = self.make_branch_and_tree('.')
-        b = wt.branch
-
-        wt.commit(message='one',
-                  allow_pointless=True,
-                  rev_id='tester@foo--1')
-
-        wt.commit(message='two',
-                  allow_pointless=True,
-                  rev_id='tester@foo--2')
-
-        ancs = b.repository.get_ancestry('tester@foo--2')
-        self.assertEqual([None, 'tester@foo--1', 'tester@foo--2'], ancs)
-        self.assertEqual([None, 'tester@foo--1'], 
-                         b.repository.get_ancestry('tester@foo--1'))
+        tree = self.make_branch_and_memory_tree('.')
+        branch = tree.branch
+        rev_id_one = tree.commit('one')
+        rev_id_two = tree.commit('two', allow_pointless=True)
+
+        self.assertAncestryEqual([None, rev_id_one, rev_id_two],
+            rev_id_two, branch)
+        self.assertAncestryEqual([None, rev_id_one], rev_id_one, branch)
 
     def test_none_is_always_an_ancestor(self):
-        wt = self.make_branch_and_tree('.')
-        b = wt.branch
+        tree = self.make_branch_and_memory_tree('.')
         # note this is tested before any commits are done.
-        self.assertEqual(True, is_ancestor(None, None, b))
-        wt.commit(message='one',
-                  allow_pointless=True,
-                  rev_id='tester@foo--1')
-        self.assertEqual(True, is_ancestor(None, None, b))
-        self.assertEqual(True, is_ancestor('tester@foo--1', None, b))
-        self.assertEqual(False, is_ancestor(None, 'tester@foo--1', b))
+        self.assertTrue(is_ancestor(None, None, tree.branch))
+        rev_id = tree.commit('one')
+        self.assertTrue(is_ancestor(None, None, tree.branch))
+        self.assertTrue(is_ancestor(rev_id, None, tree.branch))
+        self.assertFalse(is_ancestor(None, rev_id, tree.branch))
 
 
 # TODO: check that ancestry is updated to include indirectly merged revisions

=== modified file 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_bundle.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/test_bundle.py	2006-10-16 01:25:46 +0000
@@ -20,13 +20,13 @@
 import tempfile
 
 from bzrlib import (
-    bzrdir, 
-    errors, 
-    inventory, 
-    repository, 
+    bzrdir,
+    errors,
+    inventory,
+    repository,
     treebuilder,
     )
-from bzrlib.builtins import merge
+from bzrlib.builtins import _merge_helper
 from bzrlib.bzrdir import BzrDir
 from bzrlib.bundle.apply_bundle import install_bundle, merge_bundle
 from bzrlib.bundle.bundle_data import BundleTree
@@ -640,7 +640,8 @@
         self.assertEqualDiff(tree1_inv, tree2_inv)
         other.rename_one('sub/dir/nolastnewline.txt', 'sub/nolastnewline.txt')
         other.commit('rename file', rev_id='a@cset-0-6b')
-        merge([other.basedir, -1], [None, None], this_dir=self.tree1.basedir)
+        _merge_helper([other.basedir, -1], [None, None],
+                      this_dir=self.tree1.basedir)
         self.tree1.commit(u'Merge', rev_id='a@cset-0-7',
                           verbose=False)
         bundle = self.get_valid_bundle('a@cset-0-6', 'a@cset-0-7')
@@ -741,7 +742,8 @@
         tt.create_file('file2', trans_id)
         tt.apply()
         other.commit('modify text in another tree', rev_id='a@lmod-0-2b')
-        merge([other.basedir, -1], [None, None], this_dir=self.tree1.basedir)
+        _merge_helper([other.basedir, -1], [None, None],
+                      this_dir=self.tree1.basedir)
         self.tree1.commit(u'Merge', rev_id='a@lmod-0-3',
                           verbose=False)
         self.tree1.commit(u'Merge', rev_id='a@lmod-0-4')

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/test_config.py	2006-10-16 01:25:46 +0000
@@ -824,5 +824,5 @@
     def test_extract_email_address(self):
         self.assertEqual('jane@test.com',
                          config.extract_email_address('Jane <jane@test.com>'))
-        self.assertRaises(errors.BzrError,
+        self.assertRaises(errors.NoEmailInUsername,
                           config.extract_email_address, 'Jane Tester')

=== added file 'bzrlib/tests/test_lazy_regex.py'
--- bzrlib/tests/test_lazy_regex.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_lazy_regex.py	2006-10-16 01:25:46 +0000
@@ -0,0 +1,129 @@
+# Copyright (C) 2006 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Test that lazy regexes are not compiled right away"""
+
+import re
+
+from bzrlib import (
+    lazy_regex,
+    tests,
+    )
+
+
+class InstrumentedLazyRegex(lazy_regex.LazyRegex):
+    """Keep track of actions on the lazy regex"""
+
+    _actions = []
+
+    @classmethod
+    def use_actions(cls, actions):
+        cls._actions = actions
+
+    def __getattr__(self, attr):
+        self._actions.append(('__getattr__', attr))
+        return super(InstrumentedLazyRegex, self).__getattr__(attr)
+
+    def _real_re_compile(self, *args, **kwargs):
+        self._actions.append(('_real_re_compile',
+                                               args, kwargs))
+        return super(InstrumentedLazyRegex, self)._real_re_compile(*args, **kwargs)
+
+
+class TestLazyRegex(tests.TestCase):
+
+    def test_lazy_compile(self):
+        """Make sure that LazyRegex objects compile at the right time"""
+        actions = []
+        InstrumentedLazyRegex.use_actions(actions)
+
+        pattern = InstrumentedLazyRegex(args=('foo',))
+        actions.append(('created regex', 'foo'))
+        # This match call should compile the regex and go through __getattr__
+        pattern.match('foo')
+        # But a further call should not go through __getattr__ because it has
+        # been bound locally.
+        pattern.match('foo')
+
+        self.assertEqual([('created regex', 'foo'),
+                          ('__getattr__', 'match'),
+                          ('_real_re_compile', ('foo',), {}),
+                         ], actions)
+
+
+class TestLazyCompile(tests.TestCase):
+
+    def test_simple_acts_like_regex(self):
+        """Test that the returned object has basic regex like functionality"""
+        pattern = lazy_regex.lazy_compile('foo')
+        self.assertIsInstance(pattern, lazy_regex.LazyRegex)
+        self.assertTrue(pattern.match('foo'))
+        self.assertIs(None, pattern.match('bar'))
+
+    def test_extra_args(self):
+        """Test that extra arguments are also properly passed"""
+        pattern = lazy_regex.lazy_compile('foo', re.I)
+        self.assertIsInstance(pattern, lazy_regex.LazyRegex)
+        self.assertTrue(pattern.match('foo'))
+        self.assertTrue(pattern.match('Foo'))
+
+    def test_findall(self):
+        pattern = lazy_regex.lazy_compile('fo*')
+        self.assertEqual(['f', 'fo', 'foo', 'fooo'],
+                         pattern.findall('f fo foo fooo'))
+
+    def test_finditer(self):
+        pattern = lazy_regex.lazy_compile('fo*')
+        matches = [(m.start(), m.end(), m.group())
+                   for m in pattern.finditer('foo bar fop')]
+        self.assertEqual([(0, 3, 'foo'), (8, 10, 'fo')], matches)
+
+    def test_match(self):
+        pattern = lazy_regex.lazy_compile('fo*')
+        self.assertIs(None, pattern.match('baz foo'))
+        self.assertEqual('fooo', pattern.match('fooo').group())
+
+    def test_search(self):
+        pattern = lazy_regex.lazy_compile('fo*')
+        self.assertEqual('foo', pattern.search('baz foo').group())
+        self.assertEqual('fooo', pattern.search('fooo').group())
+
+    def test_split(self):
+        pattern = lazy_regex.lazy_compile('[,;]*')
+        self.assertEqual(['x', 'y', 'z'], pattern.split('x,y;z'))
+
+
+class TestInstallLazyCompile(tests.TestCase):
+
+    def setUp(self):
+        super(TestInstallLazyCompile, self).setUp()
+        self.addCleanup(lazy_regex.reset_compile)
+
+    def test_install(self):
+        lazy_regex.install_lazy_compile()
+        pattern = re.compile('foo')
+        self.assertIsInstance(pattern, lazy_regex.LazyRegex)
+
+    def test_reset(self):
+        lazy_regex.install_lazy_compile()
+        lazy_regex.reset_compile()
+        pattern = re.compile('foo')
+        self.failIf(isinstance(pattern, lazy_regex.LazyRegex),
+                    'lazy_regex.reset_compile() did not restore the original'
+                    ' compile() function %s' % (type(pattern),))
+        # but the returned object should still support regex operations
+        m = pattern.match('foo')
+        self.assertEqual('foo', m.group())

=== modified file 'bzrlib/tests/test_lockdir.py'
--- bzrlib/tests/test_lockdir.py	2006-09-27 20:52:22 +0000
+++ bzrlib/tests/test_lockdir.py	2006-09-29 20:12:58 +0000
@@ -22,6 +22,7 @@
 
 import bzrlib
 from bzrlib import (
+    config,
     osutils,
     )
 from bzrlib.errors import (
@@ -590,3 +591,12 @@
         self.assertContainsRe(info_list[1],
                               r'^held by .* on host .* \[process #\d*\]$')
         self.assertContainsRe(info_list[2], r'locked \d+ seconds? ago$')
+
+    def test_lock_without_email(self):
+        global_config = config.GlobalConfig()
+        # Intentionally has no email address
+        global_config.set_user_option('email', 'User Identity')
+        ld1 = self.get_lock()
+        ld1.create()
+        ld1.lock_write()
+        ld1.unlock()

=== modified file 'bzrlib/tests/test_memorytree.py'
--- bzrlib/tests/test_memorytree.py	2006-09-15 02:03:15 +0000
+++ bzrlib/tests/test_memorytree.py	2006-09-18 05:38:58 +0000
@@ -140,3 +140,9 @@
         tree.unversion(['foo-id'])
         self.assertFalse(tree.has_id('foo-id'))
         tree.unlock()
+
+    def test_last_revision(self):
+        """There should be a last revision method we can call."""
+        tree = self.make_branch_and_memory_tree('branch')
+        rev_id = tree.commit('first post')
+        self.assertEqual(rev_id, tree.last_revision())

=== modified file 'bzrlib/tests/test_merge_core.py'
--- bzrlib/tests/test_merge_core.py	2006-10-05 05:37:25 +0000
+++ bzrlib/tests/test_merge_core.py	2006-10-16 01:25:46 +0000
@@ -19,6 +19,9 @@
 import sys
 
 import bzrlib
+from bzrlib import (
+    osutils,
+    )
 from bzrlib.add import smart_add_tree
 from bzrlib.builtins import merge
 from bzrlib.conflicts import ContentsConflict, TextConflict, PathConflict
@@ -26,8 +29,8 @@
                            WorkingTreeNotRevision, BzrCommandError, NoDiff3)
 import bzrlib.inventory as inventory
 from bzrlib.merge import Merge3Merger, Diff3Merger, WeaveMerger
-from bzrlib.osutils import (file_kind, getcwd, mkdtemp, pathjoin, rename, rmtree,
-                            sha_file, 
+from bzrlib.osutils import (file_kind, getcwd, pathjoin, rename,
+                            sha_file,
                             )
 from bzrlib.transform import TreeTransform
 from bzrlib.tests import TestCaseWithTransport, TestCase, TestSkipped
@@ -36,7 +39,7 @@
 
 class MergeBuilder(object):
     def __init__(self, dir=None):
-        self.dir = mkdtemp(prefix="merge-test", dir=dir)
+        self.dir = osutils.mkdtemp(prefix="merge-test", dir=dir)
         def wt(name):
            path = pathjoin(self.dir, name)
            os.mkdir(path)
@@ -180,11 +183,14 @@
             new_inventory[file_id] = path
         return new_inventory
 
-    def cleanup(self):
+    def unlock(self):
         self.base.unlock()
         self.this.unlock()
         self.other.unlock()
-        rmtree(self.dir)
+
+    def cleanup(self):
+        self.unlock()
+        osutils.rmtree(self.dir)
 
 
 class MergeTest(TestCaseWithTransport):
@@ -299,14 +305,19 @@
         builder.add_file("5", "TREE_ROOT", "name7", "a\nb\nc\nd\ne\nf\n", True)
         builder.change_contents("5", other="a\nz\nc\nd\ne\nf\n", 
                                      this="a\nb\nc\nd\ne\nz\n")
-        builder.merge(merge_factory)
-        self.assertEqual(builder.this.get_file("1").read(), "text4" )
-        self.assertEqual(builder.this.get_file("2").read(), "text2" )
-        self.assertEqual(builder.this.get_file("5").read(), 
-                         "a\nz\nc\nd\ne\nz\n")
-        self.assertIs(builder.this.is_executable("1"), True)
-        self.assertIs(builder.this.is_executable("2"), False)
-        self.assertIs(builder.this.is_executable("3"), True)
+        conflicts = builder.merge(merge_factory)
+        try:
+            self.assertEqual([], conflicts)
+            self.assertEqual("text4", builder.this.get_file("1").read())
+            self.assertEqual("text2", builder.this.get_file("2").read())
+            self.assertEqual("a\nz\nc\nd\ne\nz\n", 
+                             builder.this.get_file("5").read())
+            self.assertTrue(builder.this.is_executable("1"))
+            self.assertFalse(builder.this.is_executable("2"))
+            self.assertTrue(builder.this.is_executable("3"))
+        except:
+            builder.unlock()
+            raise
         return builder
 
     def contents_test_conflicts(self, merge_factory):

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/test_osutils.py	2006-10-16 01:25:46 +0000
@@ -23,8 +23,11 @@
 import sys
 
 import bzrlib
+from bzrlib import (
+    errors,
+    osutils,
+    )
 from bzrlib.errors import BzrBadParameterNotUnicode, InvalidURL
-import bzrlib.osutils as osutils
 from bzrlib.tests import (
         StringIOWrapper,
         TestCase, 
@@ -78,6 +81,14 @@
         self.assertEqual(type(result), str)
         self.assertContainsRe(result, r'^[a-z0-9]{100}$')
 
+    def test_is_inside(self):
+        is_inside = osutils.is_inside
+        self.assertTrue(is_inside('src', 'src/foo.c'))
+        self.assertFalse(is_inside('src', 'srccontrol'))
+        self.assertTrue(is_inside('src', 'src/a/a/a/foo.c'))
+        self.assertTrue(is_inside('foo.c', 'foo.c'))
+        self.assertFalse(is_inside('foo.c', ''))
+        self.assertTrue(is_inside('', 'foo.c'))
 
     def test_rmtree(self):
         # Check to remove tree with read-only files/dirs
@@ -311,6 +322,18 @@
         except (IOError, OSError), e:
             self.assertEqual(errno.ENOENT, e.errno)
 
+    def test_splitpath(self):
+        def check(expected, path):
+            self.assertEqual(expected, osutils.splitpath(path))
+
+        check(['a'], 'a')
+        check(['a', 'b'], 'a/b')
+        check(['a', 'b'], 'a/./b')
+        check(['a', '.b'], 'a/.b')
+        check(['a', '.b'], 'a\\.b')
+
+        self.assertRaises(errors.BzrError, osutils.splitpath, 'a/../b')
+
 
 class TestMacFuncsDirs(TestCaseInTempDir):
     """Test mac special functions that require directories."""
@@ -336,6 +359,7 @@
         os.chdir(u'Ba\u030agfors')
         self.assertEndsWith(osutils._mac_getcwd(), u'B\xe5gfors')
 
+
 class TestSplitLines(TestCase):
 
     def test_split_unicode(self):

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/test_selftest.py	2006-10-16 01:25:46 +0000
@@ -24,13 +24,14 @@
 import unittest
 import warnings
 
-from bzrlib import osutils
+from bzrlib import osutils, memorytree
 import bzrlib
 from bzrlib.progress import _BaseProgressBar
 from bzrlib.tests import (
                           ChrootedTestCase,
                           TestCase,
                           TestCaseInTempDir,
+                          TestCaseWithMemoryTransport,
                           TestCaseWithTransport,
                           TestSkipped,
                           TestSuite,
@@ -435,6 +436,37 @@
         self.assertEqual(self.test_home_dir, os.environ['HOME'])
 
 
+class TestTestCaseWithMemoryTransport(TestCaseWithMemoryTransport):
+
+    def test_home_is_non_existant_dir_under_root(self):
+        """The test_home_dir for TestCaseWithMemoryTransport is missing.
+
+        This is because TestCaseWithMemoryTransport is for tests that do not
+        need any disk resources: they should be hooked into bzrlib in such a 
+        way that no global settings are being changed by the test (only a 
+        few tests should need to do that), and having a missing dir as home is
+        an effective way to ensure that this is the case.
+        """
+        self.assertEqual(self.TEST_ROOT + "/MemoryTransportMissingHomeDir",
+            self.test_home_dir)
+        self.assertEqual(self.test_home_dir, os.environ['HOME'])
+        
+    def test_cwd_is_TEST_ROOT(self):
+        self.assertEqual(self.test_dir, self.TEST_ROOT)
+        cwd = osutils.getcwd()
+        self.assertEqual(self.test_dir, cwd)
+
+    def test_make_branch_and_memory_tree(self):
+        """In TestCaseWithMemoryTransport we should not make the branch on disk.
+
+        This is hard to comprehensively robustly test, so we settle for making
+        a branch and checking no directory was created at its relpath.
+        """
+        tree = self.make_branch_and_memory_tree('dir')
+        self.failIfExists('dir')
+        self.assertIsInstance(tree, memorytree.MemoryTree)
+
+
 class TestTestCaseWithTransport(TestCaseWithTransport):
     """Tests for the convenience functions TestCaseWithTransport introduces."""
 
@@ -985,7 +1017,7 @@
         self.assertIsInstance(bzrlib.bzrdir.BzrDir.open('b')._format,
                               bzrlib.bzrdir.BzrDirFormat6)
 
-    def test_make_branch_and_mutable_tree(self):
+    def test_make_branch_and_memory_tree(self):
         # we should be able to get a new branch and a mutable tree from
         # TestCaseWithTransport
         tree = self.make_branch_and_memory_tree('a')

=== modified file 'bzrlib/tests/test_smart_transport.py'
--- bzrlib/tests/test_smart_transport.py	2006-09-18 08:34:54 +0000
+++ bzrlib/tests/test_smart_transport.py	2006-09-28 10:31:13 +0000
@@ -26,6 +26,7 @@
         bzrdir,
         errors,
         tests,
+        urlutils,
         )
 from bzrlib.transport import (
         get_transport,
@@ -72,7 +73,8 @@
         """Feed a canned query version to a server"""
         to_server = StringIO('hello\n')
         from_server = StringIO()
-        server = smart.SmartStreamServer(to_server, from_server, local.LocalTransport('file:///'))
+        server = smart.SmartStreamServer(to_server, from_server, 
+            local.LocalTransport(urlutils.local_path_to_url('/')))
         server._serve_one_request()
         self.assertEqual('ok\0011\n',
                          from_server.getvalue())
@@ -115,8 +117,11 @@
         without ssh intermediating.
         """
         args = [sys.executable, sys.argv[0], 'serve', '--inet']
+        do_close_fds = True
+        if sys.platform == 'win32':
+            do_close_fds = False
         child = subprocess.Popen(args, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-                                 close_fds=True)
+                                 close_fds=do_close_fds, universal_newlines=True)
         conn = smart.SmartStreamClient(lambda: (child.stdout, child.stdin))
         conn.query_version()
         conn.query_version()

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/test_transport.py	2006-10-16 01:25:46 +0000
@@ -100,6 +100,13 @@
         finally:
             _set_protocol_handlers(saved_handlers)
 
+    def test__combine_paths(self):
+        t = Transport('/')
+        self.assertEqual('/home/sarah/project/foo',
+                         t._combine_paths('/home/sarah', 'project/foo'))
+        self.assertEqual('/etc',
+                         t._combine_paths('/home/sarah', '../../etc'))
+
 
 class TestCoalesceOffsets(TestCase):
     
@@ -415,7 +422,7 @@
         base_url = self._server.get_url()
         # try getting the transport via the regular interface:
         t = get_transport(base_url)
-        if not isinstance(t, self.transport_class): 
+        if not isinstance(t, self.transport_class):
             # we did not get the correct transport class type. Override the
             # regular connection behaviour by direct construction.
             t = self.transport_class(base_url)

=== modified file 'bzrlib/tests/test_whitebox.py'
--- bzrlib/tests/test_whitebox.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/test_whitebox.py	2006-10-16 01:25:46 +0000
@@ -17,6 +17,9 @@
 import os
 import unittest
 
+from bzrlib import (
+    osutils,
+    )
 from bzrlib.tests import TestCaseWithTransport, TestCase
 from bzrlib.branch import Branch
 from bzrlib.errors import PathNotChild
@@ -33,7 +36,6 @@
         if it is inside a branch and return the path relative to the base.
         """
         import tempfile
-        from bzrlib.osutils import rmtree
         
         savedir = os.getcwdu()
         dtmp = tempfile.mkdtemp()
@@ -81,4 +83,4 @@
 
         finally:
             os.chdir(savedir)
-            rmtree(dtmp)
+            osutils.rmtree(dtmp)

=== modified file 'bzrlib/trace.py'
--- bzrlib/trace.py	2006-10-11 23:08:27 +0000
+++ bzrlib/trace.py	2006-10-16 01:25:46 +0000
@@ -50,15 +50,17 @@
 # is quite expensive, even when the message is not printed by any handlers.
 # We should perhaps change back to just simply doing it here.
 
-
-import errno
 import os
 import sys
 import re
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+import errno
 import logging
+""")
 
 import bzrlib
-from bzrlib.errors import BzrError, BzrNewError
 from bzrlib.symbol_versioning import (deprecated_function,
         zero_nine,
         )

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2006-09-16 02:26:44 +0000
+++ bzrlib/transport/__init__.py	2006-10-11 00:23:23 +0000
@@ -26,14 +26,17 @@
 it.
 """
 
+from cStringIO import StringIO
+import re
+import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import errno
 from collections import deque
 from copy import deepcopy
-from cStringIO import StringIO
-import re
 from stat import S_ISDIR
-import sys
-from unittest import TestSuite
+import unittest
 import urllib
 import urlparse
 import warnings
@@ -45,8 +48,8 @@
     symbol_versioning,
     urlutils,
     )
-from bzrlib.errors import DependencyNotPresent
-from bzrlib.osutils import pumpfile
+""")
+
 from bzrlib.symbol_versioning import (
         deprecated_passed,
         deprecated_method,
@@ -262,7 +265,7 @@
         """
         assert not isinstance(from_file, basestring), \
             '_pump should only be called on files not %s' % (type(from_file,))
-        pumpfile(from_file, to_file)
+        osutils.pumpfile(from_file, to_file)
 
     def _get_total(self, multi):
         """Try to figure out how many entries are in multi,
@@ -323,11 +326,10 @@
 
         Examples::
 
-            >>> t = Transport('/')
-            >>> t._combine_paths('/home/sarah', 'project/foo')
-            '/home/sarah/project/foo'
-            >>> t._combine_paths('/home/sarah', '../../etc')
-            '/etc'
+            t._combine_paths('/home/sarah', 'project/foo')
+                => '/home/sarah/project/foo'
+            t._combine_paths('/home/sarah', '../../etc')
+                => '/etc'
 
         :param base_path: urlencoded path for the transport root; typically a 
              URL but need not contain scheme/host/etc.
@@ -1031,7 +1033,7 @@
     for factory in factory_list:
         try:
             return factory(base), None
-        except DependencyNotPresent, e:
+        except errors.DependencyNotPresent, e:
             mutter("failed to instantiate transport %r for %r: %r" %
                     (factory, base, e))
             last_err = e
@@ -1084,7 +1086,7 @@
     """
 
     def adapt(self, test):
-        result = TestSuite()
+        result = unittest.TestSuite()
         for klass, server_factory in self._test_permutations():
             new_test = deepcopy(test)
             new_test.transport_class = klass

=== modified file 'bzrlib/transport/http/_pycurl.py'
--- bzrlib/transport/http/_pycurl.py	2006-08-31 21:34:20 +0000
+++ bzrlib/transport/http/_pycurl.py	2006-10-07 09:22:18 +0000
@@ -179,12 +179,6 @@
         # handle_response will raise NoSuchFile, etc based on the response code
         return code, response.handle_response(abspath, code, headers, data)
 
-    def _raise_curl_connection_error(self, curl):
-        curl_errno = curl.getinfo(pycurl.OS_ERRNO)
-        url = curl.getinfo(pycurl.EFFECTIVE_URL)
-        raise ConnectionError('curl connection error (%s) on %s'
-                              % (os.strerror(curl_errno), url))
-
     def _raise_curl_http_error(self, curl, info=None):
         code = curl.getinfo(pycurl.HTTP_CODE)
         url = curl.getinfo(pycurl.EFFECTIVE_URL)
@@ -220,8 +214,10 @@
             mutter('got pycurl error: %s, %s, %s, url: %s ',
                     e[0], _pycurl_errors.errorcode[e[0]], e, url)
             if e[0] in (_pycurl_errors.CURLE_COULDNT_RESOLVE_HOST,
-                        _pycurl_errors.CURLE_COULDNT_CONNECT):
-                self._raise_curl_connection_error(curl)
+                        _pycurl_errors.CURLE_COULDNT_CONNECT,
+                        _pycurl_errors.CURLE_COULDNT_RESOLVE_PROXY):
+                raise ConnectionError('curl connection error (%s)\non %s'
+                              % (e[1], url))
             # jam 20060713 The code didn't use to re-raise the exception here
             # but that seemed bogus
             raise

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2006-09-06 20:42:45 +0000
+++ bzrlib/transport/local.py	2006-09-13 03:21:03 +0000
@@ -19,22 +19,24 @@
 This is a fairly thin wrapper on regular file IO.
 """
 
+import os
+from stat import ST_MODE, S_ISDIR, ST_SIZE, S_IMODE
+import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import errno
-import os
 import shutil
-import sys
-from stat import ST_MODE, S_ISDIR, ST_SIZE, S_IMODE
-import tempfile
 
 from bzrlib import (
     atomicfile,
     osutils,
     urlutils,
+    symbol_versioning,
     )
-from bzrlib.osutils import (abspath, realpath, normpath, pathjoin, rename,
-                            check_legal_path, rmtree)
-from bzrlib.symbol_versioning import warn
 from bzrlib.trace import mutter
+""")
+
 from bzrlib.transport import Transport, Server
 
 
@@ -48,7 +50,8 @@
     def __init__(self, base):
         """Set the base path where files will be stored."""
         if not base.startswith('file://'):
-            warn("Instantiating LocalTransport with a filesystem path"
+            symbol_versioning.warn(
+                "Instantiating LocalTransport with a filesystem path"
                 " is deprecated as of bzr 0.8."
                 " Please use bzrlib.transport.get_transport()"
                 " or pass in a file:// url.",
@@ -91,7 +94,8 @@
         assert isinstance(relpath, basestring), (type(relpath), relpath)
         # jam 20060426 Using normpath on the real path, because that ensures
         #       proper handling of stuff like
-        path = normpath(pathjoin(self._local_base, urlutils.unescape(relpath)))
+        path = osutils.normpath(osutils.pathjoin(
+                    self._local_base, urlutils.unescape(relpath)))
         return urlutils.local_path_to_url(path)
 
     def local_abspath(self, relpath):
@@ -145,7 +149,7 @@
         path = relpath
         try:
             path = self._abspath(relpath)
-            check_legal_path(path)
+            osutils.check_legal_path(path)
             fp = atomicfile.AtomicFile(path, 'wb', new_mode=mode)
         except (IOError, OSError),e:
             self._translate_error(e, path)
@@ -165,7 +169,7 @@
         path = relpath
         try:
             path = self._abspath(relpath)
-            check_legal_path(path)
+            osutils.check_legal_path(path)
             fp = atomicfile.AtomicFile(path, 'wb', new_mode=mode)
         except (IOError, OSError),e:
             self._translate_error(e, path)
@@ -366,7 +370,7 @@
 
         try:
             # this version will delete the destination if necessary
-            rename(path_from, path_to)
+            osutils.rename(path_from, path_to)
         except (IOError, OSError),e:
             # TODO: What about path_to?
             self._translate_error(e, path_from)

=== modified file 'bzrlib/transport/smart.py'
--- bzrlib/transport/smart.py	2006-09-26 05:51:37 +0000
+++ bzrlib/transport/smart.py	2006-10-04 07:57:23 +0000
@@ -552,13 +552,14 @@
     """
 
     def __init__(self):
-        self._homedir = os.getcwd()
+        self._homedir = urlutils.local_path_to_url(os.getcwd())[7:]
         # The server is set up by default like for ssh access: the client
         # passes filesystem-absolute paths; therefore the server must look
         # them up relative to the root directory.  it might be better to act
         # a public server and have the server rewrite paths into the test
         # directory.
-        SmartTCPServer.__init__(self, transport.get_transport("file:///"))
+        SmartTCPServer.__init__(self,
+            transport.get_transport(urlutils.local_path_to_url('/')))
         
     def setUp(self):
         """Set up server for testing"""
@@ -570,9 +571,6 @@
     def get_url(self):
         """Return the url of the server"""
         host, port = self._server_socket.getsockname()
-        # XXX: I think this is likely to break on windows -- self._homedir will
-        # have backslashes (and maybe a drive letter?).
-        #  -- Andrew Bennetts, 2006-08-29
         return "bzr://%s:%d%s" % (host, port, urlutils.escape(self._homedir))
 
     def get_bogus_url(self):
@@ -1029,36 +1027,32 @@
         if self._socket is not None:
             self._socket.close()
 
-try:
-    from bzrlib.transport import sftp, ssh
-except errors.ParamikoNotPresent:
-    # no paramiko, no SSHTransport.
-    pass
-else:
-    class SmartSSHTransport(SmartTransport):
-        """Connection to smart server over SSH."""
-
-        def __init__(self, url, clone_from=None):
-            # TODO: all this probably belongs in the parent class.
-            super(SmartSSHTransport, self).__init__(url, clone_from)
-            try:
-                if self._port is not None:
-                    self._port = int(self._port)
-            except (ValueError, TypeError), e:
-                raise errors.InvalidURL(path=url, extra="invalid port %s" % self._port)
-
-        def _connect_to_server(self):
-            executable = os.environ.get('BZR_REMOTE_PATH', 'bzr')
-            vendor = ssh._get_ssh_vendor()
-            self._ssh_connection = vendor.connect_ssh(self._username,
-                    self._password, self._host, self._port,
-                    command=[executable, 'serve', '--inet', '--directory=/',
-                             '--allow-writes'])
-            return self._ssh_connection.get_filelike_channels()
-
-        def disconnect(self):
-            super(SmartSSHTransport, self).disconnect()
-            self._ssh_connection.close()
+
+class SmartSSHTransport(SmartTransport):
+    """Connection to smart server over SSH."""
+
+    def __init__(self, url, clone_from=None):
+        # TODO: all this probably belongs in the parent class.
+        super(SmartSSHTransport, self).__init__(url, clone_from)
+        try:
+            if self._port is not None:
+                self._port = int(self._port)
+        except (ValueError, TypeError), e:
+            raise errors.InvalidURL(path=url, extra="invalid port %s" % self._port)
+
+    def _connect_to_server(self):
+        from bzrlib.transport import ssh
+        executable = os.environ.get('BZR_REMOTE_PATH', 'bzr')
+        vendor = ssh._get_ssh_vendor()
+        self._ssh_connection = vendor.connect_ssh(self._username,
+                self._password, self._host, self._port,
+                command=[executable, 'serve', '--inet', '--directory=/',
+                         '--allow-writes'])
+        return self._ssh_connection.get_filelike_channels()
+
+    def disconnect(self):
+        super(SmartSSHTransport, self).disconnect()
+        self._ssh_connection.close()
 
 
 def get_test_permutations():

=== modified file 'bzrlib/ui/__init__.py'
--- bzrlib/ui/__init__.py	2006-07-28 16:05:23 +0000
+++ bzrlib/ui/__init__.py	2006-10-06 07:29:17 +0000
@@ -30,7 +30,13 @@
 
 import sys
 
-import bzrlib.progress
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+from bzrlib import (
+    progress,
+    )
+""")
+
 from bzrlib.symbol_versioning import (deprecated_method, zero_eight)
 
 
@@ -118,15 +124,15 @@
     @deprecated_method(zero_eight)
     def progress_bar(self):
         """See UIFactory.nested_progress_bar()."""
-        return bzrlib.progress.DummyProgress()
+        return progress.DummyProgress()
 
     def get_password(self, prompt='', **kwargs):
         return None
 
     def nested_progress_bar(self):
         if self._progress_bar_stack is None:
-            self._progress_bar_stack = bzrlib.progress.ProgressBarStack(
-                klass=bzrlib.progress.DummyProgress)
+            self._progress_bar_stack = progress.ProgressBarStack(
+                klass=progress.DummyProgress)
         return self._progress_bar_stack.get_nested()
 
     def clear_term(self):

=== modified file 'bzrlib/ui/text.py'
--- bzrlib/ui/text.py	2006-07-28 16:05:23 +0000
+++ bzrlib/ui/text.py	2006-10-06 07:03:55 +0000
@@ -19,12 +19,21 @@
 """Text UI, write output to the console.
 """
 
+import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import getpass
-import sys
-
-import bzrlib.progress
-from bzrlib.symbol_versioning import (deprecated_method, 
-        zero_eight)
+
+from bzrlib import (
+    progress,
+    )
+""")
+
+from bzrlib.symbol_versioning import (
+    deprecated_method,
+    zero_eight,
+    )
 from bzrlib.ui import CLIUIFactory
 
 
@@ -61,7 +70,7 @@
         """See UIFactory.nested_progress_bar()."""
         # this in turn is abstract, and creates either a tty or dots
         # bar depending on what we think of the terminal
-        return bzrlib.progress.ProgressBar()
+        return progress.ProgressBar()
 
     def get_password(self, prompt='', **kwargs):
         """Prompt the user for a password.
@@ -86,7 +95,7 @@
         may return a tty or dots bar depending on the terminal.
         """
         if self._progress_bar_stack is None:
-            self._progress_bar_stack = bzrlib.progress.ProgressBarStack(
+            self._progress_bar_stack = progress.ProgressBarStack(
                 klass=self._bar_type)
         return self._progress_bar_stack.get_nested()
 

=== modified file 'bzrlib/urlutils.py'
--- bzrlib/urlutils.py	2006-10-11 23:08:27 +0000
+++ bzrlib/urlutils.py	2006-10-16 01:25:46 +0000
@@ -19,13 +19,19 @@
 """A collection of function for handling URL operations."""
 
 import os
-from posixpath import split as _posix_split, normpath as _posix_normpath
 import re
 import sys
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+from posixpath import split as _posix_split, normpath as _posix_normpath
 import urllib
 
-import bzrlib.errors as errors
-import bzrlib.osutils
+from bzrlib import (
+    errors,
+    osutils,
+    )
+""")
 
 
 def basename(url, exclude_trailing_slash=True):
@@ -75,7 +81,7 @@
 
     base = local_path_from_url(base)
     path = local_path_from_url(path)
-    return escape(bzrlib.osutils.relpath(base, path))
+    return escape(osutils.relpath(base, path))
 
 
 def _find_scheme_and_separator(url):
@@ -168,7 +174,7 @@
     # importing directly from posixpath allows us to test this 
     # on non-posix platforms
     return 'file://' + escape(_posix_normpath(
-        bzrlib.osutils._posix_abspath(path)))
+        osutils._posix_abspath(path)))
 
 
 def _win32_local_path_from_url(url):
@@ -197,8 +203,8 @@
     #       which actually strips trailing space characters.
     #       The worst part is that under linux ntpath.abspath has different
     #       semantics, since 'nt' is not an available module.
-    win32_path = bzrlib.osutils._nt_normpath(
-        bzrlib.osutils._win32_abspath(path)).replace('\\', '/')
+    win32_path = osutils._nt_normpath(
+        osutils._win32_abspath(path)).replace('\\', '/')
     return 'file:///' + win32_path[0].upper() + ':' + escape(win32_path[2:])
 
 

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2006-10-11 23:08:27 +0000
+++ bzrlib/versionedfile.py	2006-10-16 01:25:46 +0000
@@ -19,17 +19,21 @@
 
 """Versioned text file storage api."""
 
-
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 from copy import deepcopy
-from unittest import TestSuite
-
-
-import bzrlib.errors as errors
+import unittest
+
+from bzrlib import (
+    errors,
+    tsort,
+    ui,
+    )
+from bzrlib.transport.memory import MemoryTransport
+""")
+
 from bzrlib.inter import InterObject
 from bzrlib.textmerge import TextMerge
-from bzrlib.transport.memory import MemoryTransport
-from bzrlib.tsort import topo_sort
-from bzrlib import ui
 from bzrlib.symbol_versioning import (deprecated_function,
         deprecated_method,
         zero_eight,
@@ -473,7 +477,7 @@
         """
         raise NotImplementedError(VersionedFile.plan_merge)
         
-    def weave_merge(self, plan, a_marker=TextMerge.A_MARKER, 
+    def weave_merge(self, plan, a_marker=TextMerge.A_MARKER,
                     b_marker=TextMerge.B_MARKER):
         return PlanWeaveMerge(plan, a_marker, b_marker).merge_lines()[0]
 
@@ -590,7 +594,7 @@
             target = temp_source
         version_ids = self._get_source_version_ids(version_ids, ignore_missing)
         graph = self.source.get_graph(version_ids)
-        order = topo_sort(graph.items())
+        order = tsort.topo_sort(graph.items())
         pb = ui.ui_factory.nested_progress_bar()
         parent_texts = {}
         try:
@@ -677,7 +681,7 @@
         self._formats = formats
     
     def adapt(self, test):
-        result = TestSuite()
+        result = unittest.TestSuite()
         for (interversionedfile_class,
              versionedfile_factory,
              versionedfile_factory_to) in self._formats:

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2006-09-27 20:27:46 +0000
+++ bzrlib/workingtree.py	2006-10-06 06:27:06 +0000
@@ -29,9 +29,6 @@
 WorkingTree.open(dir).
 """
 
-MERGE_MODIFIED_HEADER_1 = "BZR merge-modified list format 1"
-CONFLICT_HEADER_1 = "BZR conflict list format 1"
-
 # TODO: Give the workingtree sole responsibility for the working inventory;
 # remove the variable and references to it from the branch.  This may require
 # updating the commit code so as to update the inventory within the working
@@ -39,23 +36,39 @@
 # At the moment they may alias the inventory and have old copies of it in
 # memory.  (Now done? -- mbp 20060309)
 
-from binascii import hexlify
+from cStringIO import StringIO
+import os
+import re
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import collections
 from copy import deepcopy
-from cStringIO import StringIO
 import errno
 import fnmatch
-import os
-import re
 import stat
 from time import time
 import warnings
 
 import bzrlib
-from bzrlib import bzrdir, errors, ignores, osutils, urlutils
-from bzrlib.atomicfile import AtomicFile
+from bzrlib import (
+    bzrdir,
+    conflicts as _mod_conflicts,
+    errors,
+    ignores,
+    merge,
+    osutils,
+    urlutils,
+    textui,
+    transform,
+    xml5,
+    xml6,
+    )
 import bzrlib.branch
-from bzrlib.conflicts import Conflict, ConflictList, CONFLICT_SUFFIXES
+from bzrlib.transport import get_transport
+import bzrlib.ui
+""")
+
 from bzrlib.decorators import needs_read_lock, needs_write_lock
 from bzrlib.errors import (BzrCheckError,
                            BzrError,
@@ -70,26 +83,23 @@
 from bzrlib.inventory import InventoryEntry, Inventory
 from bzrlib.lockable_files import LockableFiles, TransportLock
 from bzrlib.lockdir import LockDir
-from bzrlib.merge import merge_inner, transform_tree
 import bzrlib.mutabletree
 from bzrlib.mutabletree import needs_tree_write_lock
 from bzrlib.osutils import (
-                            abspath,
-                            compact_date,
-                            file_kind,
-                            isdir,
-                            getcwd,
-                            pathjoin,
-                            pumpfile,
-                            safe_unicode,
-                            splitpath,
-                            rand_chars,
-                            normpath,
-                            realpath,
-                            relpath,
-                            rename,
-                            supports_executable,
-                            )
+    compact_date,
+    file_kind,
+    isdir,
+    pathjoin,
+    safe_unicode,
+    splitpath,
+    rand_chars,
+    normpath,
+    realpath,
+    supports_executable,
+    )
+from bzrlib.trace import mutter, note
+from bzrlib.transport.local import LocalTransport
+import bzrlib.tree
 from bzrlib.progress import DummyProgress, ProgressPhase
 from bzrlib.revision import NULL_REVISION
 import bzrlib.revisiontree
@@ -101,14 +111,10 @@
         zero_eight,
         zero_eleven,
         )
-from bzrlib.trace import mutter, note
-from bzrlib.transform import build_tree
-from bzrlib.transport import get_transport
-from bzrlib.transport.local import LocalTransport
-from bzrlib.textui import show_status
-import bzrlib.ui
-import bzrlib.xml5
-
+
+
+MERGE_MODIFIED_HEADER_1 = "BZR merge-modified list format 1"
+CONFLICT_HEADER_1 = "BZR conflict list format 1"
 
 # the regex removes any weird characters; we don't escape them 
 # but rather just pull them out
@@ -399,9 +405,9 @@
         else:
             try:
                 xml = self.read_basis_inventory()
-                inv = bzrlib.xml6.serializer_v6.read_inventory_from_string(xml)
+                inv = xml6.serializer_v6.read_inventory_from_string(xml)
                 if inv is not None and inv.revision_id == revision_id:
-                    return bzrlib.tree.RevisionTree(self.branch.repository, 
+                    return bzrlib.tree.RevisionTree(self.branch.repository,
                                                     inv, revision_id)
             except (NoSuchFile, errors.BadInventoryFormat):
                 pass
@@ -463,7 +469,7 @@
         The path may be absolute or relative. If its a relative path it is 
         interpreted relative to the python current working directory.
         """
-        return relpath(self.basedir, path)
+        return osutils.relpath(self.basedir, path)
 
     def has_filename(self, filename):
         return osutils.lexists(self.abspath(filename))
@@ -533,11 +539,11 @@
     def copy_content_into(self, tree, revision_id=None):
         """Copy the current content and user files of this tree into tree."""
         if revision_id is None:
-            transform_tree(tree, self)
+            merge.transform_tree(tree, self)
         else:
             # TODO now merge from tree.last_revision to revision (to preserve
             # user local changes)
-            transform_tree(tree, self)
+            merge.transform_tree(tree, self)
             tree.set_parent_ids([revision_id])
 
     def id2abspath(self, file_id):
@@ -1011,7 +1017,7 @@
                 result.append((f, dest_path))
                 inv.rename(inv.path2id(f), to_dir_id, name_tail)
                 try:
-                    rename(self.abspath(f), self.abspath(dest_path))
+                    osutils.rename(self.abspath(f), self.abspath(dest_path))
                 except OSError, e:
                     raise BzrError("failed to rename %r to %r: %s" %
                                    (f, dest_path, e[1]),
@@ -1063,7 +1069,7 @@
         from_abs = self.abspath(from_rel)
         to_abs = self.abspath(to_rel)
         try:
-            rename(from_abs, to_abs)
+            osutils.rename(from_abs, to_abs)
         except OSError, e:
             inv.rename(file_id, from_parent, from_name)
             raise BzrError("failed to rename %r to %r: %s"
@@ -1146,7 +1152,8 @@
                 pb = bzrlib.ui.ui_factory.nested_progress_bar()
                 try:
                     new_basis_tree = self.branch.basis_tree()
-                    merge_inner(self.branch,
+                    merge.merge_inner(
+                                self.branch,
                                 new_basis_tree,
                                 basis_tree,
                                 this_tree=self,
@@ -1428,7 +1435,7 @@
     def _create_basis_xml_from_inventory(self, revision_id, inventory):
         """Create the text that will be saved in basis-inventory"""
         inventory.revision_id = revision_id
-        return bzrlib.xml6.serializer_v6.write_inventory_to_string(inventory)
+        return xml6.serializer_v6.write_inventory_to_string(inventory)
 
     def _cache_basis_inventory(self, new_revision):
         """Cache new_revision as the basis inventory."""
@@ -1467,7 +1474,7 @@
         """Read the working inventory."""
         # ElementTree does its own conversion from UTF-8, so open in
         # binary.
-        result = bzrlib.xml5.serializer_v5.read_inventory(
+        result = xml5.serializer_v5.read_inventory(
             self._control_files.get('inventory'))
         self._set_inventory(result)
         return result
@@ -1507,7 +1514,8 @@
                     new_status = 'I'
                 else:
                     new_status = '?'
-                show_status(new_status, inv[fid].kind, f, to_file=to_file)
+                textui.show_status(new_status, inv[fid].kind, f,
+                                   to_file=to_file)
             del inv[fid]
 
         self._write_inventory(inv)
@@ -1515,11 +1523,10 @@
     @needs_tree_write_lock
     def revert(self, filenames, old_tree=None, backups=True, 
                pb=DummyProgress()):
-        from transform import revert
-        from conflicts import resolve
+        from bzrlib.conflicts import resolve
         if old_tree is None:
             old_tree = self.basis_tree()
-        conflicts = revert(self, old_tree, filenames, backups, pb)
+        conflicts = transform.revert(self, old_tree, filenames, backups, pb)
         if not len(filenames):
             self.set_parent_ids(self.get_parent_ids()[:1])
             resolve(self)
@@ -1617,7 +1624,8 @@
             # merge tree state up to new branch tip.
             basis = self.basis_tree()
             to_tree = self.branch.basis_tree()
-            result += merge_inner(self.branch,
+            result += merge.merge_inner(
+                                  self.branch,
                                   to_tree,
                                   basis,
                                   this_tree=self)
@@ -1658,7 +1666,8 @@
                 base_rev_id = None
             base_tree = self.branch.repository.revision_tree(base_rev_id)
             other_tree = self.branch.repository.revision_tree(old_tip)
-            result += merge_inner(self.branch,
+            result += merge.merge_inner(
+                                  self.branch,
                                   other_tree,
                                   base_tree,
                                   this_tree=self)
@@ -1668,7 +1677,7 @@
     def _write_inventory(self, inv):
         """Write inventory as the current inventory."""
         sio = StringIO()
-        bzrlib.xml5.serializer_v5.write_inventory(inv, sio)
+        xml5.serializer_v5.write_inventory(inv, sio)
         sio.seek(0)
         self._control_files.put('inventory', sio)
         self._set_inventory(inv)
@@ -1682,7 +1691,7 @@
 
     @needs_read_lock
     def conflicts(self):
-        conflicts = ConflictList()
+        conflicts = _mod_conflicts.ConflictList()
         for conflicted in self._iter_conflicts():
             text = True
             try:
@@ -1701,7 +1710,8 @@
                     if text == False:
                         break
             ctype = {True: 'text conflict', False: 'contents conflict'}[text]
-            conflicts.append(Conflict.factory(ctype, path=conflicted,
+            conflicts.append(_mod_conflicts.Conflict.factory(ctype,
+                             path=conflicted,
                              file_id=self.path2id(conflicted)))
         return conflicts
 
@@ -1777,21 +1787,21 @@
     def add_conflicts(self, new_conflicts):
         conflict_set = set(self.conflicts())
         conflict_set.update(set(list(new_conflicts)))
-        self.set_conflicts(ConflictList(sorted(conflict_set,
-                                               key=Conflict.sort_key)))
+        self.set_conflicts(_mod_conflicts.ConflictList(sorted(conflict_set,
+                                       key=_mod_conflicts.Conflict.sort_key)))
 
     @needs_read_lock
     def conflicts(self):
         try:
             confile = self._control_files.get('conflicts')
         except NoSuchFile:
-            return ConflictList()
+            return _mod_conflicts.ConflictList()
         try:
             if confile.next() != CONFLICT_HEADER_1 + '\n':
                 raise ConflictFormatError()
         except StopIteration:
             raise ConflictFormatError()
-        return ConflictList.from_stanzas(RioReader(confile))
+        return _mod_conflicts.ConflictList.from_stanzas(RioReader(confile))
 
     def unlock(self):
         if self._hashcache.needs_write and self._control_files._lock_count==1:
@@ -1804,7 +1814,7 @@
 
 
 def get_conflicted_stem(path):
-    for suffix in CONFLICT_SUFFIXES:
+    for suffix in _mod_conflicts.CONFLICT_SUFFIXES:
         if path.endswith(suffix):
             return path[:-len(suffix)]
 
@@ -1916,7 +1926,7 @@
         """
         sio = StringIO()
         inv = Inventory()
-        bzrlib.xml5.serializer_v5.write_inventory(inv, sio)
+        xml5.serializer_v5.write_inventory(inv, sio)
         sio.seek(0)
         control_files.put('inventory', sio)
 
@@ -1951,7 +1961,7 @@
         wt.set_root_id(inv.root.file_id)
         basis_tree = branch.repository.revision_tree(revision)
         wt.set_parent_trees([(revision, basis_tree)])
-        build_tree(basis_tree, wt)
+        transform.build_tree(basis_tree, wt)
         return wt
 
     def __init__(self):
@@ -2032,11 +2042,11 @@
             wt._write_inventory(inv)
             wt.set_root_id(inv.root.file_id)
             basis_tree = branch.repository.revision_tree(revision_id)
-            if revision_id == bzrlib.revision.NULL_REVISION:
+            if revision_id == NULL_REVISION:
                 wt.set_parent_trees([])
             else:
                 wt.set_parent_trees([(revision_id, basis_tree)])
-            build_tree(basis_tree, wt)
+            transform.build_tree(basis_tree, wt)
         finally:
             wt.unlock()
             control_files.unlock()

=== modified file 'profile_imports.py'
--- profile_imports.py	2006-09-12 22:02:02 +0000
+++ profile_imports.py	2006-10-11 00:23:23 +0000
@@ -82,7 +82,7 @@
         # scope_name, frame_name, frame_lineno
         out_file.write('%5.1f %5.1f %s %-35s\t@ %s:%d\n'
             % (info[-1]*1000., mod_time*1000., '+'*info[0], 
-               cur[1][:40], info[1], info[2]))
+               cur[1][:35], info[1], info[2]))
 
         if sorted:
             c_times.sort()
@@ -117,17 +117,19 @@
     extra = ''
     if frame_name.endswith('demandload'):
         # If this was demandloaded, we have 3 frames to ignore
-        extra = ' (demandload)'
+        extra = '(demandload) '
         frame = sys._getframe(4)
         frame_name = frame.f_globals.get('__name__', '<unknown>')
     elif frame_name.endswith('lazy_import'):
         # If this was lazily imported, we have 3 frames to ignore
-        extra = ' (lazy)'
+        extra = '[l] '
         frame = sys._getframe(4)
         frame_name = frame.f_globals.get('__name__', '<unknown>')
+    if fromlist:
+        extra += ' [%s]' % (', '.join(map(str, fromlist)),)
     frame_lineno = frame.f_lineno
 
-    this = stack_add(name+extra, frame_name, frame_lineno, scope_name)
+    this = stack_add(extra + name, frame_name, frame_lineno, scope_name)
 
     tstart = time.time()
     try:
@@ -148,9 +150,15 @@
     # And who is requesting this?
     frame = sys._getframe(2)
     frame_name = frame.f_globals.get('__name__', '<unknown>')
+
+    extra = ''
+    if frame_name.endswith('lazy_regex'):
+        # If this was lazily compiled, we have 3 more frames to ignore
+        extra = '[l] '
+        frame = sys._getframe(5)
+        frame_name = frame.f_globals.get('__name__', '<unknown>')
     frame_lineno = frame.f_lineno
-
-    this = stack_add(repr(args[0]), frame_name, frame_lineno)
+    this = stack_add(extra+repr(args[0]), frame_name, frame_lineno)
 
     tstart = time.time()
     try:

